static char rcsid[] = "$Id: genome_hr.c 49456 2011-10-10 17:33:48Z twu $";
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifndef HAVE_MEMCPY
# define memcpy(d,s,n) bcopy((s),(d),(n))
#endif
#ifndef HAVE_MEMMOVE
# define memmove(d,s,n) bcopy((s),(d),(n))
#endif

#include "genome_hr.h"

#include <stdio.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>		/* For tolower() */

#include "assert.h"
#include "except.h"
#include "mem.h"
#include "cmet.h"
#include "atoi.h"


#ifdef WORDS_BIGENDIAN
#include "bigendian.h"
#else
#include "littleendian.h"
#endif


#ifdef DEBUG
#define debug(x) x
#else
#define debug(x)
#endif

/* Fragments */
#ifdef DEBUG1
#define debug1(x) x
#else
#define debug1(x)
#endif

/* Splice sites */
#ifdef DEBUG2
#define debug2(x) x
#else
#define debug2(x)
#endif

/* last_dinucleotide_positions */
#ifdef DEBUG3
#define debug3(x) x
#else
#define debug3(x)
#endif

/* prev_dinucleotide_positions_fwd */
#ifdef DEBUG3A
#define debug3a(x) x
#else
#define debug3a(x)
#endif

/* prev_dinucleotide_positions_rev */
#ifdef DEBUG3B
#define debug3b(x) x
#else
#define debug3b(x)
#endif


#ifndef HAVE_BUILTIN_POPCOUNT
static const int count_bits[] =
{ 0, 1, 1, 2, 1, 2, 2, 3, 1, 2, 2, 3, 2, 3, 3, 4, 1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  1, 2, 2, 3, 2, 3, 3, 4, 2, 3, 3, 4, 3, 4, 4, 5, 2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  2, 3, 3, 4, 3, 4, 4, 5, 3, 4, 4, 5, 4, 5, 5, 6, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8, 5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  5, 6, 6, 7, 6, 7, 7, 8, 6, 7, 7, 8, 7, 8, 8, 9, 6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  6, 7, 7, 8, 7, 8, 8, 9, 7, 8, 8, 9, 8, 9, 9,10, 7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  7, 8, 8, 9, 8, 9, 9,10, 8, 9, 9,10, 9,10,10,11, 8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  8, 9, 9,10, 9,10,10,11, 9,10,10,11,10,11,11,12, 9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
  9,10,10,11,10,11,11,12,10,11,11,12,11,12,12,13,10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
 10,11,11,12,11,12,12,13,11,12,12,13,12,13,13,14,11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,
 11,12,12,13,12,13,13,14,12,13,13,14,13,14,14,15,12,13,13,14,13,14,14,15,13,14,14,15,14,15,15,16,
 };
#endif

static const UINT4 reduce_nt[] =
{0x00,0x01,0x01,0x01,0x02,0x03,0x03,0x03,0x02,0x03,0x03,0x03,0x02,0x03,0x03,0x03,
 0x04,0x05,0x05,0x05,0x06,0x07,0x07,0x07,0x06,0x07,0x07,0x07,0x06,0x07,0x07,0x07,
 0x04,0x05,0x05,0x05,0x06,0x07,0x07,0x07,0x06,0x07,0x07,0x07,0x06,0x07,0x07,0x07,
 0x04,0x05,0x05,0x05,0x06,0x07,0x07,0x07,0x06,0x07,0x07,0x07,0x06,0x07,0x07,0x07,
 0x08,0x09,0x09,0x09,0x0A,0x0B,0x0B,0x0B,0x0A,0x0B,0x0B,0x0B,0x0A,0x0B,0x0B,0x0B,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x08,0x09,0x09,0x09,0x0A,0x0B,0x0B,0x0B,0x0A,0x0B,0x0B,0x0B,0x0A,0x0B,0x0B,0x0B,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x08,0x09,0x09,0x09,0x0A,0x0B,0x0B,0x0B,0x0A,0x0B,0x0B,0x0B,0x0A,0x0B,0x0B,0x0B,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x0C,0x0D,0x0D,0x0D,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,0x0E,0x0F,0x0F,0x0F,
 0x10,0x11,0x11,0x11,0x12,0x13,0x13,0x13,0x12,0x13,0x13,0x13,0x12,0x13,0x13,0x13,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x10,0x11,0x11,0x11,0x12,0x13,0x13,0x13,0x12,0x13,0x13,0x13,0x12,0x13,0x13,0x13,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x10,0x11,0x11,0x11,0x12,0x13,0x13,0x13,0x12,0x13,0x13,0x13,0x12,0x13,0x13,0x13,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x14,0x15,0x15,0x15,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,0x16,0x17,0x17,0x17,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x18,0x19,0x19,0x19,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,0x1A,0x1B,0x1B,0x1B,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x1C,0x1D,0x1D,0x1D,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,0x1E,0x1F,0x1F,0x1F,
 0x20,0x21,0x21,0x21,0x22,0x23,0x23,0x23,0x22,0x23,0x23,0x23,0x22,0x23,0x23,0x23,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x20,0x21,0x21,0x21,0x22,0x23,0x23,0x23,0x22,0x23,0x23,0x23,0x22,0x23,0x23,0x23,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x20,0x21,0x21,0x21,0x22,0x23,0x23,0x23,0x22,0x23,0x23,0x23,0x22,0x23,0x23,0x23,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x24,0x25,0x25,0x25,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,0x26,0x27,0x27,0x27,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x28,0x29,0x29,0x29,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,0x2A,0x2B,0x2B,0x2B,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x2C,0x2D,0x2D,0x2D,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,0x2E,0x2F,0x2F,0x2F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x30,0x31,0x31,0x31,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,0x32,0x33,0x33,0x33,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x34,0x35,0x35,0x35,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,0x36,0x37,0x37,0x37,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x38,0x39,0x39,0x39,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,0x3A,0x3B,0x3B,0x3B,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x3C,0x3D,0x3D,0x3D,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,0x3E,0x3F,0x3F,0x3F,
 0x40,0x41,0x41,0x41,0x42,0x43,0x43,0x43,0x42,0x43,0x43,0x43,0x42,0x43,0x43,0x43,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x40,0x41,0x41,0x41,0x42,0x43,0x43,0x43,0x42,0x43,0x43,0x43,0x42,0x43,0x43,0x43,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x40,0x41,0x41,0x41,0x42,0x43,0x43,0x43,0x42,0x43,0x43,0x43,0x42,0x43,0x43,0x43,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x44,0x45,0x45,0x45,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,0x46,0x47,0x47,0x47,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x48,0x49,0x49,0x49,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,0x4A,0x4B,0x4B,0x4B,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x4C,0x4D,0x4D,0x4D,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,0x4E,0x4F,0x4F,0x4F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x50,0x51,0x51,0x51,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,0x52,0x53,0x53,0x53,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x54,0x55,0x55,0x55,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,0x56,0x57,0x57,0x57,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x58,0x59,0x59,0x59,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,0x5A,0x5B,0x5B,0x5B,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x5C,0x5D,0x5D,0x5D,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,0x5E,0x5F,0x5F,0x5F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x60,0x61,0x61,0x61,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,0x62,0x63,0x63,0x63,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x64,0x65,0x65,0x65,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,0x66,0x67,0x67,0x67,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x68,0x69,0x69,0x69,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,0x6A,0x6B,0x6B,0x6B,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x6C,0x6D,0x6D,0x6D,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,0x6E,0x6F,0x6F,0x6F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x70,0x71,0x71,0x71,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,0x72,0x73,0x73,0x73,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x74,0x75,0x75,0x75,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,0x76,0x77,0x77,0x77,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x78,0x79,0x79,0x79,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,0x7A,0x7B,0x7B,0x7B,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x7C,0x7D,0x7D,0x7D,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,0x7E,0x7F,0x7F,0x7F,
 0x80,0x81,0x81,0x81,0x82,0x83,0x83,0x83,0x82,0x83,0x83,0x83,0x82,0x83,0x83,0x83,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0x80,0x81,0x81,0x81,0x82,0x83,0x83,0x83,0x82,0x83,0x83,0x83,0x82,0x83,0x83,0x83,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0x80,0x81,0x81,0x81,0x82,0x83,0x83,0x83,0x82,0x83,0x83,0x83,0x82,0x83,0x83,0x83,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x84,0x85,0x85,0x85,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,0x86,0x87,0x87,0x87,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x88,0x89,0x89,0x89,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,0x8A,0x8B,0x8B,0x8B,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x8C,0x8D,0x8D,0x8D,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,0x8E,0x8F,0x8F,0x8F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x90,0x91,0x91,0x91,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,0x92,0x93,0x93,0x93,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x94,0x95,0x95,0x95,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,0x96,0x97,0x97,0x97,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x98,0x99,0x99,0x99,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,0x9A,0x9B,0x9B,0x9B,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0x9C,0x9D,0x9D,0x9D,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,0x9E,0x9F,0x9F,0x9F,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xA0,0xA1,0xA1,0xA1,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,0xA2,0xA3,0xA3,0xA3,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA4,0xA5,0xA5,0xA5,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,0xA6,0xA7,0xA7,0xA7,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xA8,0xA9,0xA9,0xA9,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,0xAA,0xAB,0xAB,0xAB,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xAC,0xAD,0xAD,0xAD,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,0xAE,0xAF,0xAF,0xAF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB0,0xB1,0xB1,0xB1,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,0xB2,0xB3,0xB3,0xB3,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB4,0xB5,0xB5,0xB5,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,0xB6,0xB7,0xB7,0xB7,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xB8,0xB9,0xB9,0xB9,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,0xBA,0xBB,0xBB,0xBB,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xBC,0xBD,0xBD,0xBD,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,0xBE,0xBF,0xBF,0xBF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xC0,0xC1,0xC1,0xC1,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,0xC2,0xC3,0xC3,0xC3,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC4,0xC5,0xC5,0xC5,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,0xC6,0xC7,0xC7,0xC7,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xC8,0xC9,0xC9,0xC9,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,0xCA,0xCB,0xCB,0xCB,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xCC,0xCD,0xCD,0xCD,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,0xCE,0xCF,0xCF,0xCF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD0,0xD1,0xD1,0xD1,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,0xD2,0xD3,0xD3,0xD3,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD4,0xD5,0xD5,0xD5,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,0xD6,0xD7,0xD7,0xD7,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xD8,0xD9,0xD9,0xD9,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,0xDA,0xDB,0xDB,0xDB,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xDC,0xDD,0xDD,0xDD,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,0xDE,0xDF,0xDF,0xDF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xE0,0xE1,0xE1,0xE1,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,0xE2,0xE3,0xE3,0xE3,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE4,0xE5,0xE5,0xE5,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,0xE6,0xE7,0xE7,0xE7,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xE8,0xE9,0xE9,0xE9,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,0xEA,0xEB,0xEB,0xEB,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xEC,0xED,0xED,0xED,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,0xEE,0xEF,0xEF,0xEF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF0,0xF1,0xF1,0xF1,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,0xF2,0xF3,0xF3,0xF3,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF4,0xF5,0xF5,0xF5,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,0xF6,0xF7,0xF7,0xF7,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xF8,0xF9,0xF9,0xF9,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,0xFA,0xFB,0xFB,0xFB,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 0xFC,0xFD,0xFD,0xFD,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,0xFE,0xFF,0xFF,0xFF,
 };

#ifndef HAVE_BUILTIN_CLZ
static const int clz_table[] =
{16,15,14,14,13,13,13,13,12,12,12,12,12,12,12,12,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,
 10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,
  9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9,
  9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9,
  8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
  8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
  8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
  8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
#endif

/* bestscore, besti, totalscore from low bit */
static const int score_low[] =
{16,15, 16,14,15, 14,14,15, 14,12,15, 12,14,15, 14,12,15, 12,12,15, 12,10,15, 10,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10, 9, 10, 8, 9,  8, 8, 9,  8, 6, 9,  6, 8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 14,15, 14,12,15, 12,12,15, 12,10,15, 10,12,15, 12,10,15, 10,10,15, 10, 8,15,  8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 12,15, 12,10,15, 10,10,15, 10, 8,15,  8,10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,15, 10, 8,15,  8, 8,15,  8, 6,15,  6, 8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,15,  8, 6,15,  6, 6,15,  6, 4,15,  4, 6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,15,  6, 4,15,  4, 4,15,  4, 2,15,  2, 4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0,
  4,15,  4, 2,15,  2, 2,15,  2, 0,15,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10, 9, 10, 8, 9,  8, 8, 9,  8, 6, 9,  6, 8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 12,11, 12,10,11, 10,10,11, 10, 8,11,  8,10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10, 9, 10, 8, 9,  8, 8, 9,  8, 6, 9,  6, 8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 11,10, 10, 9,10,  8, 9,10,  8, 7,10,  6, 9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 14,13, 14,12,13, 12,12,13, 12,10,13, 10,12,13, 12,10,13, 10,10,13, 10, 8,13,  8,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 12,13, 12,10,13, 10,10,13, 10, 8,13,  8,10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,13, 10, 8,13,  8, 8,13,  8, 6,13,  6, 8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  8, 6,13,  6, 6,13,  6, 4,13,  4, 6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,13,  6, 4,13,  4, 4,13,  4, 2,13,  2, 4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0,
  4,13,  4, 2,13,  2, 2,13,  2, 0,13,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10, 9, 10, 8, 9,  8, 8, 9,  8, 6, 9,  6, 8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 12,11, 12,10,11, 10,10,11, 10, 8,11,  8,10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,11, 10, 8,11,  8, 8,11,  8, 6,11,  6, 8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  8, 6,11,  6, 6,11,  6, 4,11,  4, 6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6,11,  6, 4,11,  4, 4,11,  4, 2,11,  2, 4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0,
  4,11,  4, 2,11,  2, 2,11,  2, 0,11,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10, 9, 10, 8, 9,  8, 8, 9,  8, 6, 9,  6, 8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  8, 6, 9,  6, 6, 9,  6, 4, 9,  4, 6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 9,  6, 4, 9,  4, 4, 9,  4, 2, 9,  2, 4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0,
  4, 9,  4, 2, 9,  2, 2, 9,  2, 0, 9,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 7,  8, 6, 7,  6, 6, 7,  6, 4, 7,  4, 6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  6, 7,  6, 4, 7,  4, 4, 7,  4, 2, 7,  2, 4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0,
  4, 7,  4, 2, 7,  2, 2, 7,  2, 0, 7,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 5,  6, 4, 5,  4, 4, 5,  4, 2, 5,  2, 4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0,
  4, 5,  4, 2, 5,  2, 2, 5,  2, 0, 5,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  4, 3,  4, 2, 3,  2, 2, 3,  2, 0, 3,  0, 2, 1,  2, 0, 1,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 11,10, 10, 9,10,  8, 9,10,  8, 7,10,  6, 9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 13,12, 12,11,12, 10,11,12, 10, 9,12,  8,11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 11,10, 10, 9,10,  8, 9,10,  8, 7,10,  6, 9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 12,11, 10,10,11,  8,10,11,  8, 8,11,  6,10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 11,10,  8, 9,10,  6, 9,10,  6, 7,10,  4, 9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 10, 9,  6, 8, 9,  4, 8, 9,  4, 6, 9,  2, 8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  9, 8,  4, 7, 8,  2, 7, 8,  2, 5, 8,  0, 7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  8, 7,  2, 6, 7,  0, 6, 7,  0, 4, 7, -2, 6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  7, 6,  0, 5, 6, -2, 5, 6, -2, 3, 6, -4, 5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
 15,14, 14,13,14, 12,13,14, 12,11,14, 10,13,14, 12,11,14, 10,11,14, 10, 9,14,  8,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 13,14, 12,11,14, 10,11,14, 10, 9,14,  8,11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 11,14, 10, 9,14,  8, 9,14,  8, 7,14,  6, 9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,14,  8, 7,14,  6, 7,14,  6, 5,14,  4, 7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,14,  6, 5,14,  4, 5,14,  4, 3,14,  2, 5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  5,14,  4, 3,14,  2, 3,14,  2, 1,14,  0, 3,14,  2, 1,14,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 11,10, 10, 9,10,  8, 9,10,  8, 7,10,  6, 9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 13,12, 12,11,12, 10,11,12, 10, 9,12,  8,11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 11,12, 10, 9,12,  8, 9,12,  8, 7,12,  6, 9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,12,  8, 7,12,  6, 7,12,  6, 5,12,  4, 7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,12,  6, 5,12,  4, 5,12,  4, 3,12,  2, 5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  5,12,  4, 3,12,  2, 3,12,  2, 1,12,  0, 3,12,  2, 1,12,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 11,10, 10, 9,10,  8, 9,10,  8, 7,10,  6, 9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  8, 7,10,  6, 7,10,  6, 5,10,  4, 7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7,10,  6, 5,10,  4, 5,10,  4, 3,10,  2, 5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  5,10,  4, 3,10,  2, 3,10,  2, 1,10,  0, 3,10,  2, 1,10,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9, 8,  8, 7, 8,  6, 7, 8,  6, 5, 8,  4, 7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  6, 5, 8,  4, 5, 8,  4, 3, 8,  2, 5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  5, 8,  4, 3, 8,  2, 3, 8,  2, 1, 8,  0, 3, 8,  2, 1, 8,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 6,  6, 5, 6,  4, 5, 6,  4, 3, 6,  2, 5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  5, 6,  4, 3, 6,  2, 3, 6,  2, 1, 6,  0, 3, 6,  2, 1, 6,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  5, 4,  4, 3, 4,  2, 3, 4,  2, 1, 4,  0, 3, 4,  2, 1, 4,  0, 1, 0,  0,-1, 0, -2,
  3, 2,  2, 1, 2,  0, 1, 0,  0,-1, 0, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 12,11, 10,10,11,  8,10,11,  8, 8,11,  6,10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 11,10,  8, 9,10,  6, 9,10,  6, 7,10,  4, 9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 10, 9,  6, 8, 9,  4, 8, 9,  4, 6, 9,  2, 8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  9, 8,  4, 7, 8,  2, 7, 8,  2, 5, 8,  0, 7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  8, 7,  2, 6, 7,  0, 6, 7,  0, 4, 7, -2, 6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  7, 6,  0, 5, 6, -2, 5, 6, -2, 3, 6, -4, 5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
 14,13, 12,12,13, 10,12,13, 10,10,13,  8,12,13, 10,10,13,  8,10,13,  8, 8,13,  6,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 12,13, 10,10,13,  8,10,13,  8, 8,13,  6,10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10,13,  8, 8,13,  6, 8,13,  6, 6,13,  4, 8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,13,  6, 6,13,  4, 6,13,  4, 4,13,  2, 6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,13,  4, 4,13,  2, 4,13,  2, 2,13,  0, 4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2,
  4,13,  2, 2,13,  0, 2,13,  0, 0,13, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 12,11, 10,10,11,  8,10,11,  8, 8,11,  6,10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10,11,  8, 8,11,  6, 8,11,  6, 6,11,  4, 8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  6, 6,11,  4, 6,11,  4, 4,11,  2, 6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6,11,  4, 4,11,  2, 4,11,  2, 2,11,  0, 4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2,
  4,11,  2, 2,11,  0, 2,11,  0, 0,11, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10, 9,  8, 8, 9,  6, 8, 9,  6, 6, 9,  4, 8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  6, 6, 9,  4, 6, 9,  4, 4, 9,  2, 6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 9,  4, 4, 9,  2, 4, 9,  2, 2, 9,  0, 4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2,
  4, 9,  2, 2, 9,  0, 2, 9,  0, 0, 9, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 7,  6, 6, 7,  4, 6, 7,  4, 4, 7,  2, 6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  6, 7,  4, 4, 7,  2, 4, 7,  2, 2, 7,  0, 4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2,
  4, 7,  2, 2, 7,  0, 2, 7,  0, 0, 7, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 5,  4, 4, 5,  2, 4, 5,  2, 2, 5,  0, 4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2,
  4, 5,  2, 2, 5,  0, 2, 5,  0, 0, 5, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  4, 3,  2, 2, 3,  0, 2, 3,  0, 0, 3, -2, 2, 1,  0, 0, 1, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 11,10,  8, 9,10,  6, 9,10,  6, 7,10,  4, 9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 10, 9,  6, 8, 9,  4, 8, 9,  4, 6, 9,  2, 8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  9, 8,  4, 7, 8,  2, 7, 8,  2, 5, 8,  0, 7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  8, 7,  2, 6, 7,  0, 6, 7,  0, 4, 7, -2, 6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  7, 6,  0, 5, 6, -2, 5, 6, -2, 3, 6, -4, 5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
 13,12, 10,11,12,  8,11,12,  8, 9,12,  6,11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4,
 11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4, 9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2,
 11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4, 9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
 11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4, 9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
 11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4, 9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
 11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4, 9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4, 9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4, 9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 11,12,  8, 9,12,  6, 9,12,  6, 7,12,  4, 9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9,12,  6, 7,12,  4, 7,12,  4, 5,12,  2, 7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,12,  4, 5,12,  2, 5,12,  2, 3,12,  0, 5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  5,12,  2, 3,12,  0, 3,12,  0, 1,12, -2, 3,12,  0, 1,12, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 11,10,  8, 9,10,  6, 9,10,  6, 7,10,  4, 9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9,10,  6, 7,10,  4, 7,10,  4, 5,10,  2, 7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7,10,  4, 5,10,  2, 5,10,  2, 3,10,  0, 5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  5,10,  2, 3,10,  0, 3,10,  0, 1,10, -2, 3,10,  0, 1,10, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9, 8,  6, 7, 8,  4, 7, 8,  4, 5, 8,  2, 7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  4, 5, 8,  2, 5, 8,  2, 3, 8,  0, 5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  5, 8,  2, 3, 8,  0, 3, 8,  0, 1, 8, -2, 3, 8,  0, 1, 8, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 6,  4, 5, 6,  2, 5, 6,  2, 3, 6,  0, 5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  5, 6,  2, 3, 6,  0, 3, 6,  0, 1, 6, -2, 3, 6,  0, 1, 6, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  5, 4,  2, 3, 4,  0, 3, 4,  0, 1, 4, -2, 3, 4,  0, 1, 4, -2, 1, 0, -2,-1, 0, -4,
  3, 2,  0, 1, 2, -2, 1, 0, -2,-1, 0, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 10, 9,  6, 8, 9,  4, 8, 9,  4, 6, 9,  2, 8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  9, 8,  4, 7, 8,  2, 7, 8,  2, 5, 8,  0, 7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  8, 7,  2, 6, 7,  0, 6, 7,  0, 4, 7, -2, 6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  7, 6,  0, 5, 6, -2, 5, 6, -2, 3, 6, -4, 5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
 12,11,  8,10,11,  6,10,11,  6, 8,11,  4,10,11,  6, 8,11,  4, 8,11,  4, 6,11,  2,
 10,11,  6, 8,11,  4, 8,11,  4, 6,11,  2, 8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0,
 10,11,  6, 8,11,  4, 8,11,  4, 6,11,  2, 8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
 10,11,  6, 8,11,  4, 8,11,  4, 6,11,  2, 8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
 10,11,  6, 8,11,  4, 8,11,  4, 6,11,  2, 8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
 10,11,  6, 8,11,  4, 8,11,  4, 6,11,  2, 8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
 10,11,  6, 8,11,  4, 8,11,  4, 6,11,  2, 8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
 10,11,  6, 8,11,  4, 8,11,  4, 6,11,  2, 8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8,11,  4, 6,11,  2, 6,11,  2, 4,11,  0, 6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6,11,  2, 4,11,  0, 4,11,  0, 2,11, -2, 4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4,
  4,11,  0, 2,11, -2, 2,11, -2, 0,11, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
 10, 9,  6, 8, 9,  4, 8, 9,  4, 6, 9,  2, 8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 9,  4, 6, 9,  2, 6, 9,  2, 4, 9,  0, 6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 9,  2, 4, 9,  0, 4, 9,  0, 2, 9, -2, 4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4,
  4, 9,  0, 2, 9, -2, 2, 9, -2, 0, 9, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 7,  4, 6, 7,  2, 6, 7,  2, 4, 7,  0, 6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  6, 7,  2, 4, 7,  0, 4, 7,  0, 2, 7, -2, 4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4,
  4, 7,  0, 2, 7, -2, 2, 7, -2, 0, 7, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 5,  2, 4, 5,  0, 4, 5,  0, 2, 5, -2, 4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4,
  4, 5,  0, 2, 5, -2, 2, 5, -2, 0, 5, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  4, 3,  0, 2, 3, -2, 2, 3, -2, 0, 3, -4, 2, 1, -2, 0, 1, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  9, 8,  4, 7, 8,  2, 7, 8,  2, 5, 8,  0, 7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  8, 7,  2, 6, 7,  0, 6, 7,  0, 4, 7, -2, 6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  7, 6,  0, 5, 6, -2, 5, 6, -2, 3, 6, -4, 5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
 11,10,  6, 9,10,  4, 9,10,  4, 7,10,  2, 9,10,  4, 7,10,  2, 7,10,  2, 5,10,  0,
  9,10,  4, 7,10,  2, 7,10,  2, 5,10,  0, 7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2,
  9,10,  4, 7,10,  2, 7,10,  2, 5,10,  0, 7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  9,10,  4, 7,10,  2, 7,10,  2, 5,10,  0, 7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  9,10,  4, 7,10,  2, 7,10,  2, 5,10,  0, 7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  9,10,  4, 7,10,  2, 7,10,  2, 5,10,  0, 7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  9,10,  4, 7,10,  2, 7,10,  2, 5,10,  0, 7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7,10,  2, 5,10,  0, 5,10,  0, 3,10, -2, 5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  5,10,  0, 3,10, -2, 3,10, -2, 1,10, -4, 3,10, -2, 1,10, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  9, 8,  4, 7, 8,  2, 7, 8,  2, 5, 8,  0, 7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  7, 8,  2, 5, 8,  0, 5, 8,  0, 3, 8, -2, 5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  5, 8,  0, 3, 8, -2, 3, 8, -2, 1, 8, -4, 3, 8, -2, 1, 8, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 6,  2, 5, 6,  0, 5, 6,  0, 3, 6, -2, 5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  5, 6,  0, 3, 6, -2, 3, 6, -2, 1, 6, -4, 3, 6, -2, 1, 6, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  5, 4,  0, 3, 4, -2, 3, 4, -2, 1, 4, -4, 3, 4, -2, 1, 4, -4, 1, 0, -4,-1, 0, -6,
  3, 2, -2, 1, 2, -4, 1, 0, -4,-1, 0, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  8, 7,  2, 6, 7,  0, 6, 7,  0, 4, 7, -2, 6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  7, 6,  0, 5, 6, -2, 5, 6, -2, 3, 6, -4, 5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
 10, 9,  4, 8, 9,  2, 8, 9,  2, 6, 9,  0, 8, 9,  2, 6, 9,  0, 6, 9,  0, 4, 9, -2,
  8, 9,  2, 6, 9,  0, 6, 9,  0, 4, 9, -2, 6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4,
  8, 9,  2, 6, 9,  0, 6, 9,  0, 4, 9, -2, 6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  8, 9,  2, 6, 9,  0, 6, 9,  0, 4, 9, -2, 6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  8, 9,  2, 6, 9,  0, 6, 9,  0, 4, 9, -2, 6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  8, 9,  2, 6, 9,  0, 6, 9,  0, 4, 9, -2, 6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 9,  0, 4, 9, -2, 4, 9, -2, 2, 9, -4, 4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6,
  4, 9, -2, 2, 9, -4, 2, 9, -4, 0, 9, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  8, 7,  2, 6, 7,  0, 6, 7,  0, 4, 7, -2, 6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  6, 7,  0, 4, 7, -2, 4, 7, -2, 2, 7, -4, 4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6,
  4, 7, -2, 2, 7, -4, 2, 7, -4, 0, 7, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 5,  0, 4, 5, -2, 4, 5, -2, 2, 5, -4, 4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6,
  4, 5, -2, 2, 5, -4, 2, 5, -4, 0, 5, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  4, 3, -2, 2, 3, -4, 2, 3, -4, 0, 3, -6, 2, 1, -4, 0, 1, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  7, 6,  0, 5, 6, -2, 5, 6, -2, 3, 6, -4, 5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
  9, 8,  2, 7, 8,  0, 7, 8,  0, 5, 8, -2, 7, 8,  0, 5, 8, -2, 5, 8, -2, 3, 8, -4,
  7, 8,  0, 5, 8, -2, 5, 8, -2, 3, 8, -4, 5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6,
  7, 8,  0, 5, 8, -2, 5, 8, -2, 3, 8, -4, 5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6,
  5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6, 3, 8, -4, 1, 8, -6, 1, 0, -6,-1, 0, -8,
  7, 8,  0, 5, 8, -2, 5, 8, -2, 3, 8, -4, 5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6,
  5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6, 3, 8, -4, 1, 8, -6, 1, 0, -6,-1, 0, -8,
  5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6, 3, 8, -4, 1, 8, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  7, 8,  0, 5, 8, -2, 5, 8, -2, 3, 8, -4, 5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6,
  5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6, 3, 8, -4, 1, 8, -6, 1, 0, -6,-1, 0, -8,
  5, 8, -2, 3, 8, -4, 3, 8, -4, 1, 8, -6, 3, 8, -4, 1, 8, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  7, 6,  0, 5, 6, -2, 5, 6, -2, 3, 6, -4, 5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  5, 6, -2, 3, 6, -4, 3, 6, -4, 1, 6, -6, 3, 6, -4, 1, 6, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  5, 4, -2, 3, 4, -4, 3, 4, -4, 1, 4, -6, 3, 4, -4, 1, 4, -6, 1, 0, -6,-1, 0, -8,
  3, 2, -4, 1, 2, -6, 1, 0, -6,-1, 0, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
  8, 7,  0, 6, 7, -2, 6, 7, -2, 4, 7, -4, 6, 7, -2, 4, 7, -4, 4, 7, -4, 2, 7, -6,
  6, 7, -2, 4, 7, -4, 4, 7, -4, 2, 7, -6, 4, 7, -4, 2, 7, -6, 2, 7, -6, 0, 7, -8,
  6, 7, -2, 4, 7, -4, 4, 7, -4, 2, 7, -6, 4, 7, -4, 2, 7, -6, 2, 7, -6, 0, 7, -8,
  4, 7, -4, 2, 7, -6, 2, 7, -6, 0, 7, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  6, 7, -2, 4, 7, -4, 4, 7, -4, 2, 7, -6, 4, 7, -4, 2, 7, -6, 2, 7, -6, 0, 7, -8,
  4, 7, -4, 2, 7, -6, 2, 7, -6, 0, 7, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  6, 5, -2, 4, 5, -4, 4, 5, -4, 2, 5, -6, 4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8,
  4, 5, -4, 2, 5, -6, 2, 5, -6, 0, 5, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  4, 3, -4, 2, 3, -6, 2, 3, -6, 0, 3, -8, 2, 1, -6, 0, 1, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
  7, 6, -2, 5, 6, -4, 5, 6, -4, 3, 6, -6, 5, 6, -4, 3, 6, -6, 3, 6, -6, 1, 6, -8,
  5, 6, -4, 3, 6, -6, 3, 6, -6, 1, 6, -8, 3, 6, -6, 1, 6, -8, 1, 0, -8,-1, 0,-10,
  5, 6, -4, 3, 6, -6, 3, 6, -6, 1, 6, -8, 3, 6, -6, 1, 6, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  5, 4, -4, 3, 4, -6, 3, 4, -6, 1, 4, -8, 3, 4, -6, 1, 4, -8, 1, 0, -8,-1, 0,-10,
  3, 2, -6, 1, 2, -8, 1, 0, -8,-1, 0,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
  6, 5, -4, 4, 5, -6, 4, 5, -6, 2, 5, -8, 4, 5, -6, 2, 5, -8, 2, 5, -8, 0, 5,-10,
  4, 5, -6, 2, 5, -8, 2, 5, -8, 0, 5,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  4, 3, -6, 2, 3, -8, 2, 3, -8, 0, 3,-10, 2, 1, -8, 0, 1,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
  5, 4, -6, 3, 4, -8, 3, 4, -8, 1, 4,-10, 3, 4, -8, 1, 4,-10, 1, 0,-10,-1, 0,-12,
  3, 2, -8, 1, 2,-10, 1, 0,-10,-1, 0,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
  4, 3, -8, 2, 3,-10, 2, 3,-10, 0, 3,-12, 2, 1,-10, 0, 1,-12, 1, 0,-12,-1, 0,-14,
  3, 2,-10, 1, 2,-12, 1, 0,-12,-1, 0,-14, 2, 1,-12, 0, 1,-14, 1, 0,-14,-1, 0,-16,
};
 
/* bestscore, besti, totalscore from high bit */
static const int score_high[] =
{16,15, 16,15,14, 14,14,13, 14,14,13, 12,14,15, 14,13,12, 12,13,12, 12,13,12, 10,
 14,15, 14,13,14, 12,12,11, 12,12,11, 10,12,11, 12,12,11, 10,12,11, 10,12,11,  8,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,10, 10,11,10, 10,11,10,  8,
 12,15, 12,11,10, 10,11,10, 10,11,10,  8,11,10, 10,11,10,  8,11,10,  8,11,10,  6,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10, 9, 10,10, 9,  8,10, 9, 10,10, 9,  8,10, 9,  8,10, 9,  6,
 12,15, 12,11,14, 10,10, 9, 10,10, 9,  8,10, 9, 10,10, 9,  8,10, 9,  8,10, 9,  6,
 10, 9, 10,10, 9,  8,10, 9,  8,10, 9,  6,10, 9,  8,10, 9,  6,10, 9,  6,10, 9,  4,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9, 8,  8, 9, 8,  8, 9, 8,  6,
 10,15, 10, 9, 8,  8, 9, 8,  8, 9, 8,  6, 9, 8,  8, 9, 8,  6, 9, 8,  6, 9, 8,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9, 8,  8, 9, 8,  8, 9, 8,  6,
 10,15, 10, 9, 8,  8, 9, 8,  8, 9, 8,  6, 9, 8,  8, 9, 8,  6, 9, 8,  6, 9, 8,  4,
 10,15, 10, 9, 8,  8, 9, 8,  8, 9, 8,  6, 9, 8,  8, 9, 8,  6, 9, 8,  6, 9, 8,  4,
  9, 8,  8, 9, 8,  6, 9, 8,  6, 9, 8,  4, 9, 8,  6, 9, 8,  4, 9, 8,  4, 9, 8,  2,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 7,  8, 8, 7,  6, 8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4,
 10,15, 10, 9,14,  8, 8, 7,  8, 8, 7,  6, 8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4,
  8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4, 8, 7,  6, 8, 7,  4, 8, 7,  4, 8, 7,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 7,  8, 8, 7,  6, 8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4,
 10,15, 10, 9,14,  8, 8, 7,  8, 8, 7,  6, 8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4,
  8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4, 8, 7,  6, 8, 7,  4, 8, 7,  4, 8, 7,  2,
 10,15, 10, 9,14,  8, 8, 7,  8, 8, 7,  6, 8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4,
  8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4, 8, 7,  6, 8, 7,  4, 8, 7,  4, 8, 7,  2,
  8, 7,  8, 8, 7,  6, 8, 7,  6, 8, 7,  4, 8, 7,  6, 8, 7,  4, 8, 7,  4, 8, 7,  2,
  8, 7,  6, 8, 7,  4, 8, 7,  4, 8, 7,  2, 8, 7,  4, 8, 7,  2, 8, 7,  2, 8, 7,  0,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
  8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4, 8, 9,  6, 8, 9,  4, 8, 9,  4, 8, 9,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
  7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2, 7, 6,  4, 7, 6,  2, 7, 6,  2, 7, 6,  0,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
  7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2, 7, 6,  4, 7, 6,  2, 7, 6,  2, 7, 6,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
  7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2, 7, 6,  4, 7, 6,  2, 7, 6,  2, 7, 6,  0,
  8,15,  8, 7, 6,  6, 7, 6,  6, 7, 6,  4, 7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2,
  7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2, 7, 6,  4, 7, 6,  2, 7, 6,  2, 7, 6,  0,
  7, 6,  6, 7, 6,  4, 7, 6,  4, 7, 6,  2, 7, 6,  4, 7, 6,  2, 7, 6,  2, 7, 6,  0,
  7, 6,  4, 7, 6,  2, 7, 6,  2, 7, 6,  0, 7, 6,  2, 7, 6,  0, 7, 6,  0, 7, 6, -2,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
  8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4, 8, 9,  6, 8, 9,  4, 8, 9,  4, 8, 9,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2, 7, 8,  4, 7, 8,  2, 7, 8,  2, 7, 8,  0,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0, 6, 5,  2, 6, 5,  0, 6, 5,  0, 6, 5, -2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0, 6, 5,  2, 6, 5,  0, 6, 5,  0, 6, 5, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0, 6, 5,  2, 6, 5,  0, 6, 5,  0, 6, 5, -2,
  8,15,  8, 7,14,  6, 6, 5,  6, 6, 5,  4, 6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0, 6, 5,  2, 6, 5,  0, 6, 5,  0, 6, 5, -2,
  6, 5,  6, 6, 5,  4, 6, 5,  4, 6, 5,  2, 6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0,
  6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0, 6, 5,  2, 6, 5,  0, 6, 5,  0, 6, 5, -2,
  6, 5,  4, 6, 5,  2, 6, 5,  2, 6, 5,  0, 6, 5,  2, 6, 5,  0, 6, 5,  0, 6, 5, -2,
  6, 5,  2, 6, 5,  0, 6, 5,  0, 6, 5, -2, 6, 5,  0, 6, 5, -2, 6, 5, -2, 6, 5, -4,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
  8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4, 8, 9,  6, 8, 9,  4, 8, 9,  4, 8, 9,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2, 7, 8,  4, 7, 8,  2, 7, 8,  2, 7, 8,  0,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0, 6, 7,  2, 6, 7,  0, 6, 7,  0, 6, 7, -2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2, 5, 4,  0, 5, 4, -2, 5, 4, -2, 5, 4, -4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2, 5, 4,  0, 5, 4, -2, 5, 4, -2, 5, 4, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2, 5, 4,  0, 5, 4, -2, 5, 4, -2, 5, 4, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2, 5, 4,  0, 5, 4, -2, 5, 4, -2, 5, 4, -4,
  6,15,  6, 5, 4,  4, 5, 4,  4, 5, 4,  2, 5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2, 5, 4,  0, 5, 4, -2, 5, 4, -2, 5, 4, -4,
  5, 4,  4, 5, 4,  2, 5, 4,  2, 5, 4,  0, 5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2,
  5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2, 5, 4,  0, 5, 4, -2, 5, 4, -2, 5, 4, -4,
  5, 4,  2, 5, 4,  0, 5, 4,  0, 5, 4, -2, 5, 4,  0, 5, 4, -2, 5, 4, -2, 5, 4, -4,
  5, 4,  0, 5, 4, -2, 5, 4, -2, 5, 4, -4, 5, 4, -2, 5, 4, -4, 5, 4, -4, 5, 4, -6,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
  8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4, 8, 9,  6, 8, 9,  4, 8, 9,  4, 8, 9,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2, 7, 8,  4, 7, 8,  2, 7, 8,  2, 7, 8,  0,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0, 6, 7,  2, 6, 7,  0, 6, 7,  0, 6, 7, -2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2, 5, 6,  0, 5, 6, -2, 5, 6, -2, 5, 6, -4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4, 4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4, 4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4, 4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4, 4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6,
  6,15,  6, 5,14,  4, 4, 3,  4, 4, 3,  2, 4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4, 4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6,
  4, 3,  4, 4, 3,  2, 4, 3,  2, 4, 3,  0, 4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4, 4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6,
  4, 3,  2, 4, 3,  0, 4, 3,  0, 4, 3, -2, 4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4,
  4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4, 4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6,
  4, 3,  0, 4, 3, -2, 4, 3, -2, 4, 3, -4, 4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6,
  4, 3, -2, 4, 3, -4, 4, 3, -4, 4, 3, -6, 4, 3, -4, 4, 3, -6, 4, 3, -6, 4, 3, -8,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
  8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4, 8, 9,  6, 8, 9,  4, 8, 9,  4, 8, 9,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2, 7, 8,  4, 7, 8,  2, 7, 8,  2, 7, 8,  0,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0, 6, 7,  2, 6, 7,  0, 6, 7,  0, 6, 7, -2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2, 5, 6,  0, 5, 6, -2, 5, 6, -2, 5, 6, -4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4, 4, 5, -2, 4, 5, -4, 4, 5, -4, 4, 5, -6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
  4,15,  4, 3, 2,  2, 3, 2,  2, 3, 2,  0, 3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
  3, 2,  2, 3, 2,  0, 3, 2,  0, 3, 2, -2, 3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
  3, 2,  0, 3, 2, -2, 3, 2, -2, 3, 2, -4, 3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
  3, 2, -2, 3, 2, -4, 3, 2, -4, 3, 2, -6, 3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8,
  3, 2, -4, 3, 2, -6, 3, 2, -6, 3, 2, -8, 3, 2, -6, 3, 2, -8, 3, 2, -8, 3, 2,-10,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
  8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4, 8, 9,  6, 8, 9,  4, 8, 9,  4, 8, 9,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2, 7, 8,  4, 7, 8,  2, 7, 8,  2, 7, 8,  0,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0, 6, 7,  2, 6, 7,  0, 6, 7,  0, 6, 7, -2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2, 5, 6,  0, 5, 6, -2, 5, 6, -2, 5, 6, -4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4, 4, 5, -2, 4, 5, -4, 4, 5, -4, 4, 5, -6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6, 3, 4, -4, 3, 4, -6, 3, 4, -6, 3, 4, -8,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
  4,15,  4, 3,14,  2, 2, 1,  2, 2, 1,  0, 2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
  2, 1,  2, 2, 1,  0, 2, 1,  0, 2, 1, -2, 2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
  2, 1,  0, 2, 1, -2, 2, 1, -2, 2, 1, -4, 2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
  2, 1, -2, 2, 1, -4, 2, 1, -4, 2, 1, -6, 2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
  2, 1, -4, 2, 1, -6, 2, 1, -6, 2, 1, -8, 2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10,
  2, 1, -6, 2, 1, -8, 2, 1, -8, 2, 1,-10, 2, 1, -8, 2, 1,-10, 2, 1,-10, 2, 1,-12,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
  8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4, 8, 9,  6, 8, 9,  4, 8, 9,  4, 8, 9,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2, 7, 8,  4, 7, 8,  2, 7, 8,  2, 7, 8,  0,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0, 6, 7,  2, 6, 7,  0, 6, 7,  0, 6, 7, -2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2, 5, 6,  0, 5, 6, -2, 5, 6, -2, 5, 6, -4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4, 4, 5, -2, 4, 5, -4, 4, 5, -4, 4, 5, -6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6, 3, 4, -4, 3, 4, -6, 3, 4, -6, 3, 4, -8,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8, 2, 3, -6, 2, 3, -8, 2, 3, -8, 2, 3,-10,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6, 2, 5, -4, 2, 5, -6, 2, 5, -6, 2, 5, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6, 2, 5, -4, 2, 5, -6, 2, 5, -6, 2, 5, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  2,15,  2, 1, 0,  0, 1, 0,  0, 1, 0, -2, 1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  1, 0,  0, 1, 0, -2, 1, 0, -2, 1, 0, -4, 1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  1, 0, -2, 1, 0, -4, 1, 0, -4, 1, 0, -6, 1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  1, 0, -4, 1, 0, -6, 1, 0, -6, 1, 0, -8, 1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  1, 0, -6, 1, 0, -8, 1, 0, -8, 1, 0,-10, 1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12,
  1, 0, -8, 1, 0,-10, 1, 0,-10, 1, 0,-12, 1, 0,-10, 1, 0,-12, 1, 0,-12, 1, 0,-14,
 14,15, 14,13,14, 12,12,13, 12,12,13, 10,12,15, 12,11,12, 10,11,12, 10,11,12,  8,
 12,15, 12,11,14, 10,10,11, 10,10,11,  8,10,11, 10,10,11,  8,10,11,  8,10,11,  6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6,
 10,15, 10, 9,10,  8, 9,10,  8, 9,10,  6, 9,10,  8, 9,10,  6, 9,10,  6, 9,10,  4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
 10,15, 10, 9,14,  8, 8, 9,  8, 8, 9,  6, 8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4,
  8, 9,  8, 8, 9,  6, 8, 9,  6, 8, 9,  4, 8, 9,  6, 8, 9,  4, 8, 9,  4, 8, 9,  2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  8,15,  8, 7, 8,  6, 7, 8,  6, 7, 8,  4, 7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2,
  7, 8,  6, 7, 8,  4, 7, 8,  4, 7, 8,  2, 7, 8,  4, 7, 8,  2, 7, 8,  2, 7, 8,  0,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  8,15,  8, 7,14,  6, 6, 7,  6, 6, 7,  4, 6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  6, 6, 7,  4, 6, 7,  4, 6, 7,  2, 6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0,
  6, 7,  4, 6, 7,  2, 6, 7,  2, 6, 7,  0, 6, 7,  2, 6, 7,  0, 6, 7,  0, 6, 7, -2,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  6,15,  6, 5, 6,  4, 5, 6,  4, 5, 6,  2, 5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  4, 5, 6,  2, 5, 6,  2, 5, 6,  0, 5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2,
  5, 6,  2, 5, 6,  0, 5, 6,  0, 5, 6, -2, 5, 6,  0, 5, 6, -2, 5, 6, -2, 5, 6, -4,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  6,15,  6, 5,14,  4, 4, 5,  4, 4, 5,  2, 4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  4, 4, 5,  2, 4, 5,  2, 4, 5,  0, 4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  2, 4, 5,  0, 4, 5,  0, 4, 5, -2, 4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4,
  4, 5,  0, 4, 5, -2, 4, 5, -2, 4, 5, -4, 4, 5, -2, 4, 5, -4, 4, 5, -4, 4, 5, -6,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  4,15,  4, 3, 4,  2, 3, 4,  2, 3, 4,  0, 3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4,  2, 3, 4,  0, 3, 4,  0, 3, 4, -2, 3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4,  0, 3, 4, -2, 3, 4, -2, 3, 4, -4, 3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6,
  3, 4, -2, 3, 4, -4, 3, 4, -4, 3, 4, -6, 3, 4, -4, 3, 4, -6, 3, 4, -6, 3, 4, -8,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  4,15,  4, 3,14,  2, 2, 3,  2, 2, 3,  0, 2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  2, 3,  2, 2, 3,  0, 2, 3,  0, 2, 3, -2, 2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  2, 3,  0, 2, 3, -2, 2, 3, -2, 2, 3, -4, 2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  2, 3, -2, 2, 3, -4, 2, 3, -4, 2, 3, -6, 2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8,
  2, 3, -4, 2, 3, -6, 2, 3, -6, 2, 3, -8, 2, 3, -6, 2, 3, -8, 2, 3, -8, 2, 3,-10,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6, 2, 5, -4, 2, 5, -6, 2, 5, -6, 2, 5, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
  2,15,  2, 1, 2,  0, 1, 2,  0, 1, 2, -2, 1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
  1, 2,  0, 1, 2, -2, 1, 2, -2, 1, 2, -4, 1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
  1, 2, -2, 1, 2, -4, 1, 2, -4, 1, 2, -6, 1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
  1, 2, -4, 1, 2, -6, 1, 2, -6, 1, 2, -8, 1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10,
  1, 2, -6, 1, 2, -8, 1, 2, -8, 1, 2,-10, 1, 2, -8, 1, 2,-10, 1, 2,-10, 1, 2,-12,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6, 2, 5, -4, 2, 5, -6, 2, 5, -6, 2, 5, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8, 1, 4, -6, 1, 4, -8, 1, 4, -8, 1, 4,-10,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6, 1, 6, -4, 1, 6, -6, 1, 6, -6, 1, 6, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6, 1, 6, -4, 1, 6, -6, 1, 6, -6, 1, 6, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  2,15,  2, 1,14,  0, 0, 1,  0, 0, 1, -2, 0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  0, 1,  0, 0, 1, -2, 0, 1, -2, 0, 1, -4, 0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  0, 1, -2, 0, 1, -4, 0, 1, -4, 0, 1, -6, 0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  0, 1, -4, 0, 1, -6, 0, 1, -6, 0, 1, -8, 0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  0, 1, -6, 0, 1, -8, 0, 1, -8, 0, 1,-10, 0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12,
  0, 1, -8, 0, 1,-10, 0, 1,-10, 0, 1,-12, 0, 1,-10, 0, 1,-12, 0, 1,-12, 0, 1,-14,
 12,15, 12,11,14, 10,10,13, 10,10,13,  8,10,15, 10, 9,12,  8, 9,12,  8, 9,12,  6,
 10,15, 10, 9,14,  8, 8,11,  8, 8,11,  6, 8,11,  8, 8,11,  6, 8,11,  6, 8,11,  4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4,
  8,15,  8, 7,10,  6, 7,10,  6, 7,10,  4, 7,10,  6, 7,10,  4, 7,10,  4, 7,10,  2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  8,15,  8, 7,14,  6, 6, 9,  6, 6, 9,  4, 6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2,
  6, 9,  6, 6, 9,  4, 6, 9,  4, 6, 9,  2, 6, 9,  4, 6, 9,  2, 6, 9,  2, 6, 9,  0,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  6,15,  6, 5, 8,  4, 5, 8,  4, 5, 8,  2, 5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0,
  5, 8,  4, 5, 8,  2, 5, 8,  2, 5, 8,  0, 5, 8,  2, 5, 8,  0, 5, 8,  0, 5, 8, -2,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  6,15,  6, 5,14,  4, 4, 7,  4, 4, 7,  2, 4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  4, 4, 7,  2, 4, 7,  2, 4, 7,  0, 4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2,
  4, 7,  2, 4, 7,  0, 4, 7,  0, 4, 7, -2, 4, 7,  0, 4, 7, -2, 4, 7, -2, 4, 7, -4,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  4,15,  4, 3, 6,  2, 3, 6,  2, 3, 6,  0, 3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  2, 3, 6,  0, 3, 6,  0, 3, 6, -2, 3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4,
  3, 6,  0, 3, 6, -2, 3, 6, -2, 3, 6, -4, 3, 6, -2, 3, 6, -4, 3, 6, -4, 3, 6, -6,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  4,15,  4, 3,14,  2, 2, 5,  2, 2, 5,  0, 2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  2, 2, 5,  0, 2, 5,  0, 2, 5, -2, 2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5,  0, 2, 5, -2, 2, 5, -2, 2, 5, -4, 2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6,
  2, 5, -2, 2, 5, -4, 2, 5, -4, 2, 5, -6, 2, 5, -4, 2, 5, -6, 2, 5, -6, 2, 5, -8,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  2,15,  2, 1, 4,  0, 1, 4,  0, 1, 4, -2, 1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  1, 4,  0, 1, 4, -2, 1, 4, -2, 1, 4, -4, 1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  1, 4, -2, 1, 4, -4, 1, 4, -4, 1, 4, -6, 1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8,
  1, 4, -4, 1, 4, -6, 1, 4, -6, 1, 4, -8, 1, 4, -6, 1, 4, -8, 1, 4, -8, 1, 4,-10,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6, 1, 6, -4, 1, 6, -6, 1, 6, -6, 1, 6, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8, 0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8, 0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8, 0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8, 0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10,
  2,15,  2, 1,14,  0, 0, 3,  0, 0, 3, -2, 0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8, 0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10,
  0, 3,  0, 0, 3, -2, 0, 3, -2, 0, 3, -4, 0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8, 0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10,
  0, 3, -2, 0, 3, -4, 0, 3, -4, 0, 3, -6, 0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8,
  0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8, 0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10,
  0, 3, -4, 0, 3, -6, 0, 3, -6, 0, 3, -8, 0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10,
  0, 3, -6, 0, 3, -8, 0, 3, -8, 0, 3,-10, 0, 3, -8, 0, 3,-10, 0, 3,-10, 0, 3,-12,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6, 1, 6, -4, 1, 6, -6, 1, 6, -6, 1, 6, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8, 0, 5, -6, 0, 5, -8, 0, 5, -8, 0, 5,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6, 0, 7, -4, 0, 7, -6, 0, 7, -6, 0, 7, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6, 0, 7, -4, 0, 7, -6, 0, 7, -6, 0, 7, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
 10,15, 10, 9,14,  8, 8,13,  8, 8,13,  6, 8,15,  8, 7,12,  6, 7,12,  6, 7,12,  4,
  8,15,  8, 7,14,  6, 6,11,  6, 6,11,  4, 6,11,  6, 6,11,  4, 6,11,  4, 6,11,  2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2,
  6,15,  6, 5,10,  4, 5,10,  4, 5,10,  2, 5,10,  4, 5,10,  2, 5,10,  2, 5,10,  0,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  6,15,  6, 5,14,  4, 4, 9,  4, 4, 9,  2, 4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0,
  4, 9,  4, 4, 9,  2, 4, 9,  2, 4, 9,  0, 4, 9,  2, 4, 9,  0, 4, 9,  0, 4, 9, -2,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  4,15,  4, 3, 8,  2, 3, 8,  2, 3, 8,  0, 3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2,
  3, 8,  2, 3, 8,  0, 3, 8,  0, 3, 8, -2, 3, 8,  0, 3, 8, -2, 3, 8, -2, 3, 8, -4,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  4,15,  4, 3,14,  2, 2, 7,  2, 2, 7,  0, 2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  2, 2, 7,  0, 2, 7,  0, 2, 7, -2, 2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4,
  2, 7,  0, 2, 7, -2, 2, 7, -2, 2, 7, -4, 2, 7, -2, 2, 7, -4, 2, 7, -4, 2, 7, -6,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  2,15,  2, 1, 6,  0, 1, 6,  0, 1, 6, -2, 1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6,  0, 1, 6, -2, 1, 6, -2, 1, 6, -4, 1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6,
  1, 6, -2, 1, 6, -4, 1, 6, -4, 1, 6, -6, 1, 6, -4, 1, 6, -6, 1, 6, -6, 1, 6, -8,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  2,15,  2, 1,14,  0, 0, 5,  0, 0, 5, -2, 0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  0, 5,  0, 0, 5, -2, 0, 5, -2, 0, 5, -4, 0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  0, 5, -2, 0, 5, -4, 0, 5, -4, 0, 5, -6, 0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8,
  0, 5, -4, 0, 5, -6, 0, 5, -6, 0, 5, -8, 0, 5, -6, 0, 5, -8, 0, 5, -8, 0, 5,-10,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6, 0, 7, -4, 0, 7, -6, 0, 7, -6, 0, 7, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6, 0, 7, -4, 0, 7, -6, 0, 7, -6, 0, 7, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
  8,15,  8, 7,14,  6, 6,13,  6, 6,13,  4, 6,15,  6, 5,12,  4, 5,12,  4, 5,12,  2,
  6,15,  6, 5,14,  4, 4,11,  4, 4,11,  2, 4,11,  4, 4,11,  2, 4,11,  2, 4,11,  0,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0,
  4,15,  4, 3,10,  2, 3,10,  2, 3,10,  0, 3,10,  2, 3,10,  0, 3,10,  0, 3,10, -2,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  4,15,  4, 3,14,  2, 2, 9,  2, 2, 9,  0, 2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2,
  2, 9,  2, 2, 9,  0, 2, 9,  0, 2, 9, -2, 2, 9,  0, 2, 9, -2, 2, 9, -2, 2, 9, -4,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  2,15,  2, 1, 8,  0, 1, 8,  0, 1, 8, -2, 1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4,
  1, 8,  0, 1, 8, -2, 1, 8, -2, 1, 8, -4, 1, 8, -2, 1, 8, -4, 1, 8, -4, 1, 8, -6,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  2,15,  2, 1,14,  0, 0, 7,  0, 0, 7, -2, 0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7,  0, 0, 7, -2, 0, 7, -2, 0, 7, -4, 0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6,
  0, 7, -2, 0, 7, -4, 0, 7, -4, 0, 7, -6, 0, 7, -4, 0, 7, -6, 0, 7, -6, 0, 7, -8,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
  6,15,  6, 5,14,  4, 4,13,  4, 4,13,  2, 4,15,  4, 3,12,  2, 3,12,  2, 3,12,  0,
  4,15,  4, 3,14,  2, 2,11,  2, 2,11,  0, 2,11,  2, 2,11,  0, 2,11,  0, 2,11, -2,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2,
  2,15,  2, 1,10,  0, 1,10,  0, 1,10, -2, 1,10,  0, 1,10, -2, 1,10, -2, 1,10, -4,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  2,15,  2, 1,14,  0, 0, 9,  0, 0, 9, -2, 0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4,
  0, 9,  0, 0, 9, -2, 0, 9, -2, 0, 9, -4, 0, 9, -2, 0, 9, -4, 0, 9, -4, 0, 9, -6,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
  4,15,  4, 3,14,  2, 2,13,  2, 2,13,  0, 2,15,  2, 1,12,  0, 1,12,  0, 1,12, -2,
  2,15,  2, 1,14,  0, 0,11,  0, 0,11, -2, 0,11,  0, 0,11, -2, 0,11, -2, 0,11, -4,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
  2,15,  2, 1,14,  0, 0,13,  0, 0,13, -2, 0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
  0,15,  0,-1, 0, -2,-1, 0, -2,-1, 0, -4,-1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
 -1, 0, -2,-1, 0, -4,-1, 0, -4,-1, 0, -6,-1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
 -1, 0, -4,-1, 0, -6,-1, 0, -6,-1, 0, -8,-1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
 -1, 0, -6,-1, 0, -8,-1, 0, -8,-1, 0,-10,-1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
 -1, 0, -8,-1, 0,-10,-1, 0,-10,-1, 0,-12,-1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,
 -1, 0,-10,-1, 0,-12,-1, 0,-12,-1, 0,-14,-1, 0,-12,-1, 0,-14,-1, 0,-14,-1, 0,-16,
};   



static const UINT4 donor_gt_bits[] =
{0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x054,0x054,0x054,0x055,0x050,0x050,0x052,0x051,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x054,0x054,0x054,0x055,0x050,0x050,0x052,0x051,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x12A,0x129,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x12A,0x129,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x12A,0x129,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x14A,0x149,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x14A,0x149,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x14A,0x149,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x152,0x151,
 0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x152,0x151,
 0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x152,0x151,
 0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x154,0x154,0x154,0x155,0x150,0x150,0x152,0x151,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x142,0x141,
 0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x14A,0x149,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x142,0x141,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x122,0x121,
 0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x12A,0x129,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x122,0x121,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x112,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x112,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x102,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x10A,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x102,0x101,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x094,0x094,0x094,0x095,0x090,0x090,0x092,0x091,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x094,0x094,0x094,0x095,0x090,0x090,0x092,0x091,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x094,0x094,0x094,0x095,0x090,0x090,0x092,0x091,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A4,0x0A4,0x0A4,0x0A5,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A4,0x0A4,0x0A4,0x0A5,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A4,0x0A4,0x0A4,0x0A5,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,
 0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A4,0x0A4,0x0A4,0x0A5,0x0A0,0x0A0,0x0A2,0x0A1,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x092,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x094,0x094,0x094,0x095,0x090,0x090,0x092,0x091,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x082,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x08A,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x082,0x081,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x052,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x054,0x054,0x054,0x055,0x050,0x050,0x052,0x051,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x042,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x04A,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x042,0x041,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x022,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x02A,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x022,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x012,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x012,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x002,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x00A,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x002,0x001,
};


static const UINT4 donor_gtgc_bits[] =
{0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x154,0x155,0x154,0x155,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x154,0x155,0x154,0x155,0x150,0x151,0x152,0x151,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x154,0x155,0x154,0x155,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x154,0x155,0x154,0x155,0x150,0x151,0x152,0x151,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x154,0x155,0x154,0x155,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x154,0x155,0x154,0x155,0x150,0x151,0x152,0x151,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x154,0x155,0x154,0x155,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,
 0x150,0x151,0x150,0x151,0x150,0x151,0x152,0x151,0x154,0x155,0x154,0x155,0x150,0x151,0x152,0x151,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,0x148,0x149,0x148,0x149,0x148,0x149,0x14A,0x149,
 0x140,0x141,0x140,0x141,0x140,0x141,0x142,0x141,0x144,0x145,0x144,0x145,0x140,0x141,0x142,0x141,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,0x128,0x129,0x128,0x129,0x128,0x129,0x12A,0x129,
 0x120,0x121,0x120,0x121,0x120,0x121,0x122,0x121,0x124,0x125,0x124,0x125,0x120,0x121,0x122,0x121,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,
 0x110,0x111,0x110,0x111,0x110,0x111,0x112,0x111,0x114,0x115,0x114,0x115,0x110,0x111,0x112,0x111,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,0x108,0x109,0x108,0x109,0x108,0x109,0x10A,0x109,
 0x100,0x101,0x100,0x101,0x100,0x101,0x102,0x101,0x104,0x105,0x104,0x105,0x100,0x101,0x102,0x101,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0A8,0x0A9,0x0AA,0x0A9,
 0x0A0,0x0A1,0x0A0,0x0A1,0x0A0,0x0A1,0x0A2,0x0A1,0x0A4,0x0A5,0x0A4,0x0A5,0x0A0,0x0A1,0x0A2,0x0A1,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,
 0x090,0x091,0x090,0x091,0x090,0x091,0x092,0x091,0x094,0x095,0x094,0x095,0x090,0x091,0x092,0x091,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,0x088,0x089,0x088,0x089,0x088,0x089,0x08A,0x089,
 0x080,0x081,0x080,0x081,0x080,0x081,0x082,0x081,0x084,0x085,0x084,0x085,0x080,0x081,0x082,0x081,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,
 0x050,0x051,0x050,0x051,0x050,0x051,0x052,0x051,0x054,0x055,0x054,0x055,0x050,0x051,0x052,0x051,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,0x048,0x049,0x048,0x049,0x048,0x049,0x04A,0x049,
 0x040,0x041,0x040,0x041,0x040,0x041,0x042,0x041,0x044,0x045,0x044,0x045,0x040,0x041,0x042,0x041,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,0x028,0x029,0x028,0x029,0x028,0x029,0x02A,0x029,
 0x020,0x021,0x020,0x021,0x020,0x021,0x022,0x021,0x024,0x025,0x024,0x025,0x020,0x021,0x022,0x021,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,
 0x010,0x011,0x010,0x011,0x010,0x011,0x012,0x011,0x014,0x015,0x014,0x015,0x010,0x011,0x012,0x011,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
 0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,0x008,0x009,0x008,0x009,0x008,0x009,0x00A,0x009,
 0x000,0x001,0x000,0x001,0x000,0x001,0x002,0x001,0x004,0x005,0x004,0x005,0x000,0x001,0x002,0x001,
};

static const UINT4 acceptor_bits[] =
{0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x12A,0x128,0x129,0x128,0x128,0x128,0x129,0x128,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x12A,0x128,0x129,0x128,0x128,0x128,0x129,0x128,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x14A,0x148,0x149,0x148,0x148,0x148,0x149,0x148,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x14A,0x148,0x149,0x148,0x148,0x148,0x149,0x148,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x152,0x150,0x151,0x150,0x150,0x150,0x151,0x150,
 0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x152,0x150,0x151,0x150,0x150,0x150,0x151,0x150,
 0x154,0x154,0x155,0x154,0x150,0x150,0x151,0x150,0x152,0x150,0x151,0x150,0x150,0x150,0x151,0x150,
 0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x152,0x150,0x151,0x150,0x150,0x150,0x151,0x150,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x14A,0x148,0x149,0x148,0x148,0x148,0x149,0x148,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x14A,0x148,0x149,0x148,0x148,0x148,0x149,0x148,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x144,0x144,0x145,0x144,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,0x140,0x140,0x140,0x141,0x140,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x12A,0x128,0x129,0x128,0x128,0x128,0x129,0x128,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x12A,0x128,0x129,0x128,0x128,0x128,0x129,0x128,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x124,0x124,0x125,0x124,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,0x120,0x120,0x120,0x121,0x120,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x114,0x114,0x115,0x114,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,0x110,0x110,0x110,0x111,0x110,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,0x108,0x108,0x108,0x109,0x108,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x104,0x104,0x105,0x104,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,0x100,0x100,0x100,0x101,0x100,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x054,0x054,0x055,0x054,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x094,0x094,0x095,0x094,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x094,0x094,0x095,0x094,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A4,0x0A4,0x0A5,0x0A4,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A4,0x0A4,0x0A5,0x0A4,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0AA,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A4,0x0A4,0x0A5,0x0A4,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A4,0x0A4,0x0A5,0x0A4,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x094,0x094,0x095,0x094,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x094,0x094,0x095,0x094,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,0x090,0x090,0x090,0x091,0x090,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,0x088,0x088,0x088,0x089,0x088,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x084,0x084,0x085,0x084,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,0x080,0x080,0x080,0x081,0x080,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x054,0x054,0x055,0x054,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x054,0x054,0x055,0x054,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,0x050,0x050,0x050,0x051,0x050,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,0x048,0x048,0x048,0x049,0x048,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x044,0x044,0x045,0x044,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,0x040,0x040,0x040,0x041,0x040,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,0x028,0x028,0x028,0x029,0x028,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x024,0x024,0x025,0x024,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,0x020,0x020,0x020,0x021,0x020,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x014,0x014,0x015,0x014,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,0x010,0x010,0x010,0x011,0x010,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,0x008,0x008,0x008,0x009,0x008,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x004,0x004,0x005,0x004,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
 0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,0x000,0x000,0x000,0x001,0x000,
};


static const UINT4 antidonor_ac_bits[] =
{0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
};


static const UINT4 antidonor_acgc_bits[] =
{0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x152,0x150,0x154,0x155,0x154,0x154,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x152,0x150,0x154,0x155,0x154,0x154,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x152,0x150,0x154,0x155,0x154,0x154,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x152,0x150,0x154,0x155,0x154,0x154,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0AA,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0AA,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0AA,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0AA,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x052,0x050,0x054,0x055,0x054,0x054,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x052,0x050,0x054,0x055,0x054,0x054,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x052,0x050,0x054,0x055,0x054,0x054,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x052,0x050,0x054,0x055,0x054,0x054,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0AA,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0AA,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0AA,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A8,0x0A9,0x0A8,0x0A8,0x0AA,0x0A9,0x0AA,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A4,0x0A5,0x0A4,0x0A4,0x0A2,0x0A1,0x0A2,0x0A0,0x0A4,0x0A5,0x0A4,0x0A4,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x0A0,0x0A1,0x0A0,0x0A0,0x0A2,0x0A1,0x0A2,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x094,0x095,0x094,0x094,0x092,0x091,0x092,0x090,0x094,0x095,0x094,0x094,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x090,0x091,0x090,0x090,0x092,0x091,0x092,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x088,0x089,0x088,0x088,0x08A,0x089,0x08A,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x084,0x085,0x084,0x084,0x082,0x081,0x082,0x080,0x084,0x085,0x084,0x084,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x080,0x081,0x080,0x080,0x082,0x081,0x082,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x152,0x150,0x154,0x155,0x154,0x154,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x152,0x150,0x154,0x155,0x154,0x154,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x152,0x150,0x154,0x155,0x154,0x154,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x154,0x155,0x154,0x154,0x152,0x151,0x152,0x150,0x154,0x155,0x154,0x154,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x150,0x151,0x150,0x150,0x152,0x151,0x152,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x148,0x149,0x148,0x148,0x14A,0x149,0x14A,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x144,0x145,0x144,0x144,0x142,0x141,0x142,0x140,0x144,0x145,0x144,0x144,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x140,0x141,0x140,0x140,0x142,0x141,0x142,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x128,0x129,0x128,0x128,0x12A,0x129,0x12A,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x124,0x125,0x124,0x124,0x122,0x121,0x122,0x120,0x124,0x125,0x124,0x124,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x120,0x121,0x120,0x120,0x122,0x121,0x122,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x114,0x115,0x114,0x114,0x112,0x111,0x112,0x110,0x114,0x115,0x114,0x114,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x110,0x111,0x110,0x110,0x112,0x111,0x112,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x108,0x109,0x108,0x108,0x10A,0x109,0x10A,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x104,0x105,0x104,0x104,0x102,0x101,0x102,0x100,0x104,0x105,0x104,0x104,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x100,0x101,0x100,0x100,0x102,0x101,0x102,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x052,0x050,0x054,0x055,0x054,0x054,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x052,0x050,0x054,0x055,0x054,0x054,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x052,0x050,0x054,0x055,0x054,0x054,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x054,0x055,0x054,0x054,0x052,0x051,0x052,0x050,0x054,0x055,0x054,0x054,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x050,0x051,0x050,0x050,0x052,0x051,0x052,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x048,0x049,0x048,0x048,0x04A,0x049,0x04A,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x044,0x045,0x044,0x044,0x042,0x041,0x042,0x040,0x044,0x045,0x044,0x044,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x040,0x041,0x040,0x040,0x042,0x041,0x042,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x028,0x029,0x028,0x028,0x02A,0x029,0x02A,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x024,0x025,0x024,0x024,0x022,0x021,0x022,0x020,0x024,0x025,0x024,0x024,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x020,0x021,0x020,0x020,0x022,0x021,0x022,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x014,0x015,0x014,0x014,0x012,0x011,0x012,0x010,0x014,0x015,0x014,0x014,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x010,0x011,0x010,0x010,0x012,0x011,0x012,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x008,0x009,0x008,0x008,0x00A,0x009,0x00A,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x004,0x005,0x004,0x004,0x002,0x001,0x002,0x000,0x004,0x005,0x004,0x004,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
 0x000,0x001,0x000,0x000,0x002,0x001,0x002,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,
};

static const UINT4 antiacceptor_bits[] =
{0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x054,0x054,0x054,0x055,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x12A,0x128,0x129,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x12A,0x128,0x129,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x12A,0x128,0x129,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x14A,0x148,0x149,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x14A,0x148,0x149,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x14A,0x148,0x149,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x152,0x150,0x151,
 0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x152,0x150,0x151,
 0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x150,0x150,0x151,0x150,0x152,0x150,0x151,
 0x150,0x150,0x150,0x151,0x154,0x154,0x154,0x155,0x150,0x150,0x150,0x151,0x150,0x152,0x150,0x151,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x148,0x148,0x149,0x148,0x14A,0x148,0x149,
 0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x140,0x140,0x140,0x141,0x144,0x144,0x144,0x145,0x140,0x140,0x140,0x141,0x140,0x142,0x140,0x141,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x128,0x128,0x129,0x128,0x12A,0x128,0x129,
 0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x120,0x120,0x120,0x121,0x124,0x124,0x124,0x125,0x120,0x120,0x120,0x121,0x120,0x122,0x120,0x121,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x110,0x110,0x110,0x111,0x114,0x114,0x114,0x115,0x110,0x110,0x110,0x111,0x110,0x112,0x110,0x111,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x108,0x108,0x109,0x108,0x10A,0x108,0x109,
 0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x100,0x100,0x100,0x101,0x104,0x104,0x104,0x105,0x100,0x100,0x100,0x101,0x100,0x102,0x100,0x101,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x054,0x054,0x054,0x055,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x094,0x094,0x094,0x095,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x094,0x094,0x094,0x095,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x094,0x094,0x094,0x095,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A4,0x0A4,0x0A4,0x0A5,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A4,0x0A4,0x0A4,0x0A5,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A4,0x0A4,0x0A4,0x0A5,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0A8,0x0A8,0x0A9,0x0A8,0x0AA,0x0A8,0x0A9,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x0A0,0x0A0,0x0A0,0x0A1,0x0A4,0x0A4,0x0A4,0x0A5,0x0A0,0x0A0,0x0A0,0x0A1,0x0A0,0x0A2,0x0A0,0x0A1,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x090,0x090,0x090,0x091,0x094,0x094,0x094,0x095,0x090,0x090,0x090,0x091,0x090,0x092,0x090,0x091,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x088,0x088,0x089,0x088,0x08A,0x088,0x089,
 0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x080,0x080,0x080,0x081,0x084,0x084,0x084,0x085,0x080,0x080,0x080,0x081,0x080,0x082,0x080,0x081,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x050,0x050,0x050,0x051,0x054,0x054,0x054,0x055,0x050,0x050,0x050,0x051,0x050,0x052,0x050,0x051,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x048,0x048,0x049,0x048,0x04A,0x048,0x049,
 0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x040,0x040,0x040,0x041,0x044,0x044,0x044,0x045,0x040,0x040,0x040,0x041,0x040,0x042,0x040,0x041,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x028,0x028,0x029,0x028,0x02A,0x028,0x029,
 0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x020,0x020,0x020,0x021,0x024,0x024,0x024,0x025,0x020,0x020,0x020,0x021,0x020,0x022,0x020,0x021,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x010,0x010,0x010,0x011,0x014,0x014,0x014,0x015,0x010,0x010,0x010,0x011,0x010,0x012,0x010,0x011,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x008,0x008,0x009,0x008,0x00A,0x008,0x009,
 0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
 0x000,0x000,0x000,0x001,0x004,0x004,0x004,0x005,0x000,0x000,0x000,0x001,0x000,0x002,0x000,0x001,
};


static const UINT4 mark_a[] =
{0xFF,0xFE,0xFE,0xFE,0xFD,0xFC,0xFC,0xFC,0xFD,0xFC,0xFC,0xFC,0xFD,0xFC,0xFC,0xFC,
 0xFB,0xFA,0xFA,0xFA,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,
 0xFB,0xFA,0xFA,0xFA,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,
 0xFB,0xFA,0xFA,0xFA,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,
 0xF7,0xF6,0xF6,0xF6,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xF7,0xF6,0xF6,0xF6,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xF7,0xF6,0xF6,0xF6,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xF3,0xF2,0xF2,0xF2,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,
 0xEF,0xEE,0xEE,0xEE,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xEF,0xEE,0xEE,0xEE,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xEF,0xEE,0xEE,0xEE,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xEB,0xEA,0xEA,0xEA,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE7,0xE6,0xE6,0xE6,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xE3,0xE2,0xE2,0xE2,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,
 0xDF,0xDE,0xDE,0xDE,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xDF,0xDE,0xDE,0xDE,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xDF,0xDE,0xDE,0xDE,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xDB,0xDA,0xDA,0xDA,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD7,0xD6,0xD6,0xD6,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xD3,0xD2,0xD2,0xD2,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xCF,0xCE,0xCE,0xCE,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xCB,0xCA,0xCA,0xCA,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC7,0xC6,0xC6,0xC6,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xC3,0xC2,0xC2,0xC2,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,
 0xBF,0xBE,0xBE,0xBE,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0xBF,0xBE,0xBE,0xBE,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0xBF,0xBE,0xBE,0xBE,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xBB,0xBA,0xBA,0xBA,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB7,0xB6,0xB6,0xB6,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xB3,0xB2,0xB2,0xB2,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xAF,0xAE,0xAE,0xAE,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xAB,0xAA,0xAA,0xAA,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA7,0xA6,0xA6,0xA6,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0xA3,0xA2,0xA2,0xA2,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x9F,0x9E,0x9E,0x9E,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x9B,0x9A,0x9A,0x9A,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x97,0x96,0x96,0x96,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x93,0x92,0x92,0x92,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x8F,0x8E,0x8E,0x8E,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x8B,0x8A,0x8A,0x8A,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x87,0x86,0x86,0x86,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x83,0x82,0x82,0x82,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,
 0x7F,0x7E,0x7E,0x7E,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x7F,0x7E,0x7E,0x7E,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x7F,0x7E,0x7E,0x7E,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x7B,0x7A,0x7A,0x7A,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x77,0x76,0x76,0x76,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x73,0x72,0x72,0x72,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x6F,0x6E,0x6E,0x6E,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x6B,0x6A,0x6A,0x6A,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x67,0x66,0x66,0x66,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x63,0x62,0x62,0x62,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x5F,0x5E,0x5E,0x5E,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x5B,0x5A,0x5A,0x5A,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x57,0x56,0x56,0x56,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x53,0x52,0x52,0x52,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x4F,0x4E,0x4E,0x4E,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x4B,0x4A,0x4A,0x4A,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x47,0x46,0x46,0x46,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x43,0x42,0x42,0x42,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x3F,0x3E,0x3E,0x3E,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x3B,0x3A,0x3A,0x3A,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x37,0x36,0x36,0x36,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x33,0x32,0x32,0x32,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x2F,0x2E,0x2E,0x2E,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x2B,0x2A,0x2A,0x2A,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x27,0x26,0x26,0x26,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x23,0x22,0x22,0x22,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x1F,0x1E,0x1E,0x1E,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x1B,0x1A,0x1A,0x1A,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x17,0x16,0x16,0x16,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x13,0x12,0x12,0x12,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x0F,0x0E,0x0E,0x0E,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x0B,0x0A,0x0A,0x0A,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x07,0x06,0x06,0x06,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
 0x03,0x02,0x02,0x02,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
};

static const UINT4 mark_c[] =
{0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x7C,0x7D,0x7C,0x7C,0x7E,0x7F,0x7E,0x7E,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xBC,0xBD,0xBC,0xBC,0xBE,0xBF,0xBE,0xBE,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xDC,0xDD,0xDC,0xDC,0xDE,0xDF,0xDE,0xDE,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xEC,0xED,0xEC,0xEC,0xEE,0xEF,0xEE,0xEE,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xF4,0xF5,0xF4,0xF4,0xF6,0xF7,0xF6,0xF6,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xF8,0xF9,0xF8,0xF8,0xFA,0xFB,0xFA,0xFA,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,
 0xFC,0xFD,0xFC,0xFC,0xFE,0xFF,0xFE,0xFE,0xFC,0xFD,0xFC,0xFC,0xFC,0xFD,0xFC,0xFC,
 0xF8,0xF9,0xF8,0xF8,0xFA,0xFB,0xFA,0xFA,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,
 0xF8,0xF9,0xF8,0xF8,0xFA,0xFB,0xFA,0xFA,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xF4,0xF5,0xF4,0xF4,0xF6,0xF7,0xF6,0xF6,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xF4,0xF5,0xF4,0xF4,0xF6,0xF7,0xF6,0xF6,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xF0,0xF1,0xF0,0xF0,0xF2,0xF3,0xF2,0xF2,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xEC,0xED,0xEC,0xEC,0xEE,0xEF,0xEE,0xEE,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xEC,0xED,0xEC,0xEC,0xEE,0xEF,0xEE,0xEE,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xE8,0xE9,0xE8,0xE8,0xEA,0xEB,0xEA,0xEA,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE4,0xE5,0xE4,0xE4,0xE6,0xE7,0xE6,0xE6,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xE0,0xE1,0xE0,0xE0,0xE2,0xE3,0xE2,0xE2,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xDC,0xDD,0xDC,0xDC,0xDE,0xDF,0xDE,0xDE,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xDC,0xDD,0xDC,0xDC,0xDE,0xDF,0xDE,0xDE,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xD8,0xD9,0xD8,0xD8,0xDA,0xDB,0xDA,0xDA,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD4,0xD5,0xD4,0xD4,0xD6,0xD7,0xD6,0xD6,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xD0,0xD1,0xD0,0xD0,0xD2,0xD3,0xD2,0xD2,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xCC,0xCD,0xCC,0xCC,0xCE,0xCF,0xCE,0xCE,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC8,0xC9,0xC8,0xC8,0xCA,0xCB,0xCA,0xCA,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC4,0xC5,0xC4,0xC4,0xC6,0xC7,0xC6,0xC6,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0xC0,0xC1,0xC0,0xC0,0xC2,0xC3,0xC2,0xC2,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xBC,0xBD,0xBC,0xBC,0xBE,0xBF,0xBE,0xBE,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xBC,0xBD,0xBC,0xBC,0xBE,0xBF,0xBE,0xBE,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xB8,0xB9,0xB8,0xB8,0xBA,0xBB,0xBA,0xBA,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB4,0xB5,0xB4,0xB4,0xB6,0xB7,0xB6,0xB6,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xB0,0xB1,0xB0,0xB0,0xB2,0xB3,0xB2,0xB2,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xAC,0xAD,0xAC,0xAC,0xAE,0xAF,0xAE,0xAE,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA8,0xA9,0xA8,0xA8,0xAA,0xAB,0xAA,0xAA,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA4,0xA5,0xA4,0xA4,0xA6,0xA7,0xA6,0xA6,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0xA0,0xA1,0xA0,0xA0,0xA2,0xA3,0xA2,0xA2,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x9C,0x9D,0x9C,0x9C,0x9E,0x9F,0x9E,0x9E,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x98,0x99,0x98,0x98,0x9A,0x9B,0x9A,0x9A,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x94,0x95,0x94,0x94,0x96,0x97,0x96,0x96,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x90,0x91,0x90,0x90,0x92,0x93,0x92,0x92,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x8C,0x8D,0x8C,0x8C,0x8E,0x8F,0x8E,0x8E,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x88,0x89,0x88,0x88,0x8A,0x8B,0x8A,0x8A,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x84,0x85,0x84,0x84,0x86,0x87,0x86,0x86,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x80,0x81,0x80,0x80,0x82,0x83,0x82,0x82,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x7C,0x7D,0x7C,0x7C,0x7E,0x7F,0x7E,0x7E,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x7C,0x7D,0x7C,0x7C,0x7E,0x7F,0x7E,0x7E,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x78,0x79,0x78,0x78,0x7A,0x7B,0x7A,0x7A,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x74,0x75,0x74,0x74,0x76,0x77,0x76,0x76,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x70,0x71,0x70,0x70,0x72,0x73,0x72,0x72,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x6C,0x6D,0x6C,0x6C,0x6E,0x6F,0x6E,0x6E,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x68,0x69,0x68,0x68,0x6A,0x6B,0x6A,0x6A,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x64,0x65,0x64,0x64,0x66,0x67,0x66,0x66,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x60,0x61,0x60,0x60,0x62,0x63,0x62,0x62,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x5C,0x5D,0x5C,0x5C,0x5E,0x5F,0x5E,0x5E,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x58,0x59,0x58,0x58,0x5A,0x5B,0x5A,0x5A,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x54,0x55,0x54,0x54,0x56,0x57,0x56,0x56,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x50,0x51,0x50,0x50,0x52,0x53,0x52,0x52,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x4C,0x4D,0x4C,0x4C,0x4E,0x4F,0x4E,0x4E,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x48,0x49,0x48,0x48,0x4A,0x4B,0x4A,0x4A,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x44,0x45,0x44,0x44,0x46,0x47,0x46,0x46,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x40,0x41,0x40,0x40,0x42,0x43,0x42,0x42,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x3C,0x3D,0x3C,0x3C,0x3E,0x3F,0x3E,0x3E,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x38,0x39,0x38,0x38,0x3A,0x3B,0x3A,0x3A,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x34,0x35,0x34,0x34,0x36,0x37,0x36,0x36,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x30,0x31,0x30,0x30,0x32,0x33,0x32,0x32,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x2C,0x2D,0x2C,0x2C,0x2E,0x2F,0x2E,0x2E,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x28,0x29,0x28,0x28,0x2A,0x2B,0x2A,0x2A,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x24,0x25,0x24,0x24,0x26,0x27,0x26,0x26,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x20,0x21,0x20,0x20,0x22,0x23,0x22,0x22,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x1C,0x1D,0x1C,0x1C,0x1E,0x1F,0x1E,0x1E,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x18,0x19,0x18,0x18,0x1A,0x1B,0x1A,0x1A,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x14,0x15,0x14,0x14,0x16,0x17,0x16,0x16,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x10,0x11,0x10,0x10,0x12,0x13,0x12,0x12,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x0C,0x0D,0x0C,0x0C,0x0E,0x0F,0x0E,0x0E,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x08,0x09,0x08,0x08,0x0A,0x0B,0x0A,0x0A,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x04,0x05,0x04,0x04,0x06,0x07,0x06,0x06,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x01,0x00,0x00,0x02,0x03,0x02,0x02,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
};

static const UINT4 mark_g[] =
{0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7E,0x7E,0x7F,0x7E,0x7C,0x7C,0x7D,0x7C,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7E,0x7E,0x7F,0x7E,0x7C,0x7C,0x7D,0x7C,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBE,0xBE,0xBF,0xBE,0xBC,0xBC,0xBD,0xBC,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBE,0xBE,0xBF,0xBE,0xBC,0xBC,0xBD,0xBC,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDE,0xDE,0xDF,0xDE,0xDC,0xDC,0xDD,0xDC,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDE,0xDE,0xDF,0xDE,0xDC,0xDC,0xDD,0xDC,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEE,0xEE,0xEF,0xEE,0xEC,0xEC,0xED,0xEC,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEE,0xEE,0xEF,0xEE,0xEC,0xEC,0xED,0xEC,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF6,0xF6,0xF7,0xF6,0xF4,0xF4,0xF5,0xF4,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF6,0xF6,0xF7,0xF6,0xF4,0xF4,0xF5,0xF4,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xFA,0xFA,0xFB,0xFA,0xF8,0xF8,0xF9,0xF8,
 0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xFA,0xFA,0xFB,0xFA,0xF8,0xF8,0xF9,0xF8,
 0xFC,0xFC,0xFD,0xFC,0xFC,0xFC,0xFD,0xFC,0xFE,0xFE,0xFF,0xFE,0xFC,0xFC,0xFD,0xFC,
 0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xFA,0xFA,0xFB,0xFA,0xF8,0xF8,0xF9,0xF8,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF6,0xF6,0xF7,0xF6,0xF4,0xF4,0xF5,0xF4,
 0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF2,0xF2,0xF3,0xF2,0xF0,0xF0,0xF1,0xF0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEE,0xEE,0xEF,0xEE,0xEC,0xEC,0xED,0xEC,
 0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xEA,0xEA,0xEB,0xEA,0xE8,0xE8,0xE9,0xE8,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE6,0xE6,0xE7,0xE6,0xE4,0xE4,0xE5,0xE4,
 0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE2,0xE2,0xE3,0xE2,0xE0,0xE0,0xE1,0xE0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDE,0xDE,0xDF,0xDE,0xDC,0xDC,0xDD,0xDC,
 0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xDA,0xDA,0xDB,0xDA,0xD8,0xD8,0xD9,0xD8,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD6,0xD6,0xD7,0xD6,0xD4,0xD4,0xD5,0xD4,
 0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD2,0xD2,0xD3,0xD2,0xD0,0xD0,0xD1,0xD0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCE,0xCE,0xCF,0xCE,0xCC,0xCC,0xCD,0xCC,
 0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xCA,0xCA,0xCB,0xCA,0xC8,0xC8,0xC9,0xC8,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC6,0xC6,0xC7,0xC6,0xC4,0xC4,0xC5,0xC4,
 0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC2,0xC2,0xC3,0xC2,0xC0,0xC0,0xC1,0xC0,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBE,0xBE,0xBF,0xBE,0xBC,0xBC,0xBD,0xBC,
 0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xBA,0xBA,0xBB,0xBA,0xB8,0xB8,0xB9,0xB8,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB6,0xB6,0xB7,0xB6,0xB4,0xB4,0xB5,0xB4,
 0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB2,0xB2,0xB3,0xB2,0xB0,0xB0,0xB1,0xB0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAE,0xAE,0xAF,0xAE,0xAC,0xAC,0xAD,0xAC,
 0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xAA,0xAA,0xAB,0xAA,0xA8,0xA8,0xA9,0xA8,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA6,0xA6,0xA7,0xA6,0xA4,0xA4,0xA5,0xA4,
 0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA2,0xA2,0xA3,0xA2,0xA0,0xA0,0xA1,0xA0,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9E,0x9E,0x9F,0x9E,0x9C,0x9C,0x9D,0x9C,
 0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x9A,0x9A,0x9B,0x9A,0x98,0x98,0x99,0x98,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x96,0x96,0x97,0x96,0x94,0x94,0x95,0x94,
 0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x92,0x92,0x93,0x92,0x90,0x90,0x91,0x90,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8E,0x8E,0x8F,0x8E,0x8C,0x8C,0x8D,0x8C,
 0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x8A,0x8A,0x8B,0x8A,0x88,0x88,0x89,0x88,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x86,0x86,0x87,0x86,0x84,0x84,0x85,0x84,
 0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x82,0x82,0x83,0x82,0x80,0x80,0x81,0x80,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7E,0x7E,0x7F,0x7E,0x7C,0x7C,0x7D,0x7C,
 0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x7A,0x7A,0x7B,0x7A,0x78,0x78,0x79,0x78,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x76,0x76,0x77,0x76,0x74,0x74,0x75,0x74,
 0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x72,0x72,0x73,0x72,0x70,0x70,0x71,0x70,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6E,0x6E,0x6F,0x6E,0x6C,0x6C,0x6D,0x6C,
 0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x6A,0x6A,0x6B,0x6A,0x68,0x68,0x69,0x68,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x66,0x66,0x67,0x66,0x64,0x64,0x65,0x64,
 0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x62,0x62,0x63,0x62,0x60,0x60,0x61,0x60,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5E,0x5E,0x5F,0x5E,0x5C,0x5C,0x5D,0x5C,
 0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x5A,0x5A,0x5B,0x5A,0x58,0x58,0x59,0x58,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x56,0x56,0x57,0x56,0x54,0x54,0x55,0x54,
 0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x52,0x52,0x53,0x52,0x50,0x50,0x51,0x50,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4E,0x4E,0x4F,0x4E,0x4C,0x4C,0x4D,0x4C,
 0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x4A,0x4A,0x4B,0x4A,0x48,0x48,0x49,0x48,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x46,0x46,0x47,0x46,0x44,0x44,0x45,0x44,
 0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x42,0x42,0x43,0x42,0x40,0x40,0x41,0x40,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3E,0x3E,0x3F,0x3E,0x3C,0x3C,0x3D,0x3C,
 0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x3A,0x3A,0x3B,0x3A,0x38,0x38,0x39,0x38,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x36,0x36,0x37,0x36,0x34,0x34,0x35,0x34,
 0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x32,0x32,0x33,0x32,0x30,0x30,0x31,0x30,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2E,0x2E,0x2F,0x2E,0x2C,0x2C,0x2D,0x2C,
 0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x2A,0x2A,0x2B,0x2A,0x28,0x28,0x29,0x28,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x26,0x26,0x27,0x26,0x24,0x24,0x25,0x24,
 0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x22,0x22,0x23,0x22,0x20,0x20,0x21,0x20,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1E,0x1E,0x1F,0x1E,0x1C,0x1C,0x1D,0x1C,
 0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x1A,0x1A,0x1B,0x1A,0x18,0x18,0x19,0x18,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x16,0x16,0x17,0x16,0x14,0x14,0x15,0x14,
 0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x12,0x12,0x13,0x12,0x10,0x10,0x11,0x10,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0E,0x0E,0x0F,0x0E,0x0C,0x0C,0x0D,0x0C,
 0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x0A,0x0A,0x0B,0x0A,0x08,0x08,0x09,0x08,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
 0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x06,0x06,0x07,0x06,0x04,0x04,0x05,0x04,
 0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x02,0x02,0x03,0x02,0x00,0x00,0x01,0x00,
};

static const UINT4 mark_t[] =
{0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7E,0x7E,0x7E,0x7F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7E,0x7E,0x7E,0x7F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x02,0x02,0x02,0x03,
 0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x04,0x04,0x04,0x05,0x06,0x06,0x06,0x07,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x08,0x08,0x08,0x09,0x0A,0x0A,0x0A,0x0B,
 0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0C,0x0C,0x0C,0x0D,0x0E,0x0E,0x0E,0x0F,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x10,0x10,0x10,0x11,0x12,0x12,0x12,0x13,
 0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x14,0x14,0x14,0x15,0x16,0x16,0x16,0x17,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x18,0x18,0x18,0x19,0x1A,0x1A,0x1A,0x1B,
 0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1C,0x1C,0x1C,0x1D,0x1E,0x1E,0x1E,0x1F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x20,0x20,0x20,0x21,0x22,0x22,0x22,0x23,
 0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x24,0x24,0x24,0x25,0x26,0x26,0x26,0x27,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x28,0x28,0x28,0x29,0x2A,0x2A,0x2A,0x2B,
 0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2C,0x2C,0x2C,0x2D,0x2E,0x2E,0x2E,0x2F,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x30,0x30,0x30,0x31,0x32,0x32,0x32,0x33,
 0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x34,0x34,0x34,0x35,0x36,0x36,0x36,0x37,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x38,0x38,0x38,0x39,0x3A,0x3A,0x3A,0x3B,
 0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3C,0x3C,0x3C,0x3D,0x3E,0x3E,0x3E,0x3F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x40,0x40,0x40,0x41,0x42,0x42,0x42,0x43,
 0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x44,0x44,0x44,0x45,0x46,0x46,0x46,0x47,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x48,0x48,0x48,0x49,0x4A,0x4A,0x4A,0x4B,
 0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4C,0x4C,0x4C,0x4D,0x4E,0x4E,0x4E,0x4F,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x50,0x50,0x50,0x51,0x52,0x52,0x52,0x53,
 0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x54,0x54,0x54,0x55,0x56,0x56,0x56,0x57,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x58,0x58,0x58,0x59,0x5A,0x5A,0x5A,0x5B,
 0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5C,0x5C,0x5C,0x5D,0x5E,0x5E,0x5E,0x5F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x60,0x60,0x60,0x61,0x62,0x62,0x62,0x63,
 0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x64,0x64,0x64,0x65,0x66,0x66,0x66,0x67,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x68,0x68,0x68,0x69,0x6A,0x6A,0x6A,0x6B,
 0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6C,0x6C,0x6C,0x6D,0x6E,0x6E,0x6E,0x6F,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x70,0x70,0x70,0x71,0x72,0x72,0x72,0x73,
 0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x74,0x74,0x74,0x75,0x76,0x76,0x76,0x77,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x78,0x78,0x78,0x79,0x7A,0x7A,0x7A,0x7B,
 0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7C,0x7C,0x7C,0x7D,0x7E,0x7E,0x7E,0x7F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBE,0xBE,0xBE,0xBF,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBE,0xBE,0xBE,0xBF,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x80,0x80,0x80,0x81,0x82,0x82,0x82,0x83,
 0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x84,0x84,0x84,0x85,0x86,0x86,0x86,0x87,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x88,0x88,0x88,0x89,0x8A,0x8A,0x8A,0x8B,
 0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8C,0x8C,0x8C,0x8D,0x8E,0x8E,0x8E,0x8F,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x90,0x90,0x90,0x91,0x92,0x92,0x92,0x93,
 0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x94,0x94,0x94,0x95,0x96,0x96,0x96,0x97,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x98,0x98,0x98,0x99,0x9A,0x9A,0x9A,0x9B,
 0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9C,0x9C,0x9C,0x9D,0x9E,0x9E,0x9E,0x9F,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA0,0xA0,0xA0,0xA1,0xA2,0xA2,0xA2,0xA3,
 0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA4,0xA4,0xA4,0xA5,0xA6,0xA6,0xA6,0xA7,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xA8,0xA8,0xA8,0xA9,0xAA,0xAA,0xAA,0xAB,
 0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAC,0xAC,0xAC,0xAD,0xAE,0xAE,0xAE,0xAF,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB0,0xB0,0xB0,0xB1,0xB2,0xB2,0xB2,0xB3,
 0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB4,0xB4,0xB4,0xB5,0xB6,0xB6,0xB6,0xB7,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xB8,0xB8,0xB8,0xB9,0xBA,0xBA,0xBA,0xBB,
 0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBC,0xBC,0xBC,0xBD,0xBE,0xBE,0xBE,0xBF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDE,0xDE,0xDE,0xDF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDE,0xDE,0xDE,0xDF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC0,0xC0,0xC0,0xC1,0xC2,0xC2,0xC2,0xC3,
 0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC4,0xC4,0xC4,0xC5,0xC6,0xC6,0xC6,0xC7,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xC8,0xC8,0xC8,0xC9,0xCA,0xCA,0xCA,0xCB,
 0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCC,0xCC,0xCC,0xCD,0xCE,0xCE,0xCE,0xCF,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD0,0xD0,0xD0,0xD1,0xD2,0xD2,0xD2,0xD3,
 0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD4,0xD4,0xD4,0xD5,0xD6,0xD6,0xD6,0xD7,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xD8,0xD8,0xD8,0xD9,0xDA,0xDA,0xDA,0xDB,
 0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDC,0xDC,0xDC,0xDD,0xDE,0xDE,0xDE,0xDF,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEE,0xEE,0xEE,0xEF,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEE,0xEE,0xEE,0xEF,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE0,0xE0,0xE0,0xE1,0xE2,0xE2,0xE2,0xE3,
 0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE4,0xE4,0xE4,0xE5,0xE6,0xE6,0xE6,0xE7,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xE8,0xE8,0xE8,0xE9,0xEA,0xEA,0xEA,0xEB,
 0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEC,0xEC,0xEC,0xED,0xEE,0xEE,0xEE,0xEF,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF6,0xF6,0xF6,0xF7,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF6,0xF6,0xF6,0xF7,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF0,0xF0,0xF0,0xF1,0xF2,0xF2,0xF2,0xF3,
 0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF4,0xF4,0xF4,0xF5,0xF6,0xF6,0xF6,0xF7,
 0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xFA,0xFA,0xFA,0xFB,
 0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xFA,0xFA,0xFA,0xFB,
 0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xF8,0xF8,0xF8,0xF9,0xFA,0xFA,0xFA,0xFB,
 0xFC,0xFC,0xFC,0xFD,0xFC,0xFC,0xFC,0xFD,0xFC,0xFC,0xFC,0xFD,0xFE,0xFE,0xFE,0xFF,
}; 


/*** Indexdb code starts here.  Put here to access clz_table. ***/

/* Original code */
#if 0
if (ctr >= 32) {
  ctr -= 32;
  if (ctr == 0) {
    value = gamma;
    gamma = *++gptr;
  } else {
    value = gamma << ctr;
    gamma = *++gptr;
    value |= gamma >> (32 - ctr);
  }
 } else {
  value = gamma >> (32 - ctr);
 }
#endif



/* ctr is 0 at high bit and 31 at low bit */
int
Genome_read_gamma (unsigned int **ptr, int ctr, unsigned int *cum) {
  unsigned int gamma;
  unsigned int value;
#ifdef BRANCHLESS
  unsigned int ge32p, mask;
#endif
#ifdef HAVE_BUILTIN_CLZ
  unsigned int firstbit;
#elif defined(HAVE_ASM_BSR)
  unsigned int msb;
#else
  unsigned int top;
  unsigned int firstbit;
#endif

  debug3(printf("Entering read_gamma with ctr %d\n",ctr));
  gamma = **ptr & (~0U >> ctr);

  if (gamma == 0U) {
    ctr -= 32;
    gamma = *(++(*ptr));
  }

#ifdef HAVE_BUILTIN_CLZ
  firstbit = __builtin_clz(gamma);
  ctr = firstbit + firstbit - ctr /* + 1 */;
#elif defined(HAVE_ASM_BSR)
  asm("bsr %1,%0" : "=r"(msb) : "r"(gamma));
  ctr = 62 - msb - msb - ctr;
#else
  firstbit = ((top = gamma >> 16) ? clz_table[top] : 16 + clz_table[gamma]);
  ctr = firstbit + firstbit - ctr /* + 1 */;
#endif

#ifdef BRANCHLESS
  ctr += 1;
  ge32p = (ctr >> 5);	/* If ctr >= 32, ge32p = 1, else 0 */
  mask = -ge32p;	/* If ctr >= 32, all 1's, else all 0's */
  ctr &= 0xDF;		/* Subtracts 32 if necessary */
  value = (gamma << ctr) & mask; /* Keeps result only if ctr >= 32 */

  (*ptr) += ge32p;
  gamma ^= ((gamma ^ **ptr) & mask); /* Selects *gptr if mask is 1's, else keeps old gamma */

  /* Shift in two parts so it works when ctr originally 32, now 0 */
  value |= ((gamma >> 1) >> (31 - ctr));
#else
  if (ctr < 31) {
    value = gamma >> (31 - ctr);
    ctr++;
  } else {
    ctr -= 31;
    value = gamma << ctr;
    gamma = *(++(*ptr));
    /* Shift in two parts so it works for ctr == 32 => 0 */
    value |= ((gamma >> 1) >> (31 - ctr));
  }
#endif

  value -= 1;			/* To allow zero to be represented */

  *cum += value;

  return ctr;
}


/* In-lined read_gamma_function */
Positionsptr_T
Genome_offsetptr_from_gammas (Positionsptr_T *end0, UINT4 *gammaptrs, Positionsptr_T *offsetscomp,
			      unsigned int offsetscomp_blocksize, Storedoligomer_T oligo) {
  Positionsptr_T ptr0;
  unsigned int *gptr;
  unsigned int ctr;
#ifdef BRANCHLESS
  unsigned int ge32p, mask;
#endif
  unsigned int remainder, j;

  unsigned int gamma;
  unsigned int value;
#ifdef HAVE_BUILTIN_CLZ
  unsigned int firstbit;
#elif defined(HAVE_ASM_BSR)
  unsigned int msb;
#else
  unsigned int top;
  unsigned int firstbit;
#endif

  gptr = &(offsetscomp[gammaptrs[oligo/offsetscomp_blocksize]]);
  ptr0 = *gptr;

  ctr = 0;
  remainder = oligo % offsetscomp_blocksize;
  gamma = *++gptr;

  for (j = 0; j < remainder; j++) {
    if (gamma == 0U) {
      ctr -= 32;
      gamma = *++gptr;
    }

#ifdef HAVE_BUILTIN_CLZ
    firstbit = __builtin_clz(gamma);
    ctr = firstbit + firstbit - ctr /* + 1 */;
#elif defined(HAVE_ASM_BSR)
    asm("bsr %1,%0" : "=r"(msb) : "r"(gamma));
    ctr = 62 - msb - msb - ctr;
#else
    firstbit = ((top = gamma >> 16) ? clz_table[top] : 16 + clz_table[gamma]);
    ctr = firstbit + firstbit - ctr /* + 1 */;
#endif

#ifdef BRANCHLESS
    ctr += 1;
    ge32p = (ctr >> 5);	/* If ctr >= 32, ge32p = 1, else 0 */
    mask = -ge32p;	/* If ctr >= 32, all 1's, else all 0's */
    ctr &= 0xDF;		/* Subtracts 32 if necessary */
    value = (gamma << ctr) & mask; /* Keeps result only if ctr >= 32 */

    gptr += ge32p;
    gamma ^= ((gamma ^ *gptr) & mask); /* Selects *gptr if mask is 1's, else keeps old gamma */

    /* Shift in two parts so it works when ctr originally 32, now 0 */
    value |= ((gamma >> 1) >> (31 - ctr));
#else
    if (ctr < 31) {
      value = gamma >> (31 - ctr);
      ctr++;
    } else {
      ctr -= 31;
      value = gamma << ctr;
      gamma = *++gptr;
      /* Shift in two parts so it works for ctr == 32 => 0 */
      value |= ((gamma >> 1) >> (31 - ctr));
    }
#endif

    gamma &= (~0U >> ctr);

#if 0
    /* Just subtract remainder at end */
    value -= 1;			/* To allow zero to be represented */
#endif

    ptr0 += value;
  }

  ptr0 -= remainder;		/* Makes up for each 1-increment to value */


  /* Compute end0 */
  if (remainder == offsetscomp_blocksize - 1) {
    if (ctr > 0) {
      /* Happens only with large integers, but if ctr == 0, we have advanced already */
      gptr++;			/* Done with last gamma byte */
    }
    *end0 = *gptr;

    assert(*end0 == offsetscomp[gammaptrs[oligo/offsetscomp_blocksize + 1]]);

  } else {
    /* Decode one more value */
    if (gamma == 0U) {
      ctr -= 32;
      gamma = *++gptr;
    }

#ifdef HAVE_BUILTIN_CLZ
    firstbit = __builtin_clz(gamma);
    ctr = firstbit + firstbit - ctr /* + 1 */;
#elif defined(HAVE_ASM_BSR)
    asm("bsr %1,%0" : "=r"(msb) : "r"(gamma));
    ctr = 62 - msb - msb - ctr;
#else
    firstbit = ((top = gamma >> 16) ? clz_table[top] : 16 + clz_table[gamma]);
    ctr = firstbit + firstbit - ctr /* + 1 */;
#endif

#ifdef BRANCHLESS
    ctr += 1;
    ge32p = (ctr >> 5);	/* If ctr >= 32, ge32p = 1, else 0 */
    mask = -ge32p;	/* If ctr >= 32, all 1's, else all 0's */
    ctr &= 0xDF;		/* Subtracts 32 if necessary */
    value = (gamma << ctr) & mask; /* Keeps result only if ctr >= 32 */

    gptr += ge32p;
    gamma ^= ((gamma ^ *gptr) & mask); /* Selects *gptr if mask is 1's, else keeps old gamma */

    /* Shift in two parts so it works when ctr originally 32, now 0 */
    value |= ((gamma >> 1) >> (31 - ctr));
#else
    if (ctr < 31) {
      value = gamma >> (31 - ctr);
      ctr++;
    } else {
      ctr -= 31;
      value = gamma << ctr;
      gamma = *++gptr;
      /* Shift in two parts so it works for ctr == 32 => 0 */
      value |= ((gamma >> 1) >> (31 - ctr));
    }
#endif

    /* gamma &= (~0U >> ctr); -- gamma not needed past end0 */

    value -= 1;			/* To allow zero to be represented */

    *end0 = ptr0 + value;
  }

  return ptr0;
}

Positionsptr_T
Genome_offsetptr_only_from_gammas (UINT4 *gammaptrs, Positionsptr_T *offsetscomp,
				   unsigned int offsetscomp_blocksize, Storedoligomer_T oligo) {
  Positionsptr_T ptr0;
  unsigned int *gptr;
  unsigned int ctr;
#ifdef BRANCHLESS
  unsigned int ge32p, mask;
#endif
  unsigned int remainder, j;

  unsigned int gamma;
  unsigned int value;
#ifdef HAVE_BUILTIN_CLZ
  unsigned int firstbit;
#elif defined(HAVE_ASM_BSR)
  unsigned int msb;
#else
  unsigned int top;
  unsigned int firstbit;
#endif

  gptr = &(offsetscomp[gammaptrs[oligo/offsetscomp_blocksize]]);
  ptr0 = *gptr;

  if ((remainder = oligo % offsetscomp_blocksize) > 0) {
    ctr = 0;
    gamma = *++gptr;

    for (j = 0; j < remainder; j++) {
      if (gamma == 0U) {
	ctr -= 32;
	gamma = *++gptr;
      }

#ifdef HAVE_BUILTIN_CLZ
      firstbit = __builtin_clz(gamma);
      ctr = firstbit + firstbit - ctr /* + 1 */;
#elif defined(HAVE_ASM_BSR)
      asm("bsr %1,%0" : "=r"(msb) : "r"(gamma));
      ctr = 62 - msb - msb - ctr;
#else
      firstbit = ((top = gamma >> 16) ? clz_table[top] : 16 + clz_table[gamma]);
      ctr = firstbit + firstbit - ctr /* + 1 */;
#endif

#ifdef BRANCHLESS
      ctr += 1;
      ge32p = (ctr >> 5);    /* If ctr >= 32, ge32p = 1, else 0 */
      mask = -ge32p;	     /* If ctr >= 32, all 1's, else all 0's */
      ctr &= 0xDF;	     /* Subtracts 32 if necessary */
      value = (gamma << ctr) & mask; /* Keeps result only if ctr >= 32 */

      gptr += ge32p;
      gamma ^= ((gamma ^ *gptr) & mask); /* Selects *gptr if mask is 1's, else keeps old gamma */

      /* Shift in two parts so it works when ctr originally 32, now 0 */
      value |= ((gamma >> 1) >> (31 - ctr));
#else
      if (ctr < 31) {
	value = gamma >> (31 - ctr);
	ctr++;
      } else {
	ctr -= 31;
	value = gamma << ctr;
	gamma = *++gptr;
	/* Shift in two parts so it works for ctr == 32 => 0 */
	value |= ((gamma >> 1) >> (31 - ctr));
      }
#endif

      gamma &= (~0U >> ctr);

#if 0
      /* Just subtract remainder at end */
      value -= 1;			/* To allow zero to be represented */
#endif

      ptr0 += value;
    }

    ptr0 -= remainder;		/* Makes up for each 1-increment to value */
  }

  return ptr0;
}



#ifdef WORDS_BIGENDIAN
/* ctr is 0 at high bit and 31 at low bit */
int
Genome_read_gamma_bigendian (unsigned int **ptr, int ctr, unsigned int *cum) {
  unsigned int gamma;
  unsigned int value;
#ifdef HAVE_BUILTIN_CLZ
  unsigned int firstbit;
#elif defined(HAVE_ASM_BSR)
  unsigned int msb;
#else
  unsigned int top;
  unsigned int firstbit;
#endif

  debug3(printf("Entering read_gamma with ctr %d\n",ctr));
  gamma = Bigendian_convert_uint(**ptr) & (~0U >> ctr);
  debug3(printf("buffer is now %08X\n",gamma));

  while (gamma == 0U) {
    ctr -= 32;
    gamma = Bigendian_convert_uint(*(++(*ptr)));
    debug3(printf("new gamma %08X\n",gamma));
  }

#ifdef HAVE_BUILTIN_CLZ
  firstbit = __builtin_clz(gamma);
  ctr = firstbit + firstbit - ctr /* + 1 */;
#elif defined(HAVE_ASM_BSR)
  asm("bsr %1,%0" : "=r"(msb) : "r"(gamma));
  ctr = 62 - msb - msb - ctr;
#else
  firstbit = ((top = gamma >> 16) ? clz_table[top] : 16 + clz_table[gamma]);
  ctr = firstbit + firstbit - ctr /* + 1 */;
#endif

  if (ctr < 31) {
    value = gamma >> (31 - ctr);
    ctr++;
  } else {
    ctr -= 31;
    value = gamma << ctr;
    gamma = Bigendian_convert_uint(*(++(*ptr)));
    /* Shift in two parts so it works for ctr == 32 => 0 */
    value |= ((gamma >> 1) >> (31 - ctr));
  }

  value -= 1;			/* To allow zero to be represented */

  *cum += value;

  return ctr;
}


/* In-lined read_gamma_function */
Positionsptr_T
Genome_offsetptr_from_gammas_bigendian (Positionsptr_T *end0, UINT4 *gammaptrs, Positionsptr_T *offsetscomp,
					unsigned int offsetscomp_blocksize, Storedoligomer_T oligo) {
  Positionsptr_T ptr0;
  unsigned int *gptr;
  unsigned int ctr;
  unsigned int remainder, j;

  unsigned int gamma;
  unsigned int value;
#ifdef HAVE_BUILTIN_CLZ
  unsigned int firstbit;
#elif defined(HAVE_ASM_BSR)
  unsigned int msb;
#else
  unsigned int top;
  unsigned int firstbit;
#endif

  gptr = &(offsetscomp[gammaptrs[oligo/offsetscomp_blocksize]]);
  ptr0 = Bigendian_convert_uint(*gptr);

  ctr = 0;
  remainder = oligo % offsetscomp_blocksize;
  gamma = Bigendian_convert_uint(*++gptr);

  for (j = 0; j < remainder; j++) {
    if (gamma == 0U) {
      ctr -= 32;
      gamma = Bigendian_convert_uint(*++gptr);
    }

#ifdef HAVE_BUILTIN_CLZ
    firstbit = __builtin_clz(gamma);
    ctr = firstbit + firstbit - ctr /* + 1 */;
#elif defined(HAVE_ASM_BSR)
    asm("bsr %1,%0" : "=r"(msb) : "r"(gamma));
    ctr = 62 - msb - msb - ctr;
#else
    firstbit = ((top = gamma >> 16) ? clz_table[top] : 16 + clz_table[gamma]);
    ctr = firstbit + firstbit - ctr /* + 1 */;
#endif

    if (ctr < 31) {
      value = gamma >> (31 - ctr);
      ctr++;
    } else {
      ctr -= 31;
      value = gamma << ctr;
      gamma = Bigendian_convert_uint(*++gptr);
      /* Shift in two parts so it works for ctr == 32 => 0 */
      value |= ((gamma >> 1) >> (31 - ctr));
    }

    gamma &= (~0U >> ctr);

#if 0
    /* Just subtract remainder at end */
    value -= 1;			/* To allow zero to be represented */
#endif

    ptr0 += value;
  }

  ptr0 -= remainder;		/* Makes up for each 1-increment to value */


  /* Compute end0 */
  if (remainder == offsetscomp_blocksize - 1) {
    if (ctr > 0) {
      /* Happens only with large integers, but if ctr == 0, we have advanced already */
      gptr++;			/* Done with last gamma byte */
    }
    *end0 = Bigendian_convert_uint(*gptr);

    /* assert(*end0 == offsetscomp[gammaptrs[oligo/offsetscomp_blocksize + 1]]); */

  } else {
    /* Decode one more value */
    if (gamma == 0U) {
      ctr -= 32;
      gamma = Bigendian_convert_uint(*++gptr);
    }

#ifdef HAVE_BUILTIN_CLZ
    firstbit = __builtin_clz(gamma);
    ctr = firstbit + firstbit - ctr /* + 1 */;
#elif defined(HAVE_ASM_BSR)
    asm("bsr %1,%0" : "=r"(msb) : "r"(gamma));
    ctr = 62 - msb - msb - ctr;
#else
    firstbit = ((top = gamma >> 16) ? clz_table[top] : 16 + clz_table[gamma]);
    ctr = firstbit + firstbit - ctr /* + 1 */;
#endif

    if (ctr < 31) {
      value = gamma >> (31 - ctr);
      ctr++;
    } else {
      ctr -= 31;
      value = gamma << ctr;
      gamma = Bigendian_convert_uint(*++gptr);
      /* Shift in two parts so it works for ctr == 32 => 0 */
      value |= ((gamma >> 1) >> (31 - ctr));
    }

    /* gamma &= (~0U >> ctr); -- gamma not needed past end0 */

    value -= 1;			/* To allow zero to be represented */

    *end0 = ptr0 + value;
  }

  return ptr0;
}


Positionsptr_T
Genome_offsetptr_only_from_gammas_bigendian (UINT4 *gammaptrs, Positionsptr_T *offsetscomp,
					     unsigned int offsetscomp_blocksize, Storedoligomer_T oligo) {
  Positionsptr_T ptr0;
  unsigned int *gptr;
  unsigned int ctr;
  unsigned int remainder, j;

  unsigned int gamma;
  unsigned int value;
#ifdef HAVE_BUILTIN_CLZ
  unsigned int firstbit;
#elif defined(HAVE_ASM_BSR)
  unsigned int msb;
#else
  unsigned int top;
  unsigned int firstbit;
#endif

  gptr = &(offsetscomp[gammaptrs[oligo/offsetscomp_blocksize]]);
  ptr0 = Bigendian_convert_uint(*gptr);

  if ((remainder = oligo % offsetscomp_blocksize) > 0) {
    ctr = 0;
    gamma = Bigendian_convert_uint(*++gptr);

    for (j = 0; j < remainder; j++) {
      if (gamma == 0U) {
	ctr -= 32;
	gamma = Bigendian_convert_uint(*++gptr);
      }

#ifdef HAVE_BUILTIN_CLZ
      firstbit = __builtin_clz(gamma);
      ctr = firstbit + firstbit - ctr /* + 1 */;
#elif defined(HAVE_ASM_BSR)
      asm("bsr %1,%0" : "=r"(msb) : "r"(gamma));
      ctr = 62 - msb - msb - ctr;
#else
      firstbit = ((top = gamma >> 16) ? clz_table[top] : 16 + clz_table[gamma]);
      ctr = firstbit + firstbit - ctr /* + 1 */;
#endif

      if (ctr < 31) {
	value = gamma >> (31 - ctr);
	ctr++;
      } else {
	ctr -= 31;
	value = gamma << ctr;
	gamma = Bigendian_convert_uint(*++gptr);
	/* Shift in two parts so it works for ctr == 32 => 0 */
	value |= ((gamma >> 1) >> (31 - ctr));
      }

      gamma &= (~0U >> ctr);

#if 0
      /* Just subtract remainder at end */
      value -= 1;			/* To allow zero to be represented */
#endif

      ptr0 += value;
    }

    ptr0 -= remainder;		/* Makes up for each 1-increment to value */
  }

  return ptr0;
}
#endif


/* Genome_hr code starts here */


#ifdef GSNAP

static Storedoligomer_T
convert_mark_a (Storedoligomer_T high, Storedoligomer_T low) {
  Storedoligomer_T mark;

  mark = (mark_a[high >> 16] << 24);
  mark |= mark_a[high & 0x0000FFFF] << 16;
  mark |= mark_a[low >> 16] << 8;
  mark |= mark_a[low & 0x0000FFFF];
  return mark;
}

static Storedoligomer_T
convert_mark_c (Storedoligomer_T high, Storedoligomer_T low) {
  Storedoligomer_T mark;

  mark = (mark_c[high >> 16] << 24);
  mark |= mark_c[high & 0x0000FFFF] << 16;
  mark |= mark_c[low >> 16] << 8;
  mark |= mark_c[low & 0x0000FFFF];
  return mark;
}

static Storedoligomer_T
convert_mark_g (Storedoligomer_T high, Storedoligomer_T low) {
  Storedoligomer_T mark;

  mark = (mark_g[high >> 16] << 24);
  mark |= mark_g[high & 0x0000FFFF] << 16;
  mark |= mark_g[low >> 16] << 8;
  mark |= mark_g[low & 0x0000FFFF];
  return mark;
}

static Storedoligomer_T
convert_mark_t (Storedoligomer_T high, Storedoligomer_T low) {
  Storedoligomer_T mark;

  mark = (mark_t[high >> 16] << 24);
  mark |= mark_t[high & 0x0000FFFF] << 16;
  mark |= mark_t[low >> 16] << 8;
  mark |= mark_t[low & 0x0000FFFF];
  return mark;
}

#endif


#if 0
static int
popcount_run (UINT4 *lastbit, int count, UINT4 diff) {
  UINT4 bit;
  int i;

  for (i = 0; i < 32; i++) {
    bit = diff & 1U;
    count += *lastbit & bit;
    diff >>= 1;
    *lastbit = bit;
  }

  return count;
}
#endif


static void
write_chars (UINT4 high, UINT4 low, UINT4 flags) {
  char Buffer[33];
  int i;

  Buffer[32] = '\0';
  /* printf("%08X %08X %08X => ",high,low,flags); */
  for (i = 0; i < 16; i++) {
    switch (low & 3U) {
    case 0U: Buffer[i] = 'A'; break;
    case 1U: Buffer[i] = 'C'; break;
    case 2U: Buffer[i] = 'G'; break;
    case 3U: Buffer[i] = 'T'; break;
    default: abort();
    }
    low >>= 2;
  }
  for ( ; i < 32; i++) {
    switch (high & 3U) {
    case 0U: Buffer[i] = 'A'; break;
    case 1U: Buffer[i] = 'C'; break;
    case 2U: Buffer[i] = 'G'; break;
    case 3U: Buffer[i] = 'T'; break;
    default: abort();
    }
    high >>= 2;
  }
  for (i = 0; i < 32; i++) {
    if ((flags & 1U) == 1U) {
      Buffer[i] = 'N';
    }
    flags >>= 1;
  }

  printf("%s",Buffer);
  return;
}


#ifdef DEBUG
static void
print_blocks (UINT4 *blocks, int nblocks) {
  int ptr = 0;

  while (ptr < nblocks*3) {
    printf("high: %08X  low: %08X  flags: %08X\t",
	   blocks[ptr],blocks[ptr+1],blocks[ptr+2]);
    write_chars(blocks[ptr],blocks[ptr+1],blocks[ptr+2]);
    printf("\n");
    ptr += 3;
  }
  printf("\n");
  return;
}
#endif


static void
Genome_print_blocks (UINT4 *blocks, Genomicpos_T startpos, Genomicpos_T endpos) {
  /* Genomicpos_T length = endpos - startpos; */
  Genomicpos_T startblock, endblock, startdiscard, enddiscard, ptr;
  UINT4 high, low, flags;

  /* sequence = (char *) CALLOC(length+1,sizeof(char)); */

  ptr = startblock = startpos/32U*3;
  endblock = endpos/32U*3;
  startdiscard = startpos % 32;
  enddiscard = endpos % 32;
  
  for (ptr = startblock ; ptr <= endblock; ptr += 3) {
#ifdef WORDS_BIGENDIAN
    high = Bigendian_convert_uint(blocks[ptr]);
    low = Bigendian_convert_uint(blocks[ptr+1]);
    flags = Bigendian_convert_uint(blocks[ptr+2]);
#else
    high = blocks[ptr]; low = blocks[ptr+1]; flags = blocks[ptr+2];
#endif
    printf("high: %08X  low: %08X  flags: %08X\t",high,low,flags);
    write_chars(high,low,flags);
    printf("\n");
  }

  return;
}

#ifdef DEBUG
static void
Genome_print_blocks_snp (UINT4 *blocks, UINT4 *snp_blocks, Genomicpos_T startpos, Genomicpos_T endpos) {
  /* Genomicpos_T length = endpos - startpos; */
  Genomicpos_T startblock, endblock, startdiscard, enddiscard, ptr;
  UINT4 high, low, flags, snpmask;

  /* sequence = (char *) CALLOC(length+1,sizeof(char)); */

  ptr = startblock = startpos/32U*3;
  endblock = endpos/32U*3;
  startdiscard = startpos % 32;
  enddiscard = endpos % 32;
  
  for (ptr = startblock ; ptr <= endblock; ptr += 3) {
#ifdef WORDS_BIGENDIAN
    high = Bigendian_convert_uint(blocks[ptr]);
    low = Bigendian_convert_uint(blocks[ptr+1]);
    flags = Bigendian_convert_uint(blocks[ptr+2]);
    snpmask = Bigendian_convert_uint(snp_blocks[ptr+2]);
#else
    high = blocks[ptr]; low = blocks[ptr+1]; flags = blocks[ptr+2]; snpmask = snp_blocks[ptr+2];
#endif
    printf("high: %08X  low: %08X  flags: %08X  snpmask: %08X\n",high,low,flags,snpmask);
  }

  return;
}
#endif


static UINT4 *ref_blocks;
static UINT4 *snp_blocks;


/* Note: not currently called by any procedure */
#if 0
int
Genome_count_mismatches (Compress_T query_compress, Genomicpos_T left, Genomicpos_T left_plus_length) {
  int nmismatches;
  Genomicpos_T startdiscard, enddiscard;
  UINT4 *startblock, *endblock, *ptr;
  UINT4 *query_shifted;
  UINT4 diff, compare;
  int nshift, i, k = 0;

  debug(
	printf("\n\n");
	printf("Genome (in Genome_count_mismatches) from %u to %u:\n",left,left_plus_length);
	Genome_print_blocks(ref_blocks,left,left_plus_length);
	printf("\n");
	);

  ptr = startblock = &(ref_blocks[left/32U*3]); /*(left+pos5)/32U*3 */
  endblock = &(ref_blocks[left_plus_length/32U*3]); /* (left+pos3)/32U*3 */
  startdiscard = left % 32; /* (left+pos5) % 32 */
  enddiscard = left_plus_length % 32; /* (left+pos3) % 32 */
  
  nshift = left % 32;
  query_shifted = Compress_shift(query_compress,nshift);
#if 0
  /* Not needed if pos5 is 0, since nshift < 32, so nshift/32U*3 = 0 */
  query_shifted = &(query_shifted[nshift/32U*3]); /* (nshift+pos5)/32U*3 */
#endif

  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));

  /* Initial: High */
  debug(printf("comparing high: %08X with %08X, ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
  compare = (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
  compare = (*query_shifted++) ^ (*ptr++);
#endif
  debug(printf("adding %08X and %08X to diff\n",
	       reduce_nt[compare & 0x0000FFFF] << 16,reduce_nt[compare >> 16] << 24));
  diff = (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;

  /* Initial: Low */
  debug(printf("comparing low: %08X with %08X, ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
  compare = (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
  compare = (*query_shifted++) ^ (*ptr++);
#endif
  debug(printf("adding %08X and %08X to diff\n",
	       reduce_nt[compare & 0x0000FFFF],reduce_nt[compare >> 16] << 8));

  diff |= reduce_nt[compare >> 16] << 8;
  diff |= reduce_nt[compare & 0x0000FFFF];

  /* Initial: Flags */
  debug(printf("comparing flags: %08X with %08X, yielding",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
  diff |= (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
  diff |= (*query_shifted++) ^ (*ptr++);
#endif
  debug(printf(" %08X\n",diff));

  if (startblock == endblock) {
    /* Mask both */
    diff &= (~0U << startdiscard);
    diff &= ~(~0U << enddiscard);
    debug(printf("adding masks %08X and %08x = %08X\n",
		 ~0U << startdiscard,~(~0U << enddiscard),(~0U << startdiscard) & ~(~0U << enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
    nmismatches = __builtin_popcount(diff);
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
#else
    nmismatches = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		 diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		 diff >> 16,count_bits[diff >> 16]));
#endif

  } else {
    /* Mask startdiscard */
    diff &= (~0U << startdiscard);
    debug(printf("adding start mask %08X\n",~0U << startdiscard));

#ifdef HAVE_BUILTIN_POPCOUNT
    nmismatches = __builtin_popcount(diff);
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
#else
    nmismatches = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		diff >> 16,count_bits[diff >> 16]));
#endif

    while (ptr < endblock) {
      /* Middle: High */
      debug(printf("comparing high: %08X with %08X, ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
      compare = (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
      compare = (*query_shifted++) ^ (*ptr++);
#endif
      debug(printf("adding %08X and %08X to diff\n",
		   reduce_nt[compare & 0x0000FFFF] << 16,reduce_nt[compare >> 16] << 24));
      diff = (reduce_nt[compare >> 16] << 24);
      diff |= reduce_nt[compare & 0x0000FFFF] << 16;

      /* Middle: Low */
      debug(printf("comparing low: %08X with %08X, ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
      compare = (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
      compare = (*query_shifted++) ^ (*ptr++);
#endif
      debug(printf("adding %08X and %08X to diff\n",
		   reduce_nt[compare & 0x0000FFFF],reduce_nt[compare >> 16] << 8));
      diff |= reduce_nt[compare >> 16] << 8;
      diff |= reduce_nt[compare & 0x0000FFFF];

      /* Middle: Flags */
      debug(printf("comparing flags: %08X with %08X, yielding",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
      diff |= (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
      diff |= (*query_shifted++) ^ (*ptr++);
#endif
      debug(printf(" %08X\n",diff));

#ifdef HAVE_BUILTIN_POPCOUNT
      nmismatches += __builtin_popcount(diff);
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
#else
      nmismatches += count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
#endif
    }

    /* Final: High */
    debug(printf("comparing high: %08X with %08X, ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
    compare = (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
    compare = (*query_shifted++) ^ (*ptr++);
#endif
    debug(printf("adding %08X and %08X to diff\n",
		 reduce_nt[compare & 0x0000FFFF] << 16,reduce_nt[compare >> 16] << 24));
    diff = (reduce_nt[compare >> 16] << 24);
    diff |= reduce_nt[compare & 0x0000FFFF] << 16;

    /* Final: Low */
    debug(printf("comparing low: %08X with %08X, ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
    compare = (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
    compare = (*query_shifted++) ^ (*ptr++);
#endif
    debug(printf("adding %08X and %08X to diff\n",
		 reduce_nt[compare & 0x0000FFFF],reduce_nt[compare >> 16] << 8));
    diff |= reduce_nt[compare >> 16] << 8;
    diff |= reduce_nt[compare & 0x0000FFFF];

    /* Final: Flags */
    debug(printf("comparing flags: %08X with %08X, yielding",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
    diff |= (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
    diff |= (*query_shifted++) ^ (*ptr++);
#endif
    debug(printf(" %08X\n",diff));

    /* Mask enddiscard */
    diff &= ~(~0U << enddiscard);
    debug(printf("adding end mask %08x\n",~(~0U << enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
    nmismatches += __builtin_popcount(diff);
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
#else
    nmismatches += count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		diff >> 16,count_bits[diff >> 16]));
#endif
  }

  return nmismatches;
}
#endif



static bool query_unk_mismatch_p = true;
static bool genome_unk_mismatch_p = true;


static UINT4
block_diff_standard (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* High */
  debug(printf("Comparing high: query %08X with genome %08X ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
  compare = (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
  compare = (*query_shifted++) ^ (*ptr++);
#endif
  diff = (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X with genome %08X ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
  compare = (*query_shifted++) ^ Bigendian_convert_uint(*ptr++);
#else
  compare = (*query_shifted++) ^ (*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));


  /* Flags: Considering N as a mismatch */
  if (query_unk_mismatch_p) {
    debug(printf("Marking query flags: query %08X ",*query_shifted));
    diff |= (*query_shifted);
  } else {
    debug(printf("Clearing query flags: query %08X ",*query_shifted));
    diff &= ~(*query_shifted);
  }

  if (genome_unk_mismatch_p) {
    debug(printf("Marking genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff |= Bigendian_convert_uint(*ptr);
#else
    diff |= (*ptr);
#endif
  } else {
    debug(printf("Clearing genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff &= ~(Bigendian_convert_uint(*ptr));
#else
    diff &= ~(*ptr);
#endif
  }
  debug(printf(" => diff %08X\n",diff));

  return diff;
}


static UINT4
block_diff_no_flags (UINT4 *query_shifted, UINT4 *alt_ptr) {
  UINT4 diff, compare;

  /* High */
  debug(printf("Comparing high: query %08X with alt genome %08X ",*query_shifted,alt_ptr[0]));
#ifdef WORDS_BIGENDIAN
  compare = (*query_shifted++) ^ Bigendian_convert_uint(alt_ptr[0]);
#else
  compare = (*query_shifted++) ^ (alt_ptr[0]);
#endif
  diff = (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X with alt genome %08X ",*query_shifted,alt_ptr[1]));
#ifdef WORDS_BIGENDIAN
  compare = (*query_shifted++) ^ Bigendian_convert_uint(alt_ptr[1]);
#else
  compare = (*query_shifted++) ^ (alt_ptr[1]);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  return diff;
}


/* wildcard if ref == alt && alt_flag == 1 */
/* not wildcard if ref != alt || alt_flag == 0 */
/* diffs are (query ^ ref) & (query ^ alt) & ~wildcard */
static UINT4
block_diff_non_wildcard (UINT4 *ref_ptr, UINT4 *alt_ptr) { 
  UINT4 non_wildcard, compare, flags;

  /* Test for equality of ref and alt */
  debug(printf("Equality high: ref genome %08X with alt genome %08X ",ref_ptr[0],alt_ptr[0]));
#ifdef WORDS_BIGENDIAN
  compare = Bigendian_convert_uint(ref_ptr[0]) ^ Bigendian_convert_uint(alt_ptr[0]);
#else
  compare = (ref_ptr[0]) ^ (alt_ptr[0]);
#endif
  non_wildcard = (reduce_nt[compare >> 16] << 24);
  non_wildcard |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",non_wildcard));
  
  debug(printf("Equality low: ref genome %08X with alt genome %08X ",ref_ptr[1],alt_ptr[1]));
#ifdef WORDS_BIGENDIAN
  compare = Bigendian_convert_uint(ref_ptr[1]) ^ Bigendian_convert_uint(alt_ptr[1]);
#else
  compare = (ref_ptr[1]) ^ (alt_ptr[1]);
#endif
  non_wildcard |= (reduce_nt[compare >> 16] << 8);
  non_wildcard |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",non_wildcard));

  /* Alt flags */
  debug(printf("Wildcard add flags: ref genome %08X and alt genome %08X ",ref_ptr[2],alt_ptr[2]));
#ifdef WORDS_BIGENDIAN
  flags = Bigendian_convert_uint(alt_ptr[2]);
#else
  flags = (alt_ptr[2]);
#endif
  non_wildcard |= ~flags;
  debug(printf(" => non_wildcard %08X\n",non_wildcard));

  return non_wildcard;
}


#ifdef GSNAP

/************************************************************************
 *   CMET
 ************************************************************************/

static UINT4
block_diff_metct (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* Mark genome-T to query-C mismatches */
  debug(printf("Marking query C %08X and genome T %08X ",
	       convert_mark_c(query_shifted[0],query_shifted[1]),
	       convert_mark_t(ptr[0],ptr[1])));
#ifdef WORDS_BIGENDIAN
  diff = convert_mark_c(query_shifted[0],query_shifted[1]) & 
    convert_mark_t(Bigendian_convert_uint(ptr[0]),Bigendian_convert_uint(ptr[1]));
#else
  diff = convert_mark_c(query_shifted[0],query_shifted[1]) & convert_mark_t(ptr[0],ptr[1]);
#endif
  debug(printf(" => diff %08X\n",diff));

  /* High */
  debug(printf("Comparing high: query %08X (CT %08X) with genome %08X (CT %08X) ",
	       *query_shifted,Cmet_reduce_ct(*query_shifted),*ptr,Cmet_reduce_ct(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Cmet_reduce_ct(*query_shifted++) ^ Cmet_reduce_ct(Bigendian_convert_uint(*ptr++));
#else
  compare = Cmet_reduce_ct(*query_shifted++) ^ Cmet_reduce_ct(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X (CT %08X) with genome %08X (CT %08X) ",
	       *query_shifted,Cmet_reduce_ct(*query_shifted),*ptr,Cmet_reduce_ct(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Cmet_reduce_ct(*query_shifted++) ^ Cmet_reduce_ct(Bigendian_convert_uint(*ptr++));
#else
  compare = Cmet_reduce_ct(*query_shifted++) ^ Cmet_reduce_ct(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  /* Flags: Considering N as a mismatch */
  if (query_unk_mismatch_p) {
    debug(printf("Marking query flags: query %08X ",*query_shifted));
    diff |= (*query_shifted);
  } else {
    debug(printf("Clearing query flags: query %08X ",*query_shifted));
    diff &= ~(*query_shifted);
  }

  if (genome_unk_mismatch_p) {
    debug(printf("Marking genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff |= Bigendian_convert_uint(*ptr);
#else
    diff |= (*ptr);
#endif
  } else {
    debug(printf("Clearing genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff &= ~(Bigendian_convert_uint(*ptr));
#else
    diff &= ~(*ptr);
#endif
  }
  debug(printf(" => diff %08X\n",diff));

  return diff;
}


static UINT4
block_diff_metga (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* Mark genome-A to query-G mismatches */
  debug(printf("Marking query G %08X and genome A %08X ",
	       convert_mark_g(query_shifted[0],query_shifted[1]),
	       convert_mark_a(ptr[0],ptr[1])));
#ifdef WORDS_BIGENDIAN
  diff = convert_mark_g(query_shifted[0],query_shifted[1]) & 
    convert_mark_a(Bigendian_convert_uint(ptr[0]),Bigendian_convert_uint(ptr[1]));
#else
  diff = convert_mark_g(query_shifted[0],query_shifted[1]) & convert_mark_a(ptr[0],ptr[1]);
#endif
  debug(printf(" => diff %08X\n",diff));

  /* High */
  debug(printf("Comparing high: query %08X (GA %08X) with genome %08X (GA %08X) ",
	       *query_shifted,Cmet_reduce_ga(*query_shifted),*ptr,Cmet_reduce_ga(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Cmet_reduce_ga(*query_shifted++) ^ Cmet_reduce_ga(Bigendian_convert_uint(*ptr++));
#else
  compare = Cmet_reduce_ga(*query_shifted++) ^ Cmet_reduce_ga(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X (GA %08X) with genome %08X (GA %08X) ",
	       *query_shifted,Cmet_reduce_ga(*query_shifted),*ptr,Cmet_reduce_ga(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Cmet_reduce_ga(*query_shifted++) ^ Cmet_reduce_ga(Bigendian_convert_uint(*ptr++));
#else
  compare = Cmet_reduce_ga(*query_shifted++) ^ Cmet_reduce_ga(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  /* Flags: Considering N as a mismatch */
  if (query_unk_mismatch_p) {
    debug(printf("Marking query flags: query %08X ",*query_shifted));
    diff |= (*query_shifted);
  } else {
    debug(printf("Clearing query flags: query %08X ",*query_shifted));
    diff &= ~(*query_shifted);
  }

  if (genome_unk_mismatch_p) {
    debug(printf("Marking genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff |= Bigendian_convert_uint(*ptr);
#else
    diff |= (*ptr);
#endif
  } else {
    debug(printf("Clearing genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff &= ~(Bigendian_convert_uint(*ptr));
#else
    diff &= ~(*ptr);
#endif
  }
  debug(printf(" => diff %08X\n",diff));

  return diff;
}



static UINT4
block_diff_metct_no_flags (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* Mark genome-T to query-C mismatches */
  debug(printf("Marking query C %08X and genome T %08X ",
	       convert_mark_c(query_shifted[0],query_shifted[1]),
	       convert_mark_t(ptr[0],ptr[1])));
#ifdef WORDS_BIGENDIAN
  diff = convert_mark_c(query_shifted[0],query_shifted[1]) & 
    convert_mark_t(Bigendian_convert_uint(ptr[0]),Bigendian_convert_uint(ptr[1]));
#else
  diff = convert_mark_c(query_shifted[0],query_shifted[1]) & convert_mark_t(ptr[0],ptr[1]);
#endif
  debug(printf(" => diff %08X\n",diff));

  /* High */
  debug(printf("Comparing high: query %08X (CT %08X) with genome %08X (CT %08X) ",
	       *query_shifted,Cmet_reduce_ct(*query_shifted),*ptr,Cmet_reduce_ct(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Cmet_reduce_ct(*query_shifted++) ^ Cmet_reduce_ct(Bigendian_convert_uint(*ptr++));
#else
  compare = Cmet_reduce_ct(*query_shifted++) ^ Cmet_reduce_ct(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X (CT %08X) with genome %08X (CT %08X) ",
	       *query_shifted,Cmet_reduce_ct(*query_shifted),*ptr,Cmet_reduce_ct(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Cmet_reduce_ct(*query_shifted++) ^ Cmet_reduce_ct(Bigendian_convert_uint(*ptr++));
#else
  compare = Cmet_reduce_ct(*query_shifted++) ^ Cmet_reduce_ct(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  return diff;
}


static UINT4
block_diff_metga_no_flags (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* Mark genome-A to query-G mismatches */
  debug(printf("Marking query G %08X and genome A %08X ",
	       convert_mark_g(query_shifted[0],query_shifted[1]),
	       convert_mark_a(ptr[0],ptr[1])));
#ifdef WORDS_BIGENDIAN
  diff = convert_mark_g(query_shifted[0],query_shifted[1]) & 
    convert_mark_a(Bigendian_convert_uint(ptr[0]),Bigendian_convert_uint(ptr[1]));
#else
  diff = convert_mark_g(query_shifted[0],query_shifted[1]) & convert_mark_a(ptr[0],ptr[1]);
#endif
  debug(printf(" => diff %08X\n",diff));

  /* High */
  debug(printf("Comparing high: query %08X (GA %08X) with genome %08X (GA %08X) ",
	       *query_shifted,Cmet_reduce_ga(*query_shifted),*ptr,Cmet_reduce_ga(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Cmet_reduce_ga(*query_shifted++) ^ Cmet_reduce_ga(Bigendian_convert_uint(*ptr++));
#else
  compare = Cmet_reduce_ga(*query_shifted++) ^ Cmet_reduce_ga(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X (GA %08X) with genome %08X (GA %08X) ",
	       *query_shifted,Cmet_reduce_ga(*query_shifted),*ptr,Cmet_reduce_ga(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Cmet_reduce_ga(*query_shifted++) ^ Cmet_reduce_ga(Bigendian_convert_uint(*ptr++));
#else
  compare = Cmet_reduce_ga(*query_shifted++) ^ Cmet_reduce_ga(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  return diff;
}


/************************************************************************
 *   ATOI
 ************************************************************************/

static UINT4
block_diff_a2iag (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* Mark genome-G to query-A mismatches */
  debug(printf("Marking query A %08X and genome G %08X ",
	       convert_mark_a(query_shifted[0],query_shifted[1]),
	       convert_mark_g(ptr[0],ptr[1])));
#ifdef WORDS_BIGENDIAN
  diff = convert_mark_a(query_shifted[0],query_shifted[1]) & 
    convert_mark_g(Bigendian_convert_uint(ptr[0]),Bigendian_convert_uint(ptr[1]));
#else
  diff = convert_mark_a(query_shifted[0],query_shifted[1]) & convert_mark_g(ptr[0],ptr[1]);
#endif
  debug(printf(" => diff %08X\n",diff));

  /* High */
  debug(printf("Comparing high: query %08X (AG %08X) with genome %08X (AG %08X) ",
	       *query_shifted,Atoi_reduce_ag(*query_shifted),*ptr,Atoi_reduce_ag(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Atoi_reduce_ag(*query_shifted++) ^ Atoi_reduce_ag(Bigendian_convert_uint(*ptr++));
#else
  compare = Atoi_reduce_ag(*query_shifted++) ^ Atoi_reduce_ag(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X (AG %08X) with genome %08X (AG %08X) ",
	       *query_shifted,Atoi_reduce_ag(*query_shifted),*ptr,Atoi_reduce_ag(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Atoi_reduce_ag(*query_shifted++) ^ Atoi_reduce_ag(Bigendian_convert_uint(*ptr++));
#else
  compare = Atoi_reduce_ag(*query_shifted++) ^ Atoi_reduce_ag(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  /* Flags: Considering N as a mismatch */
  if (query_unk_mismatch_p) {
    debug(printf("Marking query flags: query %08X ",*query_shifted));
    diff |= (*query_shifted);
  } else {
    debug(printf("Clearing query flags: query %08X ",*query_shifted));
    diff &= ~(*query_shifted);
  }

  if (genome_unk_mismatch_p) {
    debug(printf("Marking genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff |= Bigendian_convert_uint(*ptr);
#else
    diff |= (*ptr);
#endif
  } else {
    debug(printf("Clearing genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff &= ~(Bigendian_convert_uint(*ptr));
#else
    diff &= ~(*ptr);
#endif
  }
  debug(printf(" => diff %08X\n",diff));

  return diff;
}


static UINT4
block_diff_a2itc (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* Mark genome-C to query-T mismatches */
  debug(printf("Marking query T %08X and genome C %08X ",
	       convert_mark_t(query_shifted[0],query_shifted[1]),
	       convert_mark_c(ptr[0],ptr[1])));
#ifdef WORDS_BIGENDIAN
  diff = convert_mark_t(query_shifted[0],query_shifted[1]) & 
    convert_mark_c(Bigendian_convert_uint(ptr[0]),Bigendian_convert_uint(ptr[1]));
#else
  diff = convert_mark_t(query_shifted[0],query_shifted[1]) & convert_mark_c(ptr[0],ptr[1]);
#endif
  debug(printf(" => diff %08X\n",diff));

  /* High */
  debug(printf("Comparing high: query %08X (TC %08X) with genome %08X (TC %08X) ",
	       *query_shifted,Atoi_reduce_tc(*query_shifted),*ptr,Atoi_reduce_tc(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Atoi_reduce_tc(*query_shifted++) ^ Atoi_reduce_tc(Bigendian_convert_uint(*ptr++));
#else
  compare = Atoi_reduce_tc(*query_shifted++) ^ Atoi_reduce_tc(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X (TC %08X) with genome %08X (TC %08X) ",
	       *query_shifted,Atoi_reduce_tc(*query_shifted),*ptr,Atoi_reduce_tc(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Atoi_reduce_tc(*query_shifted++) ^ Atoi_reduce_tc(Bigendian_convert_uint(*ptr++));
#else
  compare = Atoi_reduce_tc(*query_shifted++) ^ Atoi_reduce_tc(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  /* Flags: Considering N as a mismatch */
  if (query_unk_mismatch_p) {
    debug(printf("Marking query flags: query %08X ",*query_shifted));
    diff |= (*query_shifted);
  } else {
    debug(printf("Clearing query flags: query %08X ",*query_shifted));
    diff &= ~(*query_shifted);
  }

  if (genome_unk_mismatch_p) {
    debug(printf("Marking genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff |= Bigendian_convert_uint(*ptr);
#else
    diff |= (*ptr);
#endif
  } else {
    debug(printf("Clearing genome flags: genome %08X ",*ptr));
#ifdef WORDS_BIGENDIAN
    diff &= ~(Bigendian_convert_uint(*ptr));
#else
    diff &= ~(*ptr);
#endif
  }
  debug(printf(" => diff %08X\n",diff));

  return diff;
}


static UINT4
block_diff_a2iag_no_flags (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* Mark genome-G to query-A mismatches */
  debug(printf("Marking query A %08X and genome G %08X ",
	       convert_mark_a(query_shifted[0],query_shifted[1]),
	       convert_mark_g(ptr[0],ptr[1])));
#ifdef WORDS_BIGENDIAN
  diff = convert_mark_a(query_shifted[0],query_shifted[1]) & 
    convert_mark_g(Bigendian_convert_uint(ptr[0]),Bigendian_convert_uint(ptr[1]));
#else
  diff = convert_mark_a(query_shifted[0],query_shifted[1]) & convert_mark_g(ptr[0],ptr[1]);
#endif
  debug(printf(" => diff %08X\n",diff));

  /* High */
  debug(printf("Comparing high: query %08X (AG %08X) with genome %08X (AG %08X) ",
	       *query_shifted,Atoi_reduce_ag(*query_shifted),*ptr,Atoi_reduce_ag(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Atoi_reduce_ag(*query_shifted++) ^ Atoi_reduce_ag(Bigendian_convert_uint(*ptr++));
#else
  compare = Atoi_reduce_ag(*query_shifted++) ^ Atoi_reduce_ag(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X (AG %08X) with genome %08X (AG %08X) ",
	       *query_shifted,Atoi_reduce_ag(*query_shifted),*ptr,Atoi_reduce_ag(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Atoi_reduce_ag(*query_shifted++) ^ Atoi_reduce_ag(Bigendian_convert_uint(*ptr++));
#else
  compare = Atoi_reduce_ag(*query_shifted++) ^ Atoi_reduce_ag(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  return diff;
}


static UINT4
block_diff_a2itc_no_flags (UINT4 *query_shifted, UINT4 *ptr) {
  UINT4 diff, compare;

  /* Mark genome-C to query-T mismatches */
  debug(printf("Marking query T %08X and genome C %08X ",
	       convert_mark_t(query_shifted[0],query_shifted[1]),
	       convert_mark_c(ptr[0],ptr[1])));
#ifdef WORDS_BIGENDIAN
  diff = convert_mark_t(query_shifted[0],query_shifted[1]) & 
    convert_mark_c(Bigendian_convert_uint(ptr[0]),Bigendian_convert_uint(ptr[1]));
#else
  diff = convert_mark_t(query_shifted[0],query_shifted[1]) & convert_mark_c(ptr[0],ptr[1]);
#endif
  debug(printf(" => diff %08X\n",diff));

  /* High */
  debug(printf("Comparing high: query %08X (TC %08X) with genome %08X (TC %08X) ",
	       *query_shifted,Atoi_reduce_tc(*query_shifted),*ptr,Atoi_reduce_tc(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Atoi_reduce_tc(*query_shifted++) ^ Atoi_reduce_tc(Bigendian_convert_uint(*ptr++));
#else
  compare = Atoi_reduce_tc(*query_shifted++) ^ Atoi_reduce_tc(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 24);
  diff |= reduce_nt[compare & 0x0000FFFF] << 16;
  debug(printf(" => diff %08X\n",diff));

  /* Low */
  debug(printf("Comparing low: query %08X (TC %08X) with genome %08X (TC %08X) ",
	       *query_shifted,Atoi_reduce_tc(*query_shifted),*ptr,Atoi_reduce_tc(*ptr)));
#ifdef WORDS_BIGENDIAN
  compare = Atoi_reduce_tc(*query_shifted++) ^ Atoi_reduce_tc(Bigendian_convert_uint(*ptr++));
#else
  compare = Atoi_reduce_tc(*query_shifted++) ^ Atoi_reduce_tc(*ptr++);
#endif
  diff |= (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug(printf(" => diff %08X\n",diff));

  return diff;
}

#endif



static Mode_T mode;

static inline UINT4
block_diff (UINT4 *query_shifted, UINT4 *ptr, bool plusp, int genestrand) {
#ifndef GSNAP
  return block_diff_standard(query_shifted,ptr);
#else
  if (mode == STANDARD) {
    return block_diff_standard(query_shifted,ptr);
  } else if (mode == CMET_STRANDED) {
    return plusp ? block_diff_metct(query_shifted,ptr) : block_diff_metga(query_shifted,ptr);
  } else if (mode == CMET_NONSTRANDED) {
    return (genestrand == +1) ? block_diff_metct(query_shifted,ptr) : block_diff_metga(query_shifted,ptr);
  } else if (mode == ATOI_STRANDED) {
    return plusp ? block_diff_a2iag(query_shifted,ptr) : block_diff_a2itc(query_shifted,ptr);
  } else if (mode == ATOI_NONSTRANDED) {
    return (genestrand == +1) ? block_diff_a2iag(query_shifted,ptr) : block_diff_a2itc(query_shifted,ptr);
  } else {
    abort();
  }
#endif
}

static inline UINT4
block_diff_snp (UINT4 *query_shifted, UINT4 *ref_ptr, UINT4 *alt_ptr, bool plusp, int genestrand) {
#ifndef GSNAP
  return (block_diff_no_flags(query_shifted,alt_ptr) & block_diff_non_wildcard(ref_ptr,alt_ptr));
#else
  if (mode == STANDARD) {
    return (block_diff_no_flags(query_shifted,alt_ptr) & block_diff_non_wildcard(ref_ptr,alt_ptr));
  } else if (mode == CMET_STRANDED) {
    return plusp ? block_diff_metct_no_flags(query_shifted,alt_ptr) : block_diff_metga_no_flags(query_shifted,alt_ptr);
  } else if (mode == CMET_NONSTRANDED) {
    return (genestrand == +1) ? block_diff_metct_no_flags(query_shifted,alt_ptr) : block_diff_metga_no_flags(query_shifted,alt_ptr);
  } else if (mode == ATOI_STRANDED) {
    return plusp ? block_diff_a2iag_no_flags(query_shifted,alt_ptr) : block_diff_a2itc_no_flags(query_shifted,alt_ptr);
  } else if (mode == ATOI_NONSTRANDED) {
    return (genestrand == +1) ? block_diff_a2iag_no_flags(query_shifted,alt_ptr) : block_diff_a2itc_no_flags(query_shifted,alt_ptr);
  } else {
    abort();
  }
#endif
}


void
Genome_hr_setup (UINT4 *ref_blocks_in, UINT4 *snp_blocks_in,
		 bool query_unk_mismatch_p_in, bool genome_unk_mismatch_p_in,
		 Mode_T mode_in) {
  ref_blocks = ref_blocks_in;
  snp_blocks = snp_blocks_in;
  query_unk_mismatch_p = query_unk_mismatch_p_in;
  genome_unk_mismatch_p = genome_unk_mismatch_p_in;
  mode = mode_in;

#if 0
  if (cmetp == false) {
    block_diff = block_diff_standard;
    block_diff_snp = block_diff_snp_standard;
  } else {
    block_diff = block_diff_cmet;
    block_diff_snp = block_diff_snp_cmet;
  }
#endif


  return;
}



/************************************************************************/

/*                 76543210 */
#define HIGH_BIT 0x80000000

#define clear_start(diff,startdiscard) (diff & (~0U << (startdiscard)))
#define clear_end(diff,enddiscard) (diff & ~(~0U << (enddiscard)))

#define clear_start_mask(startdiscard) (~0U << (startdiscard))
#define clear_end_mask(enddiscard) (~(~0U << (enddiscard)))

/* Same speed: clear_highbit(diff,relpos) diff -= (HIGH_BIT >> relpos) */
/* Note: xor assumes that bit at relpos was on */
#define clear_highbit(diff,relpos) diff ^= (HIGH_BIT >> relpos)

/* Slower: clear_lowbit(diff,relpos) diff -= (1 << relpos) */
#define clear_lowbit(diff,relpos) diff &= (diff - 1);


static int
count_mismatches_limit (Compress_T query_compress, Genomicpos_T left, 
			int pos5, int pos3, int max_mismatches, bool plusp, int genestrand) {
  int nmismatches;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *endblock, *ptr;
  UINT4 *query_shifted, *query_shifted_save_start;
  UINT4 diff;
  int nshift;

  debug(
	printf("\n\n");
	printf("Genome (in count_mismatches_limit) from %u+%d to %u+%d:\n",left,pos5,left,pos3);
	Genome_print_blocks(ref_blocks,left+pos5,left+pos3);
	printf("\n");
	);


  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));
  
  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;


  if (endblocki == startblocki) {
    debug(printf("** Single block **\n"));
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x = %08X\n",
		 clear_start_mask(startdiscard),clear_end_mask(enddiscard),clear_start_mask(startdiscard) & clear_end_mask(enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
    return __builtin_popcount(diff);
#else
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		 diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		 diff >> 16,count_bits[diff >> 16]));
    return count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

  } else if (endblocki == startblocki + 3) {
    /* Only two blocks to check */

    if (32 - startdiscard >= enddiscard) {
      /* Two blocks to check and more bits counted in startblock */
      debug(printf("* Two blocks, start block first **\n"));

      /* 1/2: Startblock */
      diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
      diff = clear_start(diff,startdiscard);
      debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));
      
#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      if ((nmismatches = __builtin_popcount(diff)) > max_mismatches) {
	return nmismatches;
      }
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      if ((nmismatches = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]) > max_mismatches) {
	return nmismatches;
      }
#endif
      
      /* 2/2: Endblock */
      diff = block_diff(query_shifted/*endblock*/+3,&(ref_blocks[endblocki]),plusp,genestrand);
      diff = clear_end(diff,enddiscard);
      debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      return nmismatches + __builtin_popcount(diff);
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      return nmismatches + count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

    } else {
      /* Two blocks to check and more bits counted in endblock */
      debug(printf("** Two blocks, end block first **\n"));

      /* 1/2: Endblock */
      diff = block_diff(query_shifted/*endblock*/+3,&(ref_blocks[endblocki]),plusp,genestrand);
      diff = clear_end(diff,enddiscard);
      debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      if ((nmismatches = __builtin_popcount(diff)) > max_mismatches) {
	return nmismatches;
      }
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      if ((nmismatches = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]) > max_mismatches) {
	return nmismatches;
      }
#endif

      /* 2/2: Startblock */
      diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
      diff = clear_start(diff,startdiscard);
      debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      return nmismatches + __builtin_popcount(diff);
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      return nmismatches + count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

    }

  } else {
    /* More than 2 blocks to check */
    debug(printf("** More than two blocks **\n"));

    query_shifted_save_start = query_shifted;

    /* 2..(n-1) / n: Check all middle blocks first */
    query_shifted += 3;
    ptr = &(ref_blocks[startblocki+3]);
    endblock = &(ref_blocks[endblocki]);
    nmismatches = 0;

    while (ptr < endblock) {
      diff = block_diff(query_shifted,ptr,plusp,genestrand);
      
#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      if ((nmismatches += __builtin_popcount(diff)) > max_mismatches) {
	return nmismatches;
      }
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      if ((nmismatches += count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]) > max_mismatches) {
	return nmismatches;
      }
#endif

      query_shifted += 3;
      ptr += 3;
    }

    if (enddiscard >= 32 - startdiscard) {
      /* More bits in end block */
      debug(printf("** Final block, end block first **\n"));

      /* n/n: Go first to end block */
      diff = block_diff(query_shifted,ptr,plusp,genestrand);
      diff = clear_end(diff,enddiscard);
      debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      if ((nmismatches += __builtin_popcount(diff)) > max_mismatches) {
	return nmismatches;
      }
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      if ((nmismatches += count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]) > max_mismatches) {
	return nmismatches;
      }
#endif
      
      /* 1/n: Go second to start block */
      diff = block_diff(query_shifted_save_start,&(ref_blocks[startblocki]),plusp,genestrand);
      diff = clear_start(diff,startdiscard);
      debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));
      
#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      return nmismatches + __builtin_popcount(diff);
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      return nmismatches + count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

    } else {
      /* 1/n: Go first to start block */
      debug(printf("** Final block, start block first **\n"));

      diff = block_diff(query_shifted_save_start,&(ref_blocks[startblocki]),plusp,genestrand);
      diff = clear_start(diff,startdiscard);
      debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));
      
#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      if ((nmismatches += __builtin_popcount(diff)) > max_mismatches) {
	return nmismatches;
      }
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      if ((nmismatches += count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]) > max_mismatches) {
	return nmismatches;
      }
#endif

      /* n/n: Go second to end block */
      diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);
      diff = clear_end(diff,enddiscard);
      debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      return nmismatches + __builtin_popcount(diff);
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      return nmismatches + count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif
    }
  }
}


static int
count_mismatches_limit_snps (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3, int max_mismatches,
			     bool plusp, int genestrand) {
  int nmismatches, incr;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *endblock;
  UINT4 *query_shifted, *query_shifted_save_start;
  UINT4 diff;
  int nshift;
  Genomicpos_T *ref_ptr, *alt_ptr;

  debug(
	printf("\n\n");
	printf("Genome (in count_mismatches_limit_snps) from %u+%d to %u+%d\n",left,pos5,left,pos3);
	Genome_print_blocks_snp(ref_blocks,snp_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));
  
  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;


  if (endblocki == startblocki) {
    /* 1/1 blocks */
    debug(printf("** Single block **\n"));
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x = %08X\n",
		 clear_start_mask(startdiscard),clear_end_mask(enddiscard),clear_start_mask(startdiscard) & clear_end_mask(enddiscard)));

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in single block */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

#ifdef HAVE_BUILTIN_POPCOUNT
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
    nmismatches = __builtin_popcount(diff);
#else
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		 diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		 diff >> 16,count_bits[diff >> 16]));
    nmismatches = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif
      
    return nmismatches;

  } else if (endblocki == startblocki + 3) {
    /* Only two blocks to check */

    if (32 - startdiscard >= enddiscard) {
      /* 1/2: Startblock */
      diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
      diff = clear_start(diff,startdiscard);
      debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));

      if (snp_blocks[startblocki+2]) {
	/* SNPs present in startblock */
	diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches /* init */ = __builtin_popcount(diff);
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches /* init */ = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

      if (nmismatches > max_mismatches) {
	return nmismatches;
      }

      /* 2/2: Endblock */
      diff = block_diff(query_shifted/*endblock*/+3,&(ref_blocks[endblocki]),plusp,genestrand);
      diff = clear_end(diff,enddiscard);
      debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

      if (snp_blocks[endblocki+2]) {
	/* SNPs present in endblock */
	diff &= block_diff_snp(query_shifted/*endblock*/+3,&(ref_blocks[endblocki]),&(snp_blocks[endblocki]),plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += (incr = __builtin_popcount(diff));
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

      return nmismatches;

    } else {
      /* Two blocks to check and more bits counted in endblock */
      debug(printf("** Two blocks, end block first **\n"));

      /* 1/2: Endblock */
      diff = block_diff(query_shifted/*endblock*/+3,&(ref_blocks[endblocki]),plusp,genestrand);
      diff = clear_end(diff,enddiscard);
      debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

      if (snp_blocks[endblocki+2]) {
	/* SNPs present in endblock */
	diff &= block_diff_snp(query_shifted/*endblock*/+3,&(ref_blocks[endblocki]),&(snp_blocks[endblocki]),plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches /* init */ = __builtin_popcount(diff);
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches /* init */ = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

      if (nmismatches > max_mismatches) {
	return nmismatches;
      }

      /* 2/2: Startblock */
      diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
      diff = clear_start(diff,startdiscard);
      debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));

      if (snp_blocks[startblocki+2]) {
	/* SNPs present in startblock */
	diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += (incr = __builtin_popcount(diff));
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

      return nmismatches;
    }

  } else {
    /* More than 2 blocks to check */
    debug(printf("** More than two blocks **\n"));

    query_shifted_save_start = query_shifted;

    /* 2..(n-1) / n: Check all middle blocks first */
    query_shifted += 3;
    ref_ptr = &(ref_blocks[startblocki+3]);
    alt_ptr = &(snp_blocks[startblocki+3]);
    endblock = &(ref_blocks[endblocki]);
    nmismatches = 0;

    while (ref_ptr < endblock) {
      diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

      if (*(alt_ptr+2)) {
	/* SNPs present in middle block */
	diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += (incr = __builtin_popcount(diff));
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

      if (nmismatches > max_mismatches) {
	return nmismatches;
      }

      query_shifted += 3;
      ref_ptr += 3;
      alt_ptr += 3;
    }

    if (enddiscard >= 32 - startdiscard) {
      /* n/n: Go first to end block */
      debug(printf("** Final block, end block first **\n"));
      diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);
      diff = clear_end(diff,enddiscard);
      debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

      if (*(alt_ptr+2)) {
	/* SNPs present in endblock */
	diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += (incr = __builtin_popcount(diff));
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

      if (nmismatches > max_mismatches) {
	return nmismatches;
      }

      /* 1/n: Go second to start block */
      diff = block_diff(query_shifted_save_start,&(ref_blocks[startblocki]),plusp,genestrand);
      diff = clear_start(diff,startdiscard);
      debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));
      
      if (snp_blocks[startblocki+2]) {
	/* SNPs present in startblock */
	diff &= block_diff_snp(query_shifted_save_start,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += (incr = __builtin_popcount(diff));
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

      return nmismatches;

    } else {
      debug(printf("** Final block, start block first **\n"));

      /* 1/n: Go first to start block */
      diff = block_diff(query_shifted_save_start,&(ref_blocks[startblocki]),plusp,genestrand);
      diff = clear_start(diff,startdiscard);
      debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));
      
      if (snp_blocks[startblocki+2]) {
	/* SNPs present in startblock */
	diff &= block_diff_snp(query_shifted_save_start,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += (incr = __builtin_popcount(diff));
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

      if (nmismatches > max_mismatches) {
	return nmismatches;
      }
      
      /* n/n: Go second to end block */
      diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);
      diff = clear_end(diff,enddiscard);
      debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

      if (snp_blocks[endblocki+2]) {
	/* SNPs present in endblock */
	diff &= block_diff_snp(query_shifted,&(ref_blocks[endblocki]),&(snp_blocks[endblocki]),plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += (incr = __builtin_popcount(diff));
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

      return nmismatches;
    }
  }
}


int
Genome_count_mismatches_limit (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3,
			       int max_mismatches, bool plusp, int genestrand) {

#if 0
  if (dibasep) {
    debug(printf("Dibase_count_mismatches_limit from %u+%d to %u+%d with max_mismatches %d:\n",
		 left,pos5,left,pos3,max_mismatches));

    return Dibase_count_mismatches_limit(&(*ncolordiffs),query,pos5,pos3,
					 /*startpos*/left+pos5,/*endpos*/left+pos3,max_mismatches);
  }
#endif

  if (snp_blocks == NULL) {
    return count_mismatches_limit(query_compress,left,pos5,pos3,max_mismatches,plusp,genestrand);
  } else {
    return count_mismatches_limit_snps(query_compress,left,pos5,pos3,max_mismatches,plusp,genestrand);
  }
}



int
Genome_count_mismatches_substring_ref (Compress_T query_compress,
				       Genomicpos_T left, int pos5, int pos3,
				       bool plusp, int genestrand) {
  int nmismatches;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ptr, *end;
  UINT4 *query_shifted;
  UINT4 diff;
  int nshift;

  debug(
	printf("\n\n");
	printf("Genome (in count_mismatches_substring) from %u+%d to %u+%d:\n",left,pos5,left,pos3);
	Genome_print_blocks(ref_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;


  if (endblocki == startblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x = %08X\n",
		 clear_start_mask(startdiscard),clear_end_mask(enddiscard),clear_start_mask(startdiscard) & clear_end_mask(enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
    return __builtin_popcount(diff);
#else
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		 diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		 diff >> 16,count_bits[diff >> 16]));
    return count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

  } else {
    /* Startblock */
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
    nmismatches = __builtin_popcount(diff);
#else
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		diff >> 16,count_bits[diff >> 16]));
    nmismatches = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

    query_shifted += 3;
    ptr = &(ref_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    while (ptr < end) {
      diff = block_diff(query_shifted,ptr,plusp,genestrand);

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += __builtin_popcount(diff);
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

      query_shifted += 3;
      ptr += 3;
    }

    /* Endblock */
    diff = block_diff(query_shifted,ptr,plusp,genestrand);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

#ifdef HAVE_BUILTIN_POPCOUNT
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
    return nmismatches + __builtin_popcount(diff);
#else
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		diff >> 16,count_bits[diff >> 16]));
    return nmismatches + count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif
  }
}

static int
count_mismatches_substring_snps (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3,
				 bool plusp, int genestrand) {
  int nmismatches, incr;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ref_ptr, *alt_ptr, *end;
  UINT4 *query_shifted;
  UINT4 diff;
  int nshift;

  debug(
	printf("\n\n");
	printf("Genome (in count_mismatches_substring_snps) from %u+%d to %u+%d:\n",left,pos5,left,pos3);
	Genome_print_blocks_snp(ref_blocks,snp_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;
  
  if (endblocki == startblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x = %08X\n",
		 clear_start_mask(startdiscard),clear_end_mask(enddiscard),clear_start_mask(startdiscard) & clear_end_mask(enddiscard)));

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in single block */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

#ifdef HAVE_BUILTIN_POPCOUNT
    nmismatches = __builtin_popcount(diff);
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
#else
    nmismatches = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		 diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		 diff >> 16,count_bits[diff >> 16]));
#endif

    return nmismatches;

  } else {
    /* Startblock */
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in startblock */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

#ifdef HAVE_BUILTIN_POPCOUNT
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
    nmismatches /* init */ = __builtin_popcount(diff);
#else
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		 diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		 diff >> 16,count_bits[diff >> 16]));
    nmismatches /* init */ = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16];
#endif

    query_shifted += 3;
    ref_ptr = &(ref_blocks[startblocki+3]);
    alt_ptr = &(snp_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    while (ref_ptr < end) {
      diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

      if (*(alt_ptr+2)) {
	/* SNPs present in middle block */
	diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
      }

#ifdef HAVE_BUILTIN_POPCOUNT
      debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
      nmismatches += (incr = __builtin_popcount(diff));
#else
      debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		   diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		   diff >> 16,count_bits[diff >> 16]));
      nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

      query_shifted += 3;
      ref_ptr += 3;
      alt_ptr += 3;
    }

    /* Endblock */
    diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    if (*(alt_ptr+2)) {
      /* SNPs present in endblock */
      diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
    }
      
#ifdef HAVE_BUILTIN_POPCOUNT
    debug(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
    nmismatches += (incr = __builtin_popcount(diff));
#else
    debug(printf("nmismatches %08X => %d plus %08X => %d\n",
		 diff & 0x0000FFFF,count_bits[diff & 0x0000FFFF],
		 diff >> 16,count_bits[diff >> 16]));
    nmismatches += (incr = count_bits[diff & 0x0000FFFF] + count_bits[diff >> 16]);
#endif

    return nmismatches;
  }
}


/* left is where the start of the query matches.  pos5 is where we
   want to start comparing in the query.  pos3 is just after where we
   want to stop comparing in the query, i.e., stop at (pos3-1)
   inclusive */
int
Genome_count_mismatches_substring (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3,
				   bool plusp, int genestrand) {

#if 0
  if (dibasep) {
    Dibase_count_mismatches_substring(&ncolordiffs,query,pos5,pos3,
				      /*startpos*/left+pos5,/*endpos*/left+pos3);
  }
#endif

  if (snp_blocks == NULL) {
    return Genome_count_mismatches_substring_ref(query_compress,left,pos5,pos3,plusp,genestrand);
  } else {
    return count_mismatches_substring_snps(query_compress,left,pos5,pos3,plusp,genestrand);
  }
}



/* pos5 is where we want to start comparing in the query.  pos3 is
   just after where we want to stop comparing in the query, i.e., stop
   at (pos3-1) inclusive */
UINT4
Genome_query_shift_fragment_right (UINT4 *flags, UINT4 *mask, Compress_T query_compress, int pos5, int pos3) {
  Genomicpos_T enddiscard;
  UINT4 *query_shifted;
  int nshift, nblocks;

#if 0
  for (nshift = 0; nshift < 32; nshift++) {
    query_shifted = Compress_shift(query_compress,nshift);
    printf("%d: %08X %08X  %08X %08X  %08X %08X\n",
	   nshift,query_shifted[0],query_shifted[1],
	   query_shifted[3],query_shifted[4],
	   query_shifted[6],query_shifted[7]);
  }
#endif

  nblocks = (pos5 + 15) / 16;
  nshift = (nblocks*16 - pos5) % 16;

#if 0
  if (pos3 - pos5 == 16) {
    enddiscard = 16;
  } else {
    enddiscard = (pos3 - pos5) % 16;
  }
#else
  enddiscard = pos3 - pos5;
#endif
  debug1(printf("shift_fragment_right: pos5 %d, pos3 %d => nblocks = %d, nshift = %d, startdiscard = %d, enddiscard = %d\n",
		pos5,pos3,nblocks,nshift,0,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  query_shifted += (nblocks/2)*3;
  *flags = query_shifted[2];
  if (nblocks % 2 == 0) {
    query_shifted += 1;		/* Point to low */
    (*flags) &= 0x0000FFFF;	/* Keep flags on bottom */
  } else {
    (*flags) >>= 16;		/* Move flags into bottom */
  }
  debug1(printf("Query shifted %d: %08X\n",nshift,*query_shifted));

  *mask = clear_end_mask(enddiscard);
  *mask &= 0x0000FFFF;
  debug1(printf("Mask for enddiscard %d: %08X\n",enddiscard,*mask));

  return *query_shifted;
}


/* pos5 is where we want to start comparing in the query.  pos3 is
   just after where we want to stop comparing in the query, i.e., stop
   at (pos3-1) inclusive */
UINT4
Genome_query_shift_fragment_left (UINT4 *flags, UINT4 *mask, Compress_T query_compress, int pos5, int pos3) {
  Genomicpos_T startdiscard;
  UINT4 *query_shifted;
  int nshift, nblocks;

  nblocks = (pos3 - 1) / 16;
  nshift = (16 + nblocks*16 - pos3) % 16;

#if 0
  startdiscard = nshift % 16;
#else
  startdiscard = nshift;
#endif
  debug1(printf("shift_fragment_left: pos5 %d, pos3 %d => nblocks = %d, nshift = %d, startdiscard = %d, enddiscard = %d\n",
		pos5,pos3,nblocks,nshift,startdiscard,0));

  query_shifted = Compress_shift(query_compress,nshift);
  query_shifted += (nblocks/2)*3;
  *flags = query_shifted[2];
  if (nblocks % 2 == 0) {
    query_shifted += 1;		/* Point to low */
    (*flags) &= 0x0000FFFF;	/* Keep flags on bottom */
  } else {
    (*flags) >>= 16;		/* Move flags into bottom */
  }
  debug1(printf("Query shifted %d: %08X\n",nshift,*query_shifted));

  /* from clear_start */
  *mask = clear_start_mask(startdiscard);
  *mask &= 0x0000FFFF;
  debug1(printf("Mask for startdiscard %d: %08X\n",startdiscard,*mask));

  return *query_shifted;
}



/* pos5 is where we want to start comparing in the query.  pos3 is
   just after where we want to stop comparing in the query, i.e., stop
   at (pos3-1) inclusive */
int
Genome_count_mismatches_fragment (UINT4 query_shifted, UINT4 flags, UINT4 mask,
				  UINT4 ref_fragment, UINT4 alt_fragment) {
  UINT4 diff, alt_diff, compare;

  /* Taken from block_diff, ptr to low */
  debug1(printf("Comparing: query %08X with ref fragment %08X and alt fragment %08X",
		query_shifted,ref_fragment,alt_fragment));
  compare = query_shifted ^ ref_fragment;
  diff = (reduce_nt[compare >> 16] << 8);
  diff |= reduce_nt[compare & 0x0000FFFF];
  debug1(printf(" => ref_diff %08X",diff));

  compare = query_shifted ^ alt_fragment;
  alt_diff = (reduce_nt[compare >> 16] << 8);
  alt_diff |= reduce_nt[compare & 0x0000FFFF];
  debug1(printf(" and alt_diff %08X\n",alt_diff));

  diff &= alt_diff;

  diff |= flags;

  diff &= mask;

  if (diff > 0x0000FFFF) {
    fprintf(stderr,"Problem: diff %08X > FFFF, flags = %08X, mask = %08X\n",diff,flags,mask);
    abort();
  }

#ifdef HAVE_BUILTIN_POPCOUNT
  debug1(printf("nmismatches %08X => %d\n",diff,__builtin_popcount(diff)));
  return __builtin_popcount(diff);
#else
  debug1(printf("nmismatches %08X => %d\n",diff,count_bits[diff]));
  return count_bits[diff];
#endif
}




#ifndef HAVE_BUILTIN_CTZ
static const int
mod_37_bit_position[] = 
  {
    32, 0, 1, 26, 2, 23, 27, 0, 3, 16, 24, 30, 28, 11, 0, 13, 4,
    7, 17, 0, 25, 22, 31, 15, 29, 10, 12, 6, 0, 21, 14, 9, 5,
    20, 8, 19, 18
  };
#endif


static int
mismatches_left (int *mismatch_positions, int max_mismatches, Compress_T query_compress,
		 Genomicpos_T left, int pos5, int pos3, bool plusp, int genestrand) {
  int nmismatches = 0, offset, nshift;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *query_shifted, *ptr, *end;
  UINT4 diff;
#ifdef HAVE_BUILTIN_CTZ
  int relpos;
#else
  UINT4 lowbit;
#endif

  debug(
	printf("\n\n");
	printf("Genome (in mismatches_left):\n");
	Genome_print_blocks(ref_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  offset = -startdiscard + pos5;
  
  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;

  if (endblocki == startblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    while (diff != 0U && nmismatches <= max_mismatches) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_positions[nmismatches++] = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else      
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_positions[nmismatches++] = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
    }
    return nmismatches;

  } else {
    /* Startblock */
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    debug(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    while (diff != 0U && nmismatches <= max_mismatches) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_positions[nmismatches++] = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_positions[nmismatches++] = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
    }
    if (nmismatches > max_mismatches) {
      return nmismatches;
    }

    query_shifted += 3;
    ptr = &(ref_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    offset += 32;
    while (ptr < end) {
      diff = block_diff(query_shifted,ptr,plusp,genestrand);

      while (diff != 0U && nmismatches <= max_mismatches) {
#ifdef HAVE_BUILTIN_CTZ
	mismatch_positions[nmismatches++] = offset + (relpos = __builtin_ctz(diff));
	clear_lowbit(diff,relpos);
#else
	debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
	mismatch_positions[nmismatches++] = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
	diff -= lowbit;
#endif
	debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
      }
      if (nmismatches > max_mismatches) {
	return nmismatches;
      }

      query_shifted += 3;
      ptr += 3;
      offset += 32;
    }

    /* Endblock */
    diff = block_diff(query_shifted,ptr,plusp,genestrand);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    while (diff != 0U && nmismatches <= max_mismatches) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_positions[nmismatches++] = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_positions[nmismatches++] = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
    }
    return nmismatches;
  }

}

/* Returns mismatch_positions[0..max_mismatches] */
static int
mismatches_left_snps (int *mismatch_positions, int max_mismatches, Compress_T query_compress,
		      Genomicpos_T left, int pos5, int pos3, bool plusp, int genestrand) {
  int nmismatches_both = 0, offset, nshift;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *query_shifted, *ref_ptr, *alt_ptr, *end;
  UINT4 diff;
#ifdef HAVE_BUILTIN_CTZ
  int relpos;
#else
  UINT4 lowbit;
#endif

  debug(
	printf("\n\n");
	printf("Genome (in mismatches_left_snps):\n");
	Genome_print_blocks_snp(ref_blocks,snp_blocks,left+pos5,left+pos3);
	printf("\n");
	);


  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  offset = -startdiscard + pos5;
  
  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;

  if (endblocki == startblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in single block */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

    while (diff != 0U && nmismatches_both <= max_mismatches) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_positions[nmismatches_both++] = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else      
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_positions[nmismatches_both++] = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
    }
    return nmismatches_both;

  } else {
    /* Startblock */
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    debug(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in startblock */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

    while (diff != 0U && nmismatches_both <= max_mismatches) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_positions[nmismatches_both++] = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_positions[nmismatches_both++] = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
    }
    if (nmismatches_both > max_mismatches) {
      return nmismatches_both;
    }

    query_shifted += 3;
    ref_ptr = &(ref_blocks[startblocki+3]);
    alt_ptr = &(snp_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    offset += 32;
    while (ref_ptr < end) {
      diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

      if (*(alt_ptr+2)) {
	/* SNPs present in middle block */
	diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
      }

      while (diff != 0U && nmismatches_both <= max_mismatches) {
#ifdef HAVE_BUILTIN_CTZ
	mismatch_positions[nmismatches_both++] = offset + (relpos = __builtin_ctz(diff));
	clear_lowbit(diff,relpos);
#else
	debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
	mismatch_positions[nmismatches_both++] = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
	diff -= lowbit;
#endif
	debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
      }
      if (nmismatches_both > max_mismatches) {
	return nmismatches_both;
      }

      query_shifted += 3;
      ref_ptr += 3;
      alt_ptr += 3;
      offset += 32;
    }

    /* Endblock */
    diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    if (*(alt_ptr+2)) {
      /* SNPs present in middle block */
      diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
    }

    while (diff != 0U && nmismatches_both <= max_mismatches) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_positions[nmismatches_both++] = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_positions[nmismatches_both++] = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
    }
    return nmismatches_both;
  }

}



/* Returns mismatch_positions[0..nmismatches], where nmismatches <= max_mismatches + 1 */
/* If request max_mismatches 3, could return m0, m1, m2, m3, m4 */
int
Genome_mismatches_left (int *mismatch_positions, int max_mismatches, Compress_T query_compress,
			Genomicpos_T left, int pos5, int pos3, bool plusp, int genestrand) {
  int nmismatches;
#ifdef DEBUG
  int i;
#endif

#if 0
  if (dibasep) {
    debug(printf("Dibase_mismatches_left from %u+%d to %u+%d:\n",left,pos5,left,pos3));

    nmismatches = Dibase_mismatches_left(&(*mismatch_positions),&(*colordiffs),max_mismatches,query,
					 pos5,pos3,/*startpos*/left+pos5,/*endpos*/left+pos3);
    mismatch_positions[nmismatches] = pos3 + 1;	/* Need +1 because of starting assumed nt */

  }
#endif

  if (snp_blocks == NULL) {
    nmismatches = mismatches_left(&(*mismatch_positions),max_mismatches,query_compress,
				  left,pos5,pos3,plusp,genestrand);
    mismatch_positions[nmismatches] = pos3;
  } else {
    nmismatches = mismatches_left_snps(&(*mismatch_positions),max_mismatches,query_compress,
				       left,pos5,pos3,plusp,genestrand);
    mismatch_positions[nmismatches] = pos3;
  }
  debug(
	printf("%d mismatches on left: ",nmismatches);
	for (i = 0; i <= nmismatches; i++) {
	  printf("%d ",mismatch_positions[i]);
	}
	printf("\n");
	);
  
  return nmismatches;
}

static int
mismatches_right (int *mismatch_positions, int max_mismatches, Compress_T query_compress,
		  Genomicpos_T left, int pos5, int pos3, bool plusp, int genestrand) {
  int nmismatches = 0, offset, relpos, nshift;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *query_shifted, *start, *ptr;
  UINT4 diff;
#ifndef HAVE_BUILTIN_CLZ
  UINT4 top;
#endif

  debug(
	printf("\n\n");
	printf("Genome (in mismatches_right):\n");
	Genome_print_blocks(ref_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  offset = (pos3 - 1) - enddiscard + 32;
  
  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u, offset = %d\n",
	       nshift,startdiscard,enddiscard,offset));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos3)/32U*3;

  if (startblocki == endblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    while (diff != 0U && nmismatches <= max_mismatches) {
#ifdef HAVE_BUILTIN_CLZ
      mismatch_positions[nmismatches++] = offset - (relpos = __builtin_clz(diff));
#else
      mismatch_positions[nmismatches++] = offset - (relpos = ((top = diff >> 16) ? clz_table[top] : 16 + clz_table[diff]));
#endif
      debug(printf("diff is %08X => offset %d - relpos %d\n",diff,offset,relpos));
      clear_highbit(diff,relpos);
    }
    return nmismatches;

  } else {
    /* Endblock */
    diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    while (diff != 0U && nmismatches <= max_mismatches) {
#ifdef HAVE_BUILTIN_CLZ
      mismatch_positions[nmismatches++] = offset - (relpos = __builtin_clz(diff));
#else
      mismatch_positions[nmismatches++] = offset - (relpos = (top = diff >> 16) ? clz_table[top] : 16 + clz_table[diff]);
#endif
      debug(printf("diff is %08X => offset %d - relpos %d\n",diff,offset,relpos));
      clear_highbit(diff,relpos);
    }
    if (nmismatches > max_mismatches) {
      return nmismatches;
    }

    query_shifted -= 3;
    ptr = &(ref_blocks[endblocki-3]);
    start = &(ref_blocks[startblocki]);
    offset -= 32;
    while (ptr > start) {
      diff = block_diff(query_shifted,ptr,plusp,genestrand);

      while (diff != 0U && nmismatches <= max_mismatches) {
#ifdef HAVE_BUILTIN_CLZ
	mismatch_positions[nmismatches++] = offset - (relpos = __builtin_clz(diff));
#else
	mismatch_positions[nmismatches++] = offset - (relpos = (top = diff >> 16) ? clz_table[top] : 16 + clz_table[diff]);
#endif
	debug(printf("diff is %08X => offset %d - relpos %d\n",diff,offset,relpos));
	clear_highbit(diff,relpos);
      }
      if (nmismatches > max_mismatches) {
	return nmismatches;
      }

      query_shifted -= 3;
      ptr -= 3;
      offset -= 32;
    }

    /* Startblock */
    diff = block_diff(query_shifted,ptr,plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));

    while (diff != 0U && nmismatches <= max_mismatches) {
#ifdef HAVE_BUILTIN_CLZ
      mismatch_positions[nmismatches++] = offset - (relpos = __builtin_clz(diff));
#else
      mismatch_positions[nmismatches++] = offset - (relpos = (top = diff >> 16) ? clz_table[top] : 16 + clz_table[diff]);
#endif
      debug(printf("diff is %08X => offset %d - relpos %d\n",diff,offset,relpos));
      clear_highbit(diff,relpos);
    }

    return nmismatches;
  }
}


static int
mismatches_right_snps (int *mismatch_positions, int max_mismatches, Compress_T query_compress,
		       Genomicpos_T left, int pos5, int pos3, bool plusp, int genestrand) {
  int nmismatches_both = 0, offset, relpos, nshift;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *query_shifted, *ref_ptr, *alt_ptr, *start;
  UINT4 diff;
#ifndef HAVE_BUILTIN_CLZ
  UINT4 top;
#endif

  debug(
	printf("\n\n");
	printf("Genome (in mismatches_right_snps):\n");
	Genome_print_blocks_snp(ref_blocks,snp_blocks,left+pos5,left+pos3);
	printf("\n");
	);


  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  offset = (pos3 - 1) - enddiscard + 32;
  
  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u, offset = %d\n",
	       nshift,startdiscard,enddiscard,offset));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos3)/32U*3;

  if (startblocki == endblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    if (snp_blocks[endblocki+2]) {
      /* SNPs present in single block */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[endblocki]),&(snp_blocks[endblocki]),plusp,genestrand);
    }

    while (diff != 0U && nmismatches_both <= max_mismatches) {
#ifdef HAVE_BUILTIN_CLZ
      mismatch_positions[nmismatches_both++] = offset - (relpos = __builtin_clz(diff));
#else
      mismatch_positions[nmismatches_both++] = offset - (relpos = (top = diff >> 16) ? clz_table[top] : 16 + clz_table[diff]);
#endif
      debug(printf("diff is %08X => offset %d - relpos %d\n",diff,offset,relpos));
      clear_highbit(diff,relpos);
    }
    return nmismatches_both;

  } else {
    /* Endblock */
    diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    if (snp_blocks[endblocki+2]) {
      /* SNPs present in endblock */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[endblocki]),&(snp_blocks[endblocki]),plusp,genestrand);
    }

    while (diff != 0U && nmismatches_both <= max_mismatches) {
#ifdef HAVE_BUILTIN_CLZ
      mismatch_positions[nmismatches_both++] = offset - (relpos = __builtin_clz(diff));
#else
      mismatch_positions[nmismatches_both++] = offset - (relpos = (top = diff >> 16) ? clz_table[top] : 16 + clz_table[diff]);
#endif
      debug(printf("diff is %08X => offset %d - relpos %d\n",diff,offset,relpos));
      clear_highbit(diff,relpos);
    }
    if (nmismatches_both > max_mismatches) {
      return nmismatches_both;
    }

    query_shifted -= 3;
    ref_ptr = &(ref_blocks[endblocki-3]);
    alt_ptr = &(snp_blocks[endblocki-3]);
    start = &(ref_blocks[startblocki]);
    offset -= 32;
    while (ref_ptr > start) {
      diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

      if (*(alt_ptr+2)) {
	/* SNPs present in middle block */
	diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
      }

      while (diff != 0U && nmismatches_both <= max_mismatches) {
#ifdef HAVE_BUILTIN_CLZ
	mismatch_positions[nmismatches_both++] = offset - (relpos = __builtin_clz(diff));
#else
	mismatch_positions[nmismatches_both++] = offset - (relpos = (top = diff >> 16) ? clz_table[top] : 16 + clz_table[diff]);
#endif
	debug(printf("diff is %08X => offset %d - relpos %d\n",diff,offset,relpos));
	clear_highbit(diff,relpos);
      }
      if (nmismatches_both > max_mismatches) {
	return nmismatches_both;
      }

      query_shifted -= 3;
      ref_ptr -= 3;
      alt_ptr -= 3;
      offset -= 32;
    }

    /* Startblock */
    diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    debug(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    if (*(alt_ptr+2)) {
      /* SNPs present in start block */
      diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
    }

    while (diff != 0U && nmismatches_both <= max_mismatches) {
#ifdef HAVE_BUILTIN_CLZ
      mismatch_positions[nmismatches_both++] = offset - (relpos = __builtin_clz(diff));
#else
      mismatch_positions[nmismatches_both++] = offset - (relpos = (top = diff >> 16) ? clz_table[top] : 16 + clz_table[diff]);
#endif
      debug(printf("diff is %08X => offset %d - relpos %d\n",diff,offset,relpos));
      clear_highbit(diff,relpos);
    }

    return nmismatches_both;
  }

}


/* Returns mismatch_positions[0..nmismatches], where nmismatches <= max_mismatches */
int
Genome_mismatches_right (int *mismatch_positions, int max_mismatches, Compress_T query_compress,
			 Genomicpos_T left, int pos5, int pos3, bool plusp, int genestrand) {
  int nmismatches;
#ifdef DEBUG
  int i;
#endif

#if 0
  if (dibasep) {
    debug(printf("Dibase_mismatches_right from %u+%d to %u+%d:\n",left,pos5,left,pos3));

    nmismatches = Dibase_mismatches_right(&(*mismatch_positions),&(*colordiffs),max_mismatches,query,
					  pos5,pos3,/*startpos*/left+pos5,/*endpos*/left+pos3);
  }
#endif

  if (snp_blocks == NULL) {
    nmismatches = mismatches_right(&(*mismatch_positions),max_mismatches,query_compress,
				   left,pos5,pos3,plusp,genestrand);
  } else {
    nmismatches = mismatches_right_snps(&(*mismatch_positions),max_mismatches,query_compress,
					left,pos5,pos3,plusp,genestrand);
  }
  mismatch_positions[nmismatches] = -1;
  debug(
	printf("%d mismatches on right: ",nmismatches);
	for (i = 0; i <= nmismatches; i++) {
	  printf("%d ",mismatch_positions[i]);
	}
	printf("\n");
	);
  return nmismatches;
}


/************************************************************************
 *  Marking
 ************************************************************************/

/* Derived from mismatches_left() */
int
Genome_mark_mismatches_ref (char *genomic, int querylength, Compress_T query_compress,
			    Genomicpos_T left, int pos5, int pos3, int mismatch_offset,
			    bool plusp, int genestrand) {
  int mismatch_position;
  int nmismatches = 0, offset, nshift;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *query_shifted, *ptr, *end;
  UINT4 diff;
#ifdef HAVE_BUILTIN_CTZ
  int relpos;
#else
  UINT4 lowbit;
#endif

  debug(
	printf("\n\n");
	printf("genomic = %s\n",genomic);
	printf("Genome (in mark_mismatches_ref):\n");
	Genome_print_blocks(ref_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  if (plusp == true) {
    offset = -startdiscard + pos5 + mismatch_offset;
  } else {
    offset = -startdiscard + pos5 - mismatch_offset;
  }
  
  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;

  if (endblocki == startblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    while (diff != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_position = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else      
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_position = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
      if (plusp == false) {
	mismatch_position = (querylength - 1) - mismatch_position;
      }
      genomic[mismatch_position] = tolower(genomic[mismatch_position]);
      nmismatches++;
    }
    debug(printf("genomic = %s\n",genomic));
    return nmismatches;

  } else {
    /* Startblock */
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    debug(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    while (diff != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_position = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_position = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
      if (plusp == false) {
	mismatch_position = (querylength - 1) - mismatch_position;
      }
      genomic[mismatch_position] = tolower(genomic[mismatch_position]);
      nmismatches++;
    }

    query_shifted += 3;
    ptr = &(ref_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    offset += 32;
    while (ptr < end) {
      diff = block_diff(query_shifted,ptr,plusp,genestrand);

      while (diff != 0U) {
#ifdef HAVE_BUILTIN_CTZ
	mismatch_position = offset + (relpos = __builtin_ctz(diff));
	clear_lowbit(diff,relpos);
#else
	debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
	mismatch_position = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
	diff -= lowbit;
#endif
	debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
	if (plusp == false) {
	  mismatch_position = (querylength - 1) - mismatch_position;
	}
	genomic[mismatch_position] = tolower(genomic[mismatch_position]);
	nmismatches++;
      }

      query_shifted += 3;
      ptr += 3;
      offset += 32;
    }

    /* Endblock */
    diff = block_diff(query_shifted,ptr,plusp,genestrand);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    while (diff != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_position = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_position = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
      if (plusp == false) {
	mismatch_position = (querylength - 1) - mismatch_position;
      }
      genomic[mismatch_position] = tolower(genomic[mismatch_position]);
      nmismatches++;
    }
    debug(printf("genomic = %s\n",genomic));
    return nmismatches;
  }

}

/* Derived from mismatches_left_snps() */
static int
mark_mismatches_snps (char *genomic, int querylength, Compress_T query_compress,
		      Genomicpos_T left, int pos5, int pos3, int mismatch_offset, bool plusp, int genestrand) {
  int mismatch_position;
  int nmismatches_both = 0, offset, nshift;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *query_shifted, *ref_ptr, *alt_ptr, *end;
  UINT4 diff;
#ifdef HAVE_BUILTIN_CTZ
  int relpos;
#else
  UINT4 lowbit;
#endif

  debug(
	printf("\n\n");
	printf("genomic = %s\n",genomic);
	printf("Genome (in mark_mismatches_snps):\n");
	Genome_print_blocks_snp(ref_blocks,snp_blocks,left+pos5,left+pos3);
	printf("\n");
	);


  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  if (plusp == true) {
    offset = -startdiscard + pos5 + mismatch_offset;
  } else {
    offset = -startdiscard + pos5 - mismatch_offset;
  }
  
  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;

  if (endblocki == startblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in single block */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

    while (diff != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_position = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else      
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_position = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
      if (plusp == false) {
	mismatch_position = (querylength - 1) - mismatch_position;
      }
      genomic[mismatch_position] = tolower(genomic[mismatch_position]);
      nmismatches_both++;
    }
    debug(printf("genomic = %s\n",genomic));
    return nmismatches_both;

  } else {
    /* Startblock */
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard);
    debug(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in startblock */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

    while (diff != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_position = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_position = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
      if (plusp == false) {
	mismatch_position = (querylength - 1) - mismatch_position;
      }
      genomic[mismatch_position] = tolower(genomic[mismatch_position]);
      nmismatches_both++;
    }

    query_shifted += 3;
    ref_ptr = &(ref_blocks[startblocki+3]);
    alt_ptr = &(snp_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    offset += 32;
    while (ref_ptr < end) {
      diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

      if (*(alt_ptr+2)) {
	/* SNPs present in middle block */
	diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
      }

      while (diff != 0U) {
#ifdef HAVE_BUILTIN_CTZ
	mismatch_position = offset + (relpos = __builtin_ctz(diff));
	clear_lowbit(diff,relpos);
#else
	debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
	mismatch_position = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
	diff -= lowbit;
#endif
	debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
	if (plusp == false) {
	  mismatch_position = (querylength - 1) - mismatch_position;
	}
	genomic[mismatch_position] = tolower(genomic[mismatch_position]);
	nmismatches_both++;
      }

      query_shifted += 3;
      ref_ptr += 3;
      alt_ptr += 3;
      offset += 32;
    }

    /* Endblock */
    diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);
    diff = clear_end(diff,enddiscard);
    debug(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    if (*(alt_ptr+2)) {
      /* SNPs present in middle block */
      diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
    }

    while (diff != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      mismatch_position = offset + (relpos = __builtin_ctz(diff));
      clear_lowbit(diff,relpos);
#else
      debug(printf("diff is %08X, -diff & diff is %08X\n",diff,-diff & diff));
      mismatch_position = offset + mod_37_bit_position[(lowbit = -diff & diff) % 37];
      diff -= lowbit;
#endif
      debug(printf("diff is %08X => offset %d + relpos %d\n",diff,offset,relpos));
      if (plusp == false) {
	mismatch_position = (querylength - 1) - mismatch_position;
      }
      genomic[mismatch_position] = tolower(genomic[mismatch_position]);
      nmismatches_both++;
    }
    debug(printf("genomic = %s\n",genomic));
    return nmismatches_both;
  }

}


int
Genome_mark_mismatches (char *genomic, int querylength, Compress_T query_compress,
			Genomicpos_T left, int pos5, int pos3, int mismatch_offset, bool plusp, int genestrand) {

#if 0
  if (dibasep) {
    fprintf(stderr,"Not implemented\n");
#if 0
    debug(printf("Dibase_mismatches_left from %u+%d to %u+%d:\n",left,pos5,left,pos3));

    nmismatches = Dibase_mismatches_left(&(*mismatch_positions),&(*colordiffs),max_mismatches,query,
					 pos5,pos3,/*startpos*/left+pos5,/*endpos*/left+pos3);
    mismatch_positions[nmismatches] = pos3 + 1;	/* Need +1 because of starting assumed nt */
#endif
    return 0;
  }
#endif

  if (snp_blocks == NULL) {
    return Genome_mark_mismatches_ref(&(*genomic),querylength,query_compress,
				      left,pos5,pos3,mismatch_offset,plusp,genestrand);
  } else {
    return mark_mismatches_snps(&(*genomic),querylength,query_compress,
				left,pos5,pos3,mismatch_offset,plusp,genestrand);
  }
}


/************************************************************************
 *  Trimming
 ************************************************************************/

#define set_start(diff,startdiscard) (diff | ~(~0U << startdiscard))
#define set_end(diff,enddiscard) (diff | (~0U << enddiscard))

#define set_start_mask(startdiscard) (~(~0U << startdiscard))
#define set_end_mask(enddiscard) (~0U << enddiscard)

static int
trim_left_substring (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3,
		     bool plusp, int genestrand) {
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ptr, *start;
  UINT4 *query_shifted;
  UINT4 diff;
  int nshift;

  int totalscore, bestscore, score;
  int trimpos, offset;
  UINT4 p;

  debug(
	printf("\n\n");
	printf("Genome (in trim_left_substring) from %u+%d to %u+%d:\n",left,pos5,left,pos3);
	Genome_print_blocks(ref_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  offset = (pos3 - 1) - enddiscard + 32;

  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u, offset = %d\n",
	       nshift,startdiscard,enddiscard,offset));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos3)/32U*3;


  if (startblocki == endblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);
    diff = clear_end(diff,enddiscard); /* puts 0 (matches) at end */
    diff = set_start(diff,startdiscard);  /* puts 1 (mismatches) at start */
    debug(printf("adding masks %08X and %08x\n",clear_end_mask(enddiscard),set_start_mask(startdiscard)));

    p = 3*(diff >> 16);
    bestscore = score_high[p];
    trimpos = offset - score_high[p+1];
    totalscore = score_high[p+2];
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset -= 16;

    p = 3*(diff & 0x0000FFFF);
    if ((score = score_high[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset - score_high[p+1];
    }
    /* totalscore += score_high[p+2]; */
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    /* offset -= 16 */
    
    return trimpos - 1;		/* trimpos-1 is on side of mismatch */

  } else {
    /* Endblock */
    diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);
    diff = clear_end(diff,enddiscard); /* puts 0 (matches) at end */
    debug(printf("adding end mask %08X\n",clear_end_mask(enddiscard)));

    p = 3*(diff >> 16);
    bestscore = score_high[p];
    trimpos = offset - score_high[p+1];
    totalscore = score_high[p+2];
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset -= 16;

    p = 3*(diff & 0x0000FFFF);
    if ((score = score_high[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset - score_high[p+1];
    }
    totalscore += score_high[p+2];
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset -= 16;

    query_shifted -= 3;
    ptr = &(ref_blocks[endblocki-3]);
    start = &(ref_blocks[startblocki]);
    while (ptr > start) {
      diff = block_diff(query_shifted,ptr,plusp,genestrand);

      p = 3*(diff >> 16);
      if ((score = score_high[p] + totalscore) > bestscore) {
	bestscore = score;
	trimpos = offset - score_high[p+1];
      }
      totalscore += score_high[p+2];
      debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		   diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
      offset -= 16;

      p = 3*(diff & 0x0000FFFF);
      if ((score = score_high[p] + totalscore) > bestscore) {
	bestscore = score;
	trimpos = offset - score_high[p+1];
      }
      totalscore += score_high[p+2];
      debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		   diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
      offset -= 16;


      query_shifted -= 3;
      ptr -= 3;
    }

    /* Startblock */
    diff = block_diff(query_shifted,ptr,plusp,genestrand);
    diff = set_start(diff,startdiscard); /* puts 1 (mismatches) at start */
    debug(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    p = 3*(diff >> 16);
    if ((score = score_high[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset - score_high[p+1];
    }
    totalscore += score_high[p+2];
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset -= 16;

    p = 3*(diff & 0x0000FFFF);
    if ((score = score_high[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset - score_high[p+1];
    }
    /* totalscore += score_high[p+2]; */
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    /* offset -= 16; */
    
    return trimpos - 1;		/* trimpos-1 is on side of mismatch */
  }
}


static int
trim_left_substring_snps (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3, bool plusp, int genestrand) {
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ref_ptr, *alt_ptr, *start;
  UINT4 *query_shifted;
  UINT4 diff;
  int nshift;

  int totalscore, bestscore, score;
  int trimpos, offset;
  UINT4 p;

  debug(
	printf("\n\n");
	printf("Genome (in trim_left_substring_snps) from %u+%d to %u+%d:\n",left,pos5,left,pos3);
	Genome_print_blocks_snp(ref_blocks,snp_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  offset = (pos3 - 1) - enddiscard + 32;

  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u, offset = %d\n",
	       nshift,startdiscard,enddiscard,offset));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos3)/32U*3;
  
  if (startblocki == endblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);

    if (snp_blocks[endblocki+2]) {
      /* SNPs present in single block */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[endblocki]),&(snp_blocks[endblocki]),plusp,genestrand);
    }

    diff = clear_end(diff,enddiscard); /* puts 0 (matches) at end */
    diff = set_start(diff,startdiscard);  /* puts 1 (mismatches) at start */
    debug(printf("adding masks %08X and %08x\n",clear_end_mask(enddiscard),set_start_mask(startdiscard)));

    p = 3*(diff >> 16);
    bestscore = score_high[p];
    trimpos = offset - score_high[p+1];
    totalscore = score_high[p+2];
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset -= 16;

    p = 3*(diff & 0x0000FFFF);
    if ((score = score_high[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset - score_high[p+1];
    }
    /* totalscore += score_high[p+2]; */
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    /* offset -= 16; */
    
    return trimpos - 1;		/* trimpos-1 is on side of mismatch */

  } else {
    /* Endblock */
    diff = block_diff(query_shifted,&(ref_blocks[endblocki]),plusp,genestrand);

    if (snp_blocks[endblocki+2]) {
      /* SNPs present in endblock */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[endblocki]),&(snp_blocks[endblocki]),plusp,genestrand);
    }

    diff = clear_end(diff,enddiscard); /* puts 0 (matches) at end */
    debug(printf("adding end mask %08X\n",clear_end_mask(enddiscard)));

    p = 3*(diff >> 16);
    bestscore = score_high[p];
    trimpos = offset - score_high[p+1];
    totalscore = score_high[p+2];
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset -= 16;

    p = 3*(diff & 0x0000FFFF);
    if ((score = score_high[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset - score_high[p+1];
    }
    totalscore += score_high[p+2];
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset -= 16;


    query_shifted -= 3;
    ref_ptr = &(ref_blocks[endblocki-3]);
    alt_ptr = &(snp_blocks[endblocki-3]);
    start = &(ref_blocks[startblocki]);
    while (ref_ptr > start) {
      diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

      if (*(alt_ptr+2)) {
	/* SNPs present in middle block */
	diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
      }

      p = 3*(diff >> 16);
      if ((score = score_high[p] + totalscore) > bestscore) {
	bestscore = score;
	trimpos = offset - score_high[p+1];
      }
      totalscore += score_high[p+2];
      debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		   diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
      offset -= 16;

      p = 3*(diff & 0x0000FFFF);
      if ((score = score_high[p] + totalscore) > bestscore) {
	bestscore = score;
	trimpos = offset - score_high[p+1];
      }
      totalscore += score_high[p+2];
      debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		   diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
      offset -= 16;


      query_shifted -= 3;
      ref_ptr -= 3;
      alt_ptr -= 3;
    }

    /* Startblock */
    diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

    if (*(alt_ptr+2)) {
      /* SNPs present in startblock */
      diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
    }

    diff = set_start(diff,startdiscard); /* puts 1 (mismatches) at start */
    debug(printf("adding start mask %08x\n",set_start_mask(startdiscard)));

    p = 3*(diff >> 16);
    if ((score = score_high[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset - score_high[p+1];
    }
    totalscore += score_high[p+2];
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset -= 16;

    p = 3*(diff & 0x0000FFFF);
    if ((score = score_high[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset - score_high[p+1];
    }
    /* totalscore += score_high[p+2]; */
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    /* offset -= 16; */

    return trimpos - 1;		/* trimpos-1 is on side of mismatch */
  }
}




static int
trim_right_substring (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3,
		      bool plusp, int genestrand) {
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ptr, *end;
  UINT4 *query_shifted;
  UINT4 diff;
  int nshift;

  int totalscore, bestscore, score;
  int trimpos, offset;
  UINT4 p;

  debug(
	printf("\n\n");
	printf("Genome (in trim_right_substring) from %u+%d to %u+%d:\n",left,pos5,left,pos3);
	Genome_print_blocks(ref_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  offset = -startdiscard + pos5;
  
  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;


  if (endblocki == startblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard); /* puts 0 (matches) at start */
    diff = set_end(diff,enddiscard);  /* puts 1 (mismatches) at end */
    debug(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),set_end_mask(enddiscard)));

    p = 3*(diff & 0x0000FFFF);
    bestscore = score_low[p];
    trimpos = offset + score_low[p+1];
    totalscore = score_low[p+2];
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset += 16;

    p = 3*(diff >> 16);
    if ((score = score_low[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset + score_low[p+1];
    }
    /* totalscore += score_low[p+2]; */
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    /* offset += 16; */
    
    return trimpos + 1;		/* trimpos+1 is on side of mismatch */

  } else {
    /* Startblock */
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);
    diff = clear_start(diff,startdiscard); /* puts 0 (matches) at start */
    debug(printf("clearing start %08X\n",clear_start_mask(startdiscard)));

    p = 3*(diff & 0x0000FFFF);
    bestscore = score_low[p];
    trimpos = offset + score_low[p+1];
    totalscore = score_low[p+2];
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset += 16;

    p = 3*(diff >> 16);
    if ((score = score_low[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset + score_low[p+1];
    }
    totalscore += score_low[p+2];
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset += 16;


    query_shifted += 3;
    ptr = &(ref_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    while (ptr < end) {
      diff = block_diff(query_shifted,ptr,plusp,genestrand);

      p = 3*(diff & 0x0000FFFF);
      if ((score = score_low[p] + totalscore) > bestscore) {
	bestscore = score;
	trimpos = offset + score_low[p+1];
      }
      totalscore += score_low[p+2];
      debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		   diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
      offset += 16;

      p = 3*(diff >> 16);
      if ((score = score_low[p] + totalscore) > bestscore) {
	bestscore = score;
	trimpos = offset + score_low[p+1];
      }
      totalscore += score_low[p+2];
      debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		   diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
      offset += 16;


      query_shifted += 3;
      ptr += 3;
    }

    /* Endblock */
    diff = block_diff(query_shifted,ptr,plusp,genestrand);
    diff = set_end(diff,enddiscard); /* puts 1 (mismatches) at end */
    debug(printf("adding end mask %08X\n",~0U << enddiscard));

    p = 3*(diff & 0x0000FFFF);
    if ((score = score_low[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset + score_low[p+1];
    }
    totalscore += score_low[p+2];
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset += 16;

    p = 3*(diff >> 16);
    if ((score = score_low[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset + score_low[p+1];
    }
    /* totalscore += score_low[p+2]; */
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    /* offset += 16; */
    
    return trimpos + 1;		/* trimpos+1 is on side of mismatch */
  }
}



static int
trim_right_substring_snps (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3, bool plusp, int genestrand) {
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ref_ptr, *alt_ptr, *end;
  UINT4 *query_shifted;
  UINT4 diff;
  int nshift;

  int totalscore, bestscore, score;
  int trimpos, offset;
  UINT4 p;

  debug(
	printf("\n\n");
	printf("Genome (in trim_right_substring_snps) from %u+%d to %u+%d:\n",left,pos5,left,pos3);
	Genome_print_blocks_snp(ref_blocks,snp_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  nshift = left % 32;

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  offset = -startdiscard + pos5;
  
  debug(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug(printf("nshift = %d, startdiscard = %u, enddiscard = %u\n",nshift,startdiscard,enddiscard));

  query_shifted = Compress_shift(query_compress,nshift);
  debug(printf("Query shifted %d:\n",nshift));
  debug(print_blocks(query_shifted,Compress_nblocks(query_compress)+1));
  query_shifted += (nshift+pos5)/32U*3;
  
  if (endblocki == startblocki) {
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in single block */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

    diff = clear_start(diff,startdiscard); /* puts 0 (matches) at start */
    diff = set_end(diff,enddiscard);  /* puts 1 (mismatches) at end */
    debug(printf("adding masks %08X and %08X\n",clear_start_mask(startdiscard),set_end_mask(enddiscard)));

    p = 3*(diff & 0x0000FFFF);
    bestscore = score_low[p];
    trimpos = offset + score_low[p+1];
    totalscore = score_low[p+2];
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset += 16;

    p = 3*(diff >> 16);
    if ((score = score_low[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset + score_low[p+1];
    }
    /* totalscore += score_low[p+2]; */
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    /* offset += 16; */
    
    return trimpos + 1;		/* trimpos+1 is on side of mismatch */

  } else {
    /* Startblock */
    diff = block_diff(query_shifted,&(ref_blocks[startblocki]),plusp,genestrand);

    if (snp_blocks[startblocki+2]) {
      /* SNPs present in startblock */
      diff &= block_diff_snp(query_shifted,&(ref_blocks[startblocki]),&(snp_blocks[startblocki]),plusp,genestrand);
    }

    diff = clear_start(diff,startdiscard); /* puts 0 (matches) at start */
    debug(printf("adding start mask %08X\n",clear_start_mask(startdiscard)));

    p = 3*(diff & 0x0000FFFF);
    bestscore = score_low[p];
    trimpos = offset + score_low[p+1];
    totalscore = score_low[p+2];
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset += 16;

    p = 3*(diff >> 16);
    if ((score = score_low[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset + score_low[p+1];
    }
    totalscore += score_low[p+2];
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset += 16;


    query_shifted += 3;
    ref_ptr = &(ref_blocks[startblocki+3]);
    alt_ptr = &(snp_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    while (ref_ptr < end) {
      diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

      if (*(alt_ptr+2)) {
	/* SNPs present in middle block */
	diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
      }

      p = 3*(diff & 0x0000FFFF);
      if ((score = score_low[p] + totalscore) > bestscore) {
	bestscore = score;
	trimpos = offset + score_low[p+1];
      }
      totalscore += score_low[p+2];
      debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		   diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
      offset += 16;

      p = 3*(diff >> 16);
      if ((score = score_low[p] + totalscore) > bestscore) {
	bestscore = score;
	trimpos = offset + score_low[p+1];
      }
      totalscore += score_low[p+2];
      debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		   diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
      offset += 16;


      query_shifted += 3;
      ref_ptr += 3;
      alt_ptr += 3;
    }

    /* Endblock */
    diff = block_diff(query_shifted,ref_ptr,plusp,genestrand);

    if (*(alt_ptr+2)) {
      /* SNPs present in endblock */
      diff &= block_diff_snp(query_shifted,ref_ptr,alt_ptr,plusp,genestrand);
    }

    diff = set_end(diff,enddiscard); /* puts 1 (mismatches) at end */
    debug(printf("adding end mask %08X\n",set_end_mask(enddiscard)));

    p = 3*(diff & 0x0000FFFF);
    if ((score = score_low[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset + score_low[p+1];
    }
    totalscore += score_low[p+2];
    debug(printf("diff low %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff & 0x0000FFFF,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    offset += 16;

    p = 3*(diff >> 16);
    if ((score = score_low[p] + totalscore) > bestscore) {
      bestscore = score;
      trimpos = offset + score_low[p+1];
    }
    /* totalscore += score_low[p+2]; */
    debug(printf("diff high %04X => bestscore %d at pos %d, offset %d, trimpos %d, totalscore %d\n",
		 diff >> 16,score_high[p],score_high[p+1],offset,trimpos,totalscore));
    /* offset += 16; */

    return trimpos + 1;		/* trimpos+1 is on side of mismatch */
  }
}


int
Genome_trim_left (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3,
		  bool plusp, int genestrand) {
#if 0
  if (dibasep) {
    /* Not implemented */
    return 0;
  }
#endif

  if (snp_blocks == NULL) {
    return trim_left_substring(query_compress,left,pos5,pos3,plusp,genestrand);
  } else {
    return trim_left_substring_snps(query_compress,left,pos5,pos3,plusp,genestrand);
  }
}

int
Genome_trim_right (Compress_T query_compress, Genomicpos_T left, int pos5, int pos3,
		   bool plusp, int genestrand) {
#if 0
  if (dibasep) {
    /* Not implemented */
    return 0;
  }
#endif

  if (snp_blocks == NULL) {
    return trim_right_substring(query_compress,left,pos5,pos3,plusp,genestrand);
  } else {
    return trim_right_substring_snps(query_compress,left,pos5,pos3,plusp,genestrand);
  }
}



/* Not tested yet */
char
Genome_get_dinucleotide (char *altdinucl, Genomicpos_T pos) {
  /* Genomicpos_T length = endpos - startpos; */
  char refdinucl;
  Genomicpos_T shift, ptr;
  UINT4 high, low;

  ptr = pos/32*3;
  shift = pos % 32;

  if (shift < 15) {
#ifdef WORDS_BIGENDIAN
    low = Bigendian_convert_uint(ref_blocks[ptr+1]);
#else
    low = ref_blocks[ptr+1];
#endif
    refdinucl = (char) ((low >> (shift+shift)) & 0x0F);

    if (snp_blocks == NULL) {
      *altdinucl = refdinucl;
    } else {
#ifdef WORDS_BIGENDIAN
      low = Bigendian_convert_uint(snp_blocks[ptr+1]);
#else
      low = snp_blocks[ptr+1];
#endif
      *altdinucl = (char) ((low >> (shift+shift)) & 0x0F);
    }

  } else if (shift == 15) {
#ifdef WORDS_BIGENDIAN
    high = Bigendian_convert_uint(ref_blocks[ptr]);
    low = Bigendian_convert_uint(ref_blocks[ptr+1]);
#else
    high = ref_blocks[ptr]; low = ref_blocks[ptr+1];
#endif
    refdinucl = (char) (((low >> 30) | (high << 2)) & 0x0F);

    if (snp_blocks == NULL) {
      *altdinucl = refdinucl;
    } else {
#ifdef WORDS_BIGENDIAN
      high = Bigendian_convert_uint(snp_blocks[ptr]);
      low = Bigendian_convert_uint(snp_blocks[ptr+1]);
#else
      high = snp_blocks[ptr]; low = snp_blocks[ptr+1];
#endif
      *altdinucl = (char) (((low >> 30) | (high << 2)) & 0x0F);
    }
    
  } else if (shift < 31) {
#ifdef WORDS_BIGENDIAN
    high = Bigendian_convert_uint(ref_blocks[ptr]);
#else
    high = ref_blocks[ptr];
#endif
    shift -= 16;
    refdinucl = (char) ((high >> (shift+shift)) & 0x0F);

    if (snp_blocks == NULL) {
      *altdinucl = refdinucl;
    } else {
#ifdef WORDS_BIGENDIAN
      high = Bigendian_convert_uint(snp_blocks[ptr]);
#else
      high = snp_blocks[ptr];
#endif
      shift -= 16;
      *altdinucl = (char) ((high >> (shift+shift)) & 0x0F);
    }
      
  } else {
    /* shift == 31 */
#ifdef WORDS_BIGENDIAN
    high = Bigendian_convert_uint(ref_blocks[ptr]);
    low = Bigendian_convert_uint(ref_blocks[ptr+4]);
#else
    high = ref_blocks[ptr]; low = ref_blocks[ptr+4];
#endif
    refdinucl = (char) (((high >> 30) | (low << 2)) & 0x0F);

    if (snp_blocks == NULL) {
      *altdinucl = refdinucl;
    } else {
#ifdef WORDS_BIGENDIAN
      high = Bigendian_convert_uint(snp_blocks[ptr]);
      low = Bigendian_convert_uint(snp_blocks[ptr+4]);
#else
      high = snp_blocks[ptr]; low = snp_blocks[ptr+4];
#endif
      *altdinucl = (char) (((high >> 30) | (low << 2)) & 0x0F);
    }

  }

  return refdinucl;
}


/************************************************************************
 *   Splice sites
 ************************************************************************/


static UINT4
block_find (UINT4 *high_halfsite, UINT4 *low_halfsite, UINT4 *ptr, const UINT4 *splicesite_bits) {
  UINT4 found, compare, flags;

  /* High */
  debug2(printf("Evaluating high %08X and low %08X\n",*ptr,ptr[1]));
#ifdef WORDS_BIGENDIAN
  compare = Bigendian_convert_uint(*ptr++);
#else
  compare = *ptr++;
#endif
  /* Get high_halfsite bit */
  found = splicesite_bits[compare >> 16];
  *high_halfsite = (found & 0x100) >> 8;
  found = (found << 24) | 0x00FFFFFF;
  debug2(printf("  splicesite_bits_3: %08X, high_halfsite %d\n",
		splicesite_bits[compare >> 16] << 24,*high_halfsite));

  found &= (splicesite_bits[compare & 0x0000FFFF] << 16) | 0xFE00FFFF; /* Use FE to allow for high bit */
  debug2(printf("  splicesite_bits_2: %08X\n",splicesite_bits[compare & 0x0000FFFF] << 16));

  /* Low */
#ifdef WORDS_BIGENDIAN
  compare = Bigendian_convert_uint(*ptr++);
#else
  compare = *ptr++;
#endif
  found &= (splicesite_bits[compare >> 16] << 8) | 0xFFFE00FF;
  debug2(printf("  splicesite_bits_1: %08X\n",splicesite_bits[compare >> 16] << 8));

  found &= splicesite_bits[compare & 0x0000FFFF] | 0xFFFFFE00;
  debug2(printf("  splicesite_bits_0: %08X, low_halfsite %d\n",
		splicesite_bits[compare & 0x0000FFFF],found & 0x1));


  /* Flags: N is considered a mismatch */
  debug2(printf("Marking flags: query %08X and genome %08X ",*query_shifted,*ptr));
#ifdef WORDS_BIGENDIAN
  flags = Bigendian_convert_uint(*ptr);
#else
  flags = (*ptr);
#endif

  found &= ~flags;
  found &= ~(flags << 1);

  *low_halfsite = found & 0x00000001;

  *high_halfsite &= ~(flags >> 31);

  /* splicesite_bits are 1-based, so need to reduce values by 1 */
  /* No need to clear top bit */
  found >>= 1;
  debug2(printf(" => found %08X, high_halfsite %d, low_halfsite %d\n",found,*high_halfsite,*low_halfsite));

  return found;
}



static UINT4
block_find_snp (UINT4 *high_halfsite, UINT4 *low_halfsite, UINT4 *ref_ptr, UINT4 *alt_ptr,
		const UINT4 *splicesite_bits) {
  UINT4 found, ref, alt;
  

  /* High */
  debug2(printf("Evaluating high %08X and low %08X\n",*ref_ptr,ref_ptr[1]));
#ifdef WORDS_BIGENDIAN
  ref = Bigendian_convert_uint(*ref_ptr++);
  alt = Bigendian_convert_uint(*alt_ptr++);
#else
  ref = *ref_ptr++;
  alt = *alt_ptr++;
#endif
  /* Get high_halfsite bit */
  found = splicesite_bits[ref >> 16] | splicesite_bits[alt >> 16];
  *high_halfsite = (found & 0x100) >> 8;
  found = (found << 24) | 0x00FFFFFF;
  debug2(printf("  splicesite_bits_3: %08X | %08X, high_halfsite %d\n",
		splicesite_bits[ref >> 16] << 24,splicesite_bits[alt >> 16] << 24,*high_halfsite));

 /* Use FE to allow for high bit */
  found &= ((splicesite_bits[ref & 0x0000FFFF] | splicesite_bits[alt & 0x0000FFFF]) << 16) | 0xFE00FFFF;
  debug2(printf("  splicesite_bits_2: %08X | %08X\n",
		splicesite_bits[ref & 0x0000FFFF] << 16,splicesite_bits[alt & 0x0000FFFF] << 16));

  /* Low */
#ifdef WORDS_BIGENDIAN
  ref = Bigendian_convert_uint(*ref_ptr++);
  alt = Bigendian_convert_uint(*alt_ptr++);
#else
  ref = *ref_ptr++;
  alt = *alt_ptr++;
#endif
  found &= ((splicesite_bits[ref >> 16] | splicesite_bits[alt >> 16]) << 8) | 0xFFFE00FF;
  debug2(printf("  splicesite_bits_1: %08X | %08X\n",
		splicesite_bits[ref >> 16] << 8,splicesite_bits[alt >> 16] << 8));

  found &= (splicesite_bits[ref & 0x0000FFFF] | splicesite_bits[alt & 0x0000FFFF]) | 0xFFFFFE00;
  debug2(printf("  splicesite_bits_0: %08X | %08X, low_halfsite %d\n",
		splicesite_bits[ref & 0x0000FFFF],splicesite_bits[ref & 0x0000FFFF],found & 0x1));


#if 0
  /* Not handling flags yet */
  /* Flags: N is considered a mismatch */
  debug2(printf("Marking flags: query %08X and genome %08X ",*query_shifted,*ref_ptr));
#ifdef WORDS_BIGENDIAN
  found |= Bigendian_convert_uint(*ref_ptr);
#else
  found |= (*ref_ptr);
#endif
#endif

  *low_halfsite = found & 0x00000001;

  /* splicesite_bits are 1-based, so need to reduce values by 1 */
  /* No need to clear top bit */
  found >>= 1;
  debug2(printf(" => found %08X, high_halfsite %d, low_halfsite %d\n",found,*high_halfsite,*low_halfsite));

  return found;
}


static int
splicesite_positions (int *site_positions, int *site_knowni, int *knownpos, int *knowni,
		      Genomicpos_T left, int pos5, int pos3,
		      const UINT4 *splicesite_bits, int splicepos_offset) {
  int nfound = 0, offset;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ptr, *end;
  UINT4 found;
  UINT4 high_halfsite, low_halfsite, prev_high_halfsite;
  int pos;
#ifdef HAVE_BUILTIN_CTZ
  int relpos;
#else
  UINT4 lowbit;
#endif

  debug2(
	printf("\n\n");
	printf("Genome (in splicesite_positions):\n");
	Genome_print_blocks(ref_blocks,left+pos5,left+pos3);
	printf("\n");
	);

  /* nshift = left % 32; */

  startblocki = (left+pos5)/32U*3;
  endblocki = (left+pos3)/32U*3;
  startdiscard = (left+pos5) % 32;
  enddiscard = (left+pos3) % 32;

  offset = -startdiscard + pos5 + splicepos_offset;
  
  debug2(printf("left = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
	       left,pos5,pos3,startblocki,endblocki));
  debug2(printf("startdiscard = %u, enddiscard = %u\n",startdiscard,enddiscard));

  if (endblocki == startblocki) {
    /* Advance knownpos past pos5 */
    while (*knownpos < pos5) {
      debug2(printf("Skipping knownpos #%d at %d < pos5 %d\n",*knowni,*knownpos,pos5));
      knowni++;
      knownpos++;
    }

    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[startblocki]),splicesite_bits);
    found = clear_start(found,startdiscard);
    found = clear_end(found,enddiscard);
    debug2(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset + (relpos = __builtin_ctz(found));
      while (*knownpos < pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      }
      if (*knownpos == pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      } else {
	site_knowni[nfound] = -1;
	site_positions[nfound++] = pos;
      }
      clear_lowbit(found,relpos);
#else      
      debug2(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset + mod_37_bit_position[(lowbit = -found & found) % 37];
      while (*knownpos < pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      }
      if (*knownpos == pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      } else {
	site_knowni[nfound] = -1;
	site_positions[nfound++] = pos;
      }
      found -= lowbit;
#endif
      debug2(printf("found is %08X => offset %d + relpos %d\n",found,offset,relpos));
    }

    /* Add knownpos to pos3 */
    while (*knownpos < pos3) {
      debug2(printf("Adding knownpos #%d at %d < pos3 %d\n",*knowni,*knownpos,pos3));
      site_knowni[nfound] = *knowni++;
      site_positions[nfound++] = *knownpos++;
    }

    return nfound;

  } else {
    /* Advance knownpos past pos5 */
    while (*knownpos < pos5) {
      debug2(printf("Skipping knownpos #%d at %d < pos5 %d\n",*knowni,*knownpos,pos5));
      knowni++;
      knownpos++;
    }

    /* Startblock */
    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[startblocki]),splicesite_bits);
    found = clear_start(found,startdiscard);
    debug2(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset + (relpos = __builtin_ctz(found));
      while (*knownpos < pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      }
      if (*knownpos == pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      } else {
	site_knowni[nfound] = -1;
	site_positions[nfound++] = pos;
      }
      clear_lowbit(found,relpos);
#else
      debug2(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset + mod_37_bit_position[(lowbit = -found & found) % 37];
      while (*knownpos < pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      }
      if (*knownpos == pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      } else {
	site_knowni[nfound] = -1;
	site_positions[nfound++] = pos;
      }
      found -= lowbit;
#endif
      debug2(printf("found is %08X => offset %d + relpos %d\n",found,offset,relpos));
    }

    ptr = &(ref_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    offset += 32;
    while (ptr < end) {
      prev_high_halfsite = high_halfsite;
      found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);

      if (low_halfsite & prev_high_halfsite) {
	debug2(printf("low_halfsite & prev_high_halfsite => offset %d - 1\n",offset));
	pos = offset - 1;	/* verified that this should be offset - 1 */
	while (*knownpos < pos) {
	  site_knowni[nfound] = *knowni++;
	  site_positions[nfound++] = *knownpos++;
	}
	if (*knownpos == pos) {
	  site_knowni[nfound] = *knowni++;
	  site_positions[nfound++] = *knownpos++;
	} else {
	  site_knowni[nfound] = -1;
	  site_positions[nfound++] = pos;
	}
      }

      while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
	pos = offset + (relpos = __builtin_ctz(found));
	while (*knownpos < pos) {
	  site_knowni[nfound] = *knowni++;
	  site_positions[nfound++] = *knownpos++;
	}
	if (*knownpos == pos) {
	  site_knowni[nfound] = *knowni++;
	  site_positions[nfound++] = *knownpos++;
	} else {
	  site_knowni[nfound] = -1;
	  site_positions[nfound++] = pos;
	}
	clear_lowbit(found,relpos);
#else
	debug2(printf("found is %08X, -found & found is %08X\n",found,-found & found));
	pos = offset + mod_37_bit_position[(lowbit = -found & found) % 37];
	while (*knownpos < pos) {
	  site_knowni[nfound] = *knowni++;
	  site_positions[nfound++] = *knownpos++;
	}
	if (*knownpos == pos) {
	  site_knowni[nfound] = *knowni++;
	  site_positions[nfound++] = *knownpos++;
	} else {
	  site_knowni[nfound] = -1;
	  site_positions[nfound++] = pos;
	}
	found -= lowbit;
#endif
	debug2(printf("found is %08X => offset %d + relpos %d\n",found,offset,relpos));
      }

      ptr += 3;
      offset += 32;
    }

    /* Endblock */
    prev_high_halfsite = high_halfsite;
    found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);
    found = clear_end(found,enddiscard);
    debug2(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    if (low_halfsite & prev_high_halfsite) {
      debug2(printf("low_halfsite & prev_high_halfsite => offset %d - 1\n",offset));
      pos = offset - 1;		/* verified that this should be offset - 1 */
      while (*knownpos < pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      }
      if (*knownpos == pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      } else {
	site_knowni[nfound] = -1;
	site_positions[nfound++] = pos;
      }
    }

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset + (relpos = __builtin_ctz(found));
      while (*knownpos < pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      }
      if (*knownpos == pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      } else {
	site_knowni[nfound] = -1;
	site_positions[nfound++] = pos;
      }
      clear_lowbit(found,relpos);
#else
      debug2(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset + mod_37_bit_position[(lowbit = -found & found) % 37];
      while (*knownpos < pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      }
      if (*knownpos == pos) {
	site_knowni[nfound] = *knowni++;
	site_positions[nfound++] = *knownpos++;
      } else {
	site_knowni[nfound] = -1;
	site_positions[nfound++] = pos;
      }
      found -= lowbit;
#endif
      debug2(printf("found is %08X => offset %d + relpos %d\n",found,offset,relpos));
    }

    /* Add knownpos to pos3 */
    while (*knownpos < pos3) {
      debug2(printf("Adding knownpos #%d at %d < pos3 %d\n",*knowni,*knownpos,pos3));
      site_knowni[nfound] = *knowni++;
      site_positions[nfound++] = *knownpos++;
    }

    return nfound;
  }

}


int
Genome_donor_positions (int *site_positions, int *site_knowni, int *knownpos, int *knowni,
			Genomicpos_T left, int pos5, int pos3) {
  return splicesite_positions(site_positions,site_knowni,knownpos,knowni,left,pos5,pos3,donor_gtgc_bits,
			      /*splicepos_offset*/0);
}

int
Genome_acceptor_positions (int *site_positions, int *site_knowni, int *knownpos, int *knowni,
			   Genomicpos_T left, int pos5, int pos3) {
  return splicesite_positions(site_positions,site_knowni,knownpos,knowni,left,pos5,pos3,acceptor_bits,
			      /*splicepos_offset*/2);
}

int
Genome_antidonor_positions (int *site_positions, int *site_knowni, int *knownpos, int *knowni,
			    Genomicpos_T left, int pos5, int pos3) {
  return splicesite_positions(site_positions,site_knowni,knownpos,knowni,left,pos5,pos3,antidonor_acgc_bits,
			      /*splicepos_offset*/2);
}

int
Genome_antiacceptor_positions (int *site_positions, int *site_knowni, int *knownpos, int *knowni,
			       Genomicpos_T left, int pos5, int pos3) {
  return splicesite_positions(site_positions,site_knowni,knownpos,knowni,left,pos5,pos3,antiacceptor_bits,
			      /*splicepos_offset*/0);
}


/* pos5 (startblock) corresponds to a lower genomicpos than pos */
static int
prev_dinucleotide_position_fwd (int pos, Genomicpos_T genomicstart, int pos5,
				const UINT4 *splicesite_bits, int splicepos_offset) {
  int lastpos;
  int offset;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ptr, *start;
  UINT4 found;
  UINT4 high_halfsite, low_halfsite, prev_low_halfsite;
  int relpos;
#ifndef HAVE_BUILTIN_CLZ
  UINT4 top;
#endif

  startblocki = (genomicstart+pos5)/32U*3;
  endblocki = (genomicstart+pos)/32U*3;
  enddiscard = (genomicstart+pos) % 32;

#if 1
  debug3a(
	printf("\n\n");
	printf("Genome (in prev_dinucleotide_position_fwd): genomicstart %u, pos %d, pos5 %d\n",
	       genomicstart,pos,pos5);
	Genome_print_blocks(ref_blocks,genomicstart+pos5,genomicstart+pos);
	printf("\n");
	);
#endif

  offset = (pos - 1) - enddiscard + 32 + splicepos_offset;

  if (endblocki == startblocki) {
    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[endblocki]),splicesite_bits);
    found = clear_end(found,enddiscard);
    startdiscard = (genomicstart+pos5) % 32;
    found = clear_start(found,startdiscard);

    if (found != 0U) {
#ifdef HAVE_BUILTIN_CLZ
      lastpos = offset - (relpos = __builtin_clz(found));
#else
      lastpos = offset - (relpos = (top = found >> 16) ? clz_table[top] : 16 + clz_table[found]);
#endif
      debug3a(printf("oneblock: found is %08X => offset %d - relpos %d\n",found,offset,relpos));
      return lastpos;
    } else {
      return -1;
    }

  } else {
    /* Endblock */
    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[endblocki]),splicesite_bits);
    found = clear_end(found,enddiscard);

    if (found != 0U) {
#ifdef HAVE_BUILTIN_CLZ
      lastpos = offset - (relpos = __builtin_clz(found));
#else
      lastpos = offset - (relpos = (top = found >> 16) ? clz_table[top] : 16 + clz_table[found]);
#endif
      debug3a(printf("endblock: found is %08X => offset %d - relpos %d\n",found,offset,relpos));
      return lastpos;
    }

    ptr = &(ref_blocks[endblocki-3]);
    start = &(ref_blocks[startblocki]);
    offset -= 32;

    while (ptr > start) {
      /* Middle blocks */
      prev_low_halfsite = low_halfsite;
      found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);

      if (high_halfsite & prev_low_halfsite) {
	debug3a(printf("high_halfsite & prev_low_halfsite => offset %d - 1\n",offset));
	return offset;
      } else if (found != 0U) {
#ifdef HAVE_BUILTIN_CLZ
	lastpos = offset - (relpos = __builtin_clz(found));
#else
	lastpos = offset - (relpos = (top = found >> 16) ? clz_table[top] : 16 + clz_table[found]);
#endif
	debug3a(printf("middleblock: found is %08X => offset %d - relpos %d\n",found,offset,relpos));
	return lastpos;
      }

      ptr -= 3;
      offset -= 32;
    }

    /* Startblock */
    prev_low_halfsite = low_halfsite;
    found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);

    if (high_halfsite & prev_low_halfsite) {
      debug3a(printf("high_halfsite & prev_low_halfsite => offset %d - 1\n",offset));
      return offset;
    } else {
      startdiscard = (genomicstart+pos5) % 32;
      found = clear_start(found,startdiscard);

      if (found != 0U) {
#ifdef HAVE_BUILTIN_CLZ
	lastpos = offset - (relpos = __builtin_clz(found));
#else
	lastpos = offset - (relpos = (top = found >> 16) ? clz_table[top] : 16 + clz_table[found]);
#endif
	debug3a(printf("startblock: found is %08X => offset %d - relpos %d\n",found,offset,relpos));
	return lastpos;
      } else {
	return -1;
      }
    }
  }
}


/* Same as splicesite_positions, but designed for stage 2 */
static void
last_dinucleotide_positions_fwd (int *last_position, Genomicpos_T genomicstart, 
				 int margin5, int margin3, int genomiclength,
				 const UINT4 *splicesite_bits, int splicepos_offset) {
  int lastpos = -1, pos5, pos3;
  int offset;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ptr, *end;
  UINT4 found;
  UINT4 high_halfsite, low_halfsite, prev_high_halfsite;
  int pos, i = 0;
#ifdef HAVE_BUILTIN_CTZ
  int relpos;
#else
  UINT4 lowbit;
#endif

  pos5 = margin5;
  pos3 = genomiclength - margin3;

#if 0
  debug3(
	printf("\n\n");
	printf("Genome (in last_dinucleotide_positions):\n");
	Genome_print_blocks(ref_blocks,genomicstart+pos5,genomicstart+pos3);
	printf("\n");
	);
#endif

  startblocki = (genomicstart+pos5)/32U*3;
  endblocki = (genomicstart+pos3)/32U*3;
  startdiscard = (genomicstart+pos5) % 32;
  enddiscard = (genomicstart+pos3) % 32;

  offset = -startdiscard + pos5 + splicepos_offset;
  
  debug3(printf("genomicstart = %u, pos5 = %d, pos3 = %d, startblocki = %u, endblocki = %u\n",
		genomicstart,pos5,pos3,startblocki,endblocki));
  debug3(printf("startdiscard = %u, enddiscard = %u\n",startdiscard,enddiscard));

  if (endblocki == startblocki) {

    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[startblocki]),splicesite_bits);
    found = clear_start(found,startdiscard);
    found = clear_end(found,enddiscard);
    debug3(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset + (relpos = __builtin_ctz(found));
      while (i < pos) {
	last_position[i] = lastpos;
	i++;
      }
      lastpos = pos;

      clear_lowbit(found,relpos);
#else      
      debug3(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset + mod_37_bit_position[(lowbit = -found & found) % 37];
      while (i < pos) {
	last_position[i] = lastpos;
	i++;
      }
      lastpos = pos;

      found -= lowbit;
#endif
      debug3(printf("found is %08X => offset %d + relpos %d\n",found,offset,relpos));
    }

    while (i < genomiclength) {
      last_position[i] = lastpos;
      i++;
    }

    return;

  } else {

    /* Startblock */
    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[startblocki]),splicesite_bits);
    found = clear_start(found,startdiscard);
    debug3(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset + (relpos = __builtin_ctz(found));
      while (i < pos) {
	last_position[i] = lastpos;
	i++;
      }
      lastpos = pos;

      clear_lowbit(found,relpos);
#else
      debug3(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset + mod_37_bit_position[(lowbit = -found & found) % 37];
      while (i < pos) {
	last_position[i] = lastpos;
	i++;
      }
      lastpos = pos;

      found -= lowbit;
#endif
      debug3(printf("found is %08X => offset %d + relpos %d\n",found,offset,relpos));
    }

    ptr = &(ref_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    offset += 32;
    while (ptr < end) {
      prev_high_halfsite = high_halfsite;
      found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);

      if (low_halfsite & prev_high_halfsite) {
	debug3(printf("low_halfsite & prev_high_halfsite => offset %d\n",offset));
	pos = offset;
	while (i < pos) {
	  last_position[i] = lastpos;
	  i++;
	}
	lastpos = pos;
      }

      while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
	pos = offset + (relpos = __builtin_ctz(found));
	while (i < pos) {
	  last_position[i] = lastpos;
	  i++;
	}
	lastpos = pos;

	clear_lowbit(found,relpos);
#else
	debug3(printf("found is %08X, -found & found is %08X\n",found,-found & found));
	pos = offset + mod_37_bit_position[(lowbit = -found & found) % 37];
	while (i < pos) {
	  last_position[i] = lastpos;
	  i++;
	}
	lastpos = pos;

	found -= lowbit;
#endif
	debug3(printf("found is %08X => offset %d + relpos %d\n",found,offset,relpos));
      }

      ptr += 3;
      offset += 32;
    }

    /* Endblock */
    prev_high_halfsite = high_halfsite;
    found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);
    found = clear_end(found,enddiscard);
    debug3(printf("adding end mask %08x\n",clear_end_mask(enddiscard)));

    if (low_halfsite & prev_high_halfsite) {
      debug3(printf("low_halfsite & prev_high_halfsite => offset %d\n",offset));
      pos = offset;
      while (i < pos) {
	last_position[i] = lastpos;
	i++;
      }
      lastpos = pos;
    }

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset + (relpos = __builtin_ctz(found));
      while (i < pos) {
	last_position[i] = lastpos;
	i++;
      }
      lastpos = pos;

      clear_lowbit(found,relpos);
#else
      debug3(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset + mod_37_bit_position[(lowbit = -found & found) % 37];
      while (i < pos) {
	last_position[i] = lastpos;
	i++;
      }
      lastpos = pos;

      found -= lowbit;
#endif
      debug3(printf("found is %08X => offset %d + relpos %d\n",found,offset,relpos));
    }

    while (i < genomiclength) {
      last_position[i] = lastpos;
      i++;
    }

    return;
  }

}


/* pos5 (endblock) corresponds to a higher genomicpos than pos */
static int
prev_dinucleotide_position_rev (int pos, Genomicpos_T genomicend, int pos5,
				const UINT4 *splicesite_bits, int splicepos_offset) {
  int lastpos;
  int offset;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  UINT4 *ptr, *end;
  UINT4 found;
  UINT4 high_halfsite, low_halfsite, prev_high_halfsite;
  int relpos;
#ifndef HAVE_BUILTIN_CTZ
  UINT4 lowbit;
#endif

  startblocki = (genomicend-pos)/32U*3;
  endblocki = (genomicend-pos5)/32U*3;
  startdiscard = (genomicend-pos) % 32;

#if 0
  debug3b(
	printf("\n\n");
	printf("Genome (in prev_dinucleotide_position_rev): genomicend %u, pos %d, pos5 %d\n",
	       genomicend,pos,pos5);
	Genome_print_blocks(ref_blocks,genomicend-pos,genomicend-pos5);
	printf("\n");
	);
#endif

  offset = pos + startdiscard + splicepos_offset;
  debug3b(printf("offset %d = pos %d + startdiscard %d + splicepos_offset %d\n",
		offset,pos,startdiscard,splicepos_offset));

  if (startblocki == endblocki) {
    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[startblocki]),splicesite_bits);
    found = clear_start(found,startdiscard);
    enddiscard = (genomicend-pos5) % 32;
    found = clear_end(found,enddiscard);

    if (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      lastpos = offset - (relpos = __builtin_ctz(found));
#else
      lastpos = offset - (relpos = mod_37_bit_position[(lowbit = -found & found) % 37]);
#endif
      debug3b(printf("oneblock: found is %08X => offset %d - relpos %d\n",found,offset,relpos));
      return lastpos;
    } else {
      return -1;
    }

  } else {
    /* Startblock */
    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[startblocki]),splicesite_bits);
    found = clear_start(found,startdiscard);

    if (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      lastpos = offset - (relpos = __builtin_ctz(found));
#else
      lastpos = offset - (relpos = mod_37_bit_position[(lowbit = -found & found) % 37]);
#endif
      debug3b(printf("startblock: found is %08X => offset %d - relpos %d\n",found,offset,relpos));
      return lastpos;
    }

    ptr = &(ref_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    offset -= 32;

    while (ptr < end) {
      /* Middle blocks */
      prev_high_halfsite = high_halfsite;
      found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);

      if (low_halfsite & prev_high_halfsite) {
	debug3b(printf("low_halfsite & prev_high_halfsite => offset %d + 1\n",offset));
	return offset + 1;
      } else if (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
	lastpos = offset - (relpos = __builtin_ctz(found));
#else
	lastpos = offset - (relpos = mod_37_bit_position[(lowbit = -found & found) % 37]);
#endif
	debug3b(printf("middleblock: found is %08X => offset %d - relpos %d\n",found,offset,relpos));
	return lastpos;
      }

      ptr += 3;
      offset -= 32;
    }

    /* Endblock */
    prev_high_halfsite = high_halfsite;
    found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);

    if (low_halfsite & prev_high_halfsite) {
      debug3b(printf("low_halfsite & prev_high_halfsite => offset %d + 1\n",offset));
      return offset + 1;
    } else {
      enddiscard = (genomicend-pos5) % 32;
      found = clear_end(found,enddiscard);

      if (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
	lastpos = offset - (relpos = __builtin_ctz(found));
#else
	lastpos = offset - (relpos = mod_37_bit_position[(lowbit = -found & found) % 37]);
#endif
	debug3b(printf("endblock: found is %08X => offset %d - relpos %d\n",found,offset,relpos));
	return lastpos;
      } else {
	return -1;
      }
    }
  }
}



static void
last_dinucleotide_positions_rev (int *last_position, Genomicpos_T genomicstart, 
				 int margin5, int margin3, int genomiclength,
				 const UINT4 *splicesite_bits, int splicepos_offset) {
  int pos5, pos3;
  int offset;
  Genomicpos_T startdiscard, enddiscard, startblocki, endblocki;
  Genomicpos_T origindiscard, originblocki;
  UINT4 *ptr, *end;
  UINT4 found;
  UINT4 high_halfsite, low_halfsite, prev_high_halfsite;
  int pos, i = genomiclength - 1;
#ifdef HAVE_BUILTIN_CTZ
  int relpos;
#else
  UINT4 lowbit;
#endif

  pos5 = margin3;
  pos3 = genomiclength - margin5;

  debug3(
	printf("\n\n");
	printf("Genome (in last_dinucleotide_positions):\n");
	Genome_print_blocks(ref_blocks,genomicstart+pos5,genomicstart+pos3);
	printf("\n");
	);

  startblocki = (genomicstart+pos5)/32U*3;
  endblocki = (genomicstart+pos3)/32U*3;
  originblocki = (genomicstart+genomiclength)/32U*3;

  startdiscard = (genomicstart+pos5) % 32;
  enddiscard = (genomicstart+pos3) % 32;
  origindiscard = (genomicstart+genomiclength) % 32;

  offset = (originblocki - startblocki) * 32U/3 + origindiscard + splicepos_offset;

  debug3(printf("genomicstart = %u, pos5 = %d, pos3 = %d, genomiclength = %d, startblocki = %u, endblocki = %u, originblocki = %u\n",
		genomicstart,pos5,pos3,genomiclength,startblocki,endblocki,originblocki));
  debug3(printf("startdiscard = %u, enddiscard = %u, origindiscard = %u\n",
		startdiscard,enddiscard,origindiscard));
  debug3(printf("offset = %d\n",offset));

  if (endblocki == startblocki) {

    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[startblocki]),splicesite_bits);
    found = clear_start(found,startdiscard);
    found = clear_end(found,enddiscard);
    debug3(printf("adding masks %08X and %08x\n",clear_start_mask(startdiscard),clear_end_mask(enddiscard)));

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset - (relpos = __builtin_ctz(found));
      while (i >= pos) {
	last_position[i] = pos;
	i--;
      }

      clear_lowbit(found,relpos);
#else      
      debug3(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset - mod_37_bit_position[(lowbit = -found & found) % 37];
      while (i >= pos) {
	last_position[i] = pos;
	i--;
      }

      found -= lowbit;
#endif
      debug3(printf("found is %08X => offset %d - relpos %d\n",found,offset,relpos));
    }

    while (i >= 0) {
      last_position[i] = -1;
      i--;
    }

    assert(i == -1);
    return;

  } else {

    /* Startblock */
    found = block_find(&high_halfsite,&low_halfsite,&(ref_blocks[startblocki]),splicesite_bits);
    found = clear_start(found,startdiscard);
    debug3(printf("adding start mask %08x\n",clear_start_mask(startdiscard)));

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset - (relpos = __builtin_ctz(found));
      while (i >= pos) {
	last_position[i] = pos;
	i--;
      }

      clear_lowbit(found,relpos);
#else
      debug3(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset - mod_37_bit_position[(lowbit = -found & found) % 37];
      while (i >= pos) {
	last_position[i] = pos;
	i--;
      }

      found -= lowbit;
#endif
      debug3(printf("found is %08X => offset %d - relpos %d\n",found,offset,relpos));
    }

    ptr = &(ref_blocks[startblocki+3]);
    end = &(ref_blocks[endblocki]);
    offset -= 32;
    while (ptr < end) {
      prev_high_halfsite = high_halfsite;
      found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);

      if (low_halfsite & prev_high_halfsite) {
	debug3(printf("high_halfsite & prev_low_halfsite => offset %d + 1\n",offset));
	pos = offset + 1;
	while (i >= pos) {
	  last_position[i] = pos;
	  i--;
	}
      }

      while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
	pos = offset - (relpos = __builtin_ctz(found));
	while (i >= pos) {
	  last_position[i] = pos;
	  i--;
	}

	clear_lowbit(found,relpos);
#else
	debug3(printf("found is %08X, -found & found is %08X\n",found,-found & found));
	pos = offset - mod_37_bit_position[(lowbit = -found & found) % 37];
	while (i >= pos) {
	  last_position[i] = pos;
	  i--;
	}

	found -= lowbit;
#endif
	debug3(printf("found is %08X => offset %d - relpos %d\n",found,offset,relpos));
      }

      ptr += 3;
      offset -= 32;
    }

    /* Endblock */
    prev_high_halfsite = high_halfsite;
    found = block_find(&high_halfsite,&low_halfsite,ptr,splicesite_bits);
    found = clear_end(found,enddiscard);
    debug3(printf("adding end mask %08x => found %08x\n",clear_end_mask(enddiscard),found));

    if (low_halfsite & prev_high_halfsite) {
      debug3(printf("high_halfsite & prev_low_halfsite => offset %d + 1\n",offset));
      pos = offset + 1;
      while (i >= pos) {
	last_position[i] = pos;
	i--;
      }
    }

    while (found != 0U) {
#ifdef HAVE_BUILTIN_CTZ
      pos = offset - (relpos = __builtin_ctz(found));
      while (i >= pos) {
	last_position[i] = pos;
	i--;
      }

      clear_lowbit(found,relpos);
#else
      debug3(printf("found is %08X, -found & found is %08X\n",found,-found & found));
      pos = offset - mod_37_bit_position[(lowbit = -found & found) % 37];
      while (i >= pos) {
	last_position[i] = pos;
	i--;
      }

      found -= lowbit;
#endif
      debug3(printf("found is %08X => offset %d - relpos %d\n",found,offset,relpos));
    }

    while (i >= 0) {
      last_position[i] = -1;
      i--;
    }

    assert(i == -1);
    return;
  }

}

  

int
Genome_prev_donor_position (int pos, Genomicpos_T genomicstart, Genomicpos_T genomicend,
			    int pos5, bool plusp) {
  if (plusp == true) {
    return prev_dinucleotide_position_fwd(pos+2,genomicstart,pos5,donor_gt_bits,/*splicepos_offset*/-1);
  } else {
    return prev_dinucleotide_position_rev(pos+3,genomicend,pos5,antidonor_ac_bits,/*splicepos_offset*/-3);
  }
}

int
Genome_prev_acceptor_position (int pos, Genomicpos_T genomicstart, Genomicpos_T genomicend,
			       int pos5, bool plusp) {
  if (plusp == true) {
    return prev_dinucleotide_position_fwd(pos-1,genomicstart,pos5,acceptor_bits,/*splicepos_offset*/2);
  } else {
    return prev_dinucleotide_position_rev(pos,genomicend,pos5,antiacceptor_bits,/*splicepos_offset*/0);
  }
}

int
Genome_prev_antidonor_position (int pos, Genomicpos_T genomicstart, Genomicpos_T genomicend,
				int pos5, bool plusp) {
  if (plusp == true) {
    return prev_dinucleotide_position_fwd(pos-1,genomicstart,pos5,antidonor_ac_bits,/*splicepos_offset*/2);
  } else {
    return prev_dinucleotide_position_rev(pos,genomicend,pos5,donor_gt_bits,/*splicepos_offset*/0);
  }
}

int
Genome_prev_antiacceptor_position (int pos, Genomicpos_T genomicstart, Genomicpos_T genomicend,
				   int pos5, bool plusp) {
  if (plusp == true) {
    return prev_dinucleotide_position_fwd(pos+2,genomicstart,pos5,antiacceptor_bits,/*splicepos_offset*/-1);
  } else {
    return prev_dinucleotide_position_rev(pos+3,genomicend,pos5,acceptor_bits,/*splicepos_offset*/-3);
  }
}


void
Genome_last_donor_positions (int *last_position, Genomicpos_T genomicstart, int margin5, int margin3, int genomiclength,
			     bool plusp) {
  if (plusp == true) {
    last_dinucleotide_positions_fwd(last_position,genomicstart,margin5,margin3,genomiclength,donor_gt_bits,
					   /*splicepos_offset*/-1);
  } else {
    last_dinucleotide_positions_rev(last_position,genomicstart,margin5,margin3,genomiclength,antidonor_ac_bits,
					   /*splicepos_offset*/-3);
  }
}

void
Genome_last_acceptor_positions (int *last_position, Genomicpos_T genomicstart, int margin5, int margin3, int genomiclength,
				bool plusp) {
  if (plusp == true) {
    last_dinucleotide_positions_fwd(last_position,genomicstart,margin5,margin3,genomiclength,acceptor_bits,
					   /*splicepos_offset*/2);
  } else {
    last_dinucleotide_positions_rev(last_position,genomicstart,margin5,margin3,genomiclength,antiacceptor_bits,
					   /*splicepos_offset*/0);
  }
}

void
Genome_last_antidonor_positions (int *last_position, Genomicpos_T genomicstart, int margin5, int margin3, int genomiclength,
				 bool plusp) {
  if (plusp == true) {
    last_dinucleotide_positions_fwd(last_position,genomicstart,margin5,margin3,genomiclength,antidonor_ac_bits,
					   /*splicepos_offset*/2);
  } else {
    last_dinucleotide_positions_rev(last_position,genomicstart,margin5,margin3,genomiclength,donor_gt_bits,
					   /*splicepos_offset*/0);
  }
}

void
Genome_last_antiacceptor_positions (int *last_position, Genomicpos_T genomicstart, int margin5, int margin3, int genomiclength,
				    bool plusp) {
  if (plusp == true) {
    last_dinucleotide_positions_fwd(last_position,genomicstart,margin5,margin3,genomiclength,antiacceptor_bits,
					   /*splicepos_offset*/-1);
  } else {
    last_dinucleotide_positions_rev(last_position,genomicstart,margin5,margin3,genomiclength,acceptor_bits,
					   /*splicepos_offset*/-3);
  }
}
